<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="java"
	version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Account by Type '" />
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'data']/row and $report_type = 1">
			<xsl:call-template name="summary" />
		</xsl:when>
		<xsl:when test="/all_results/results[@name = 'data']/row and $report_type = 2">
			<xsl:call-template name="detail" />
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No accounts found for type.
			</fo:block>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="summary">
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.50in" />
			<fo:table-column column-width="1.50in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Account
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Account Name
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Address
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> City / State
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Zip
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Account Type
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Active Services
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:call-template name="sumrow" />
			</fo:table-body>
		</fo:table>
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			Account Total
			<fo:inline>
				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '#,###,###,##0')" />
			</fo:inline>
		</fo:block>
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			Total Active Services
			<fo:inline>
				<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row/servcnt), '#,###,###,##0')" />
			</fo:inline>
		</fo:block>
	</xsl:template>	
	
	<xsl:template name="sumrow">
		<xsl:for-each select="/all_results/results[@name = 'data']/row">
			<fo:table-row keep-together="always">
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:if test="./cycle &gt; 0 and ./acct &gt; 0">
							<xsl:value-of select="format-number(./cycle, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number(./acct, '0000000')" />
						</xsl:if>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./fname" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./lname" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./adln1" />
					</fo:block>
					<fo:block>
						<xsl:value-of select="./adln2" />
					</fo:block>
					<fo:block>
						<xsl:value-of select="./adln3" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./adcity" />
						<xsl:value-of select="', '" />
						<xsl:value-of select="./adst" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="substring(./adzip, 1, 5)" />
						<xsl:if test="string-length(normalize-space(./adzip)) &gt; 5">
							<xsl:value-of select="'-'" />
							<xsl:value-of select="substring(./adzip, 6, 4)" />
						</xsl:if>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:choose>
							<xsl:when test="./typser = 'R'">
								<xsl:value-of select="'Residential'" />
							</xsl:when>
							<xsl:when test="./typser = 'B'">
								<xsl:value-of select="'Business'" />
							</xsl:when>
							<xsl:when test="./typser = 'C'">
								<xsl:value-of select="'Company'" />
							</xsl:when>
							<xsl:when test="./typser = ' '">
								<xsl:value-of select="'no type set'" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="./typser" />
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
					<fo:block>
						<xsl:if test="./servcnt &gt; 0">
							<xsl:value-of select="format-number(./servcnt, '###,##0')" />
						</xsl:if>
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="detail">
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.50in" />
			<fo:table-column column-width="1.50in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="1.00in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Account
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Account Name
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Address
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> City / State
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Zip
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Account Type
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> MDN
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Disc Date
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block> Connect Date
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:call-template name="detrow" />
			</fo:table-body>
		</fo:table>
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
			Account/Services Total
			<fo:inline>
				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '#,###,###,##0')" />
			</fo:inline>
		</fo:block>
	</xsl:template>	
	
	<xsl:template name="detrow">
		<xsl:for-each select="/all_results/results[@name = 'data']/row">
			<fo:table-row keep-together="always">
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:if test="./cycle &gt; 0 and ./acct &gt; 0">
							<xsl:value-of select="format-number(./cycle, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number(./acct, '0000000')" />
						</xsl:if>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./fname" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./lname" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./adln1" />
					</fo:block>
					<fo:block>
						<xsl:value-of select="./adln2" />
					</fo:block>
					<fo:block>
						<xsl:value-of select="./adln3" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="./adcity" />
						<xsl:value-of select="', '" />
						<xsl:value-of select="./adst" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
					<fo:block>
						<xsl:value-of select="substring(./adzip, 1, 5)" />
						<xsl:if test="string-length(normalize-space(./adzip)) &gt; 5">
							<xsl:value-of select="'-'" />
							<xsl:value-of select="substring(./adzip, 6, 4)" />
						</xsl:if>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:choose>
							<xsl:when test="./typser = 'R'">
								<xsl:value-of select="'Residential'" />
							</xsl:when>
							<xsl:when test="./typser = 'B'">
								<xsl:value-of select="'Business'" />
							</xsl:when>
							<xsl:when test="./typser = 'C'">
								<xsl:value-of select="'Company'" />
							</xsl:when>
							<xsl:when test="./typser = ' '">
								<xsl:value-of select="'no type set'" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="./typser" />
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:call-template name="phone">
							<xsl:with-param name="npa" select="./cnpa"/>
							<xsl:with-param name="nxx" select="./cnxx"/>
							<xsl:with-param name="line" select="./cline"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<xsl:if test="./dcmm &gt; 0">
						<fo:block>
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./dccc"/>
								<xsl:with-param name="yy" select="./dcyy"/>
								<xsl:with-param name="mm" select="./dcmm"/>
								<xsl:with-param name="dd" select="./dcdd"/>
							</xsl:call-template>										
						</fo:block>
					</xsl:if>
				</fo:table-cell>					
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<xsl:if test="./cnmm &gt; 0">
						<fo:block>
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./cncc"/>
								<xsl:with-param name="yy" select="./cnyy"/>
								<xsl:with-param name="mm" select="./cnmm"/>
								<xsl:with-param name="dd" select="./cndd"/>
							</xsl:call-template>										
						</fo:block>
					</xsl:if>
				</fo:table-cell>						
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>	
</xsl:stylesheet>