<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
							  xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
							  xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				              xmlns:saxon="http://saxon.sf.net/"							  
							  xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
								extension-element-prefixes="saxon"							  
							  exclude-result-prefixes="java" 
							  version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="'Payment Receipt'" />

    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set" />
            <xsl:call-template name="make-body" />
        </fo:root>
    </xsl:template>	
    <xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="exists(/all_results/results[@name = 'sel']/row)">				
					<xsl:call-template name="header"></xsl:call-template>
					<xsl:call-template name="payment"></xsl:call-template>
					<xsl:call-template name="agent_note"></xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
					No Information Found
			</fo:block>
			</xsl:otherwise>
		</xsl:choose>    
    </xsl:template>	 
    <xsl:template name="header">
       <xsl:param name="row" select="/all_results/results[@name = 'sel']/row[position() = 1]"></xsl:param>
           
		<fo:table font-size="8pt" space-before="4px">
		
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="2in" />
				<fo:table-column column-width="3in" />
				<fo:table-body>
					<fo:table-row keep-with-next="always">
							<fo:table-cell text-align="right" padding-right="4px">
									<fo:block xsl:use-attribute-sets="summary-headings">Account: </fo:block>
							</fo:table-cell>
							<fo:table-cell number-columns-spanned="2" text-align="left">
								<fo:block xsl:use-attribute-sets="summary-headings">
										<xsl:value-of select="format-number($row/cycle, '000')" />
										<xsl:value-of select="'-'" />
										<xsl:value-of select="format-number($row/bacct, '0000000')" />
								</fo:block>			
							</fo:table-cell>							
					</fo:table-row>					
					<fo:table-row keep-with-next="always">
							<fo:table-cell text-align="right" padding-right="4px">
									<fo:block xsl:use-attribute-sets="summary-headings">Service: </fo:block>
							</fo:table-cell>					
							<fo:table-cell number-columns-spanned="2" text-align="left">
									<fo:block xsl:use-attribute-sets="summary-headings">
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="$row/cnpa"/>
											<xsl:with-param name="nxx" select="$row/cnxx"/>
											<xsl:with-param name="line" select="$row/cline"/>
										</xsl:call-template>
									</fo:block>      
							</fo:table-cell>
							<fo:table-cell number-columns-spanned="2">
									<fo:block><xsl:value-of select="' '"/></fo:block>
							</fo:table-cell>								
					</fo:table-row>
					<xsl:if test="$row/dccc != 0 and $row/dcyy != 0 and $row/dcmm != 0 and $row/dcdd != 0">	
						<fo:table-row keep-with-next="always">
								<fo:table-cell text-align="right" padding-right="4px">
									<fo:block xsl:use-attribute-sets="summary-headings">
											<fo:inline xsl:use-attribute-sets="category-label">Disconnect Date: </fo:inline>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell text-align="left">
									<fo:block xsl:use-attribute-sets="summary-headings">
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="$row/dccc"/>
											<xsl:with-param name="yy" select="$row/dcyy"/>
											<xsl:with-param name="mm" select="$row/dcmm"/>
											<xsl:with-param name="dd" select="$row/dcdd"/>
										</xsl:call-template>													
									</fo:block>								
								</fo:table-cell>	   					
						</fo:table-row>
					</xsl:if>	
					
					<fo:table-row keep-with-next="always">
							<fo:table-cell number-columns-spanned="3">
									<fo:block><xsl:value-of select="' '"/></fo:block>
							</fo:table-cell>						
					</fo:table-row>
					
					<fo:table-row keep-with-previous="always" keep-with-next="always">		
							<fo:table-cell text-align="left">
									<fo:block><xsl:value-of select="' '"/></fo:block>      
							</fo:table-cell>
							<fo:table-cell text-align="left">  						
									<fo:block xsl:use-attribute-sets="summary-headings">
											<xsl:value-of select="$row/fname" />
											<xsl:value-of select="$row/lname" />
									</fo:block>
							</fo:table-cell>														
					</fo:table-row>
					<xsl:if test="normalize-space($row/adln1)">
						<fo:table-row keep-with-previous="always" keep-with-next="always">		
								<fo:table-cell text-align="left">
										<fo:block><xsl:value-of select="' '"/></fo:block>      
								</fo:table-cell>
								<fo:table-cell text-align="left">  						
									<fo:block xsl:use-attribute-sets="summary-headings">
											<xsl:value-of select="$row/adln1" />
									</fo:block>
								</fo:table-cell>														
						</fo:table-row>					
					</xsl:if>						
					<xsl:if test="normalize-space($row/adln2)">
						<fo:table-row keep-with-previous="always" keep-with-next="always">		
								<fo:table-cell text-align="left">
										<fo:block><xsl:value-of select="' '"/></fo:block>      
								</fo:table-cell>
								<fo:table-cell text-align="left">  						
									<fo:block xsl:use-attribute-sets="summary-headings">
											<xsl:value-of select="$row/adln2" />
									</fo:block>
								</fo:table-cell>														
						</fo:table-row>					
					</xsl:if>
					<xsl:if test="normalize-space($row/adln3)">
						<fo:table-row keep-with-previous="always" keep-with-next="always">		
								<fo:table-cell text-align="left">
										<fo:block><xsl:value-of select="' '"/></fo:block>      
								</fo:table-cell>
								<fo:table-cell text-align="left">  						
									<fo:block xsl:use-attribute-sets="summary-headings">
											<xsl:value-of select="$row/adln3" />
									</fo:block>
								</fo:table-cell>														
						</fo:table-row>					
					</xsl:if>
					<fo:table-row keep-with-previous="always" keep-with-next="always">		
							<fo:table-cell text-align="left" >
									<fo:block><xsl:value-of select="' '"/></fo:block>      
							</fo:table-cell>
							<fo:table-cell text-align="left">  						
									<fo:block xsl:use-attribute-sets="summary-headings" space-after="12px">
											<xsl:value-of select="$row/adcity" />
											<xsl:value-of select="', '" />
											<xsl:value-of select="$row/adst" />
											<xsl:value-of select="' '" />
											<xsl:value-of select="substring($row/adzip, 1, 5)" />
											<xsl:if test="substring($row/adzip, 6, 4) != '0000'">
													<xsl:value-of select="'-'" />
													<xsl:value-of select="substring($row/adzip, 6, 4)" />
											</xsl:if>
									</fo:block>
							</fo:table-cell>														
					</fo:table-row>	
					<fo:table-row>
                    	<fo:table-cell text-align="left"><fo:block><xsl:value-of select="' '"/></fo:block></fo:table-cell>		
                    </fo:table-row>					
			</fo:table-body>																										
		</fo:table>
	</xsl:template>	
	<xsl:template name="payment">	
	<xsl:param name="row" select="/all_results/results[@name = 'sel']/row[position() = 1]"></xsl:param>
		<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
		<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
		<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
		<fo:table font-size="10pt" space-before="10px">
		
				<fo:table-column column-width="3in" />
				<fo:table-column column-width="3in" />
				<fo:table-body>							
					<fo:table-row  space-before="8px">				
						<fo:table-cell text-align="left" padding-right="14px">
							<fo:block xsl:use-attribute-sets="component-2">
								<xsl:value-of select="'Payment Amount'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="left" >
							<fo:block xsl:use-attribute-sets="component-2">
								<xsl:value-of select="format-number($row/payamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
							</fo:block>			
						</fo:table-cell>
					</fo:table-row>									
					<fo:table-row  space-before="8px">				
						<fo:table-cell text-align="left" padding-right="14px">
							<fo:block xsl:use-attribute-sets="component-2">
								<xsl:value-of select="'Payment Date'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="component-2">
								<xsl:call-template name="date1parm-db">
									<xsl:with-param name="date" select="$row/paytime"/>
								</xsl:call-template>	
							</fo:block>			
						</fo:table-cell>	
					</fo:table-row>
					<!--   fo:table-row  space-before="8px">
					<fo:table-cell>
					<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
					</fo:table-cell>	
					</fo:table-row -->	                                                            					

					
					<fo:table-row  space-before="8px">				
						<fo:table-cell text-align="left" padding-right="14px">
							<fo:block xsl:use-attribute-sets="component-2">
								<xsl:value-of select="'Payment Type'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$row/paytype" />
							</fo:block>							
						</fo:table-cell>	
					</fo:table-row>
					<xsl:if test="normalize-space($row/note)">
					<fo:table-row  space-before="8px">				
						<fo:table-cell text-align="left" padding-right="14px">
							<fo:block xsl:use-attribute-sets="component-2">
								<xsl:value-of select="'Payment Note'"/>
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell text-align="left">
							<fo:block xsl:use-attribute-sets="component-2">
									<xsl:value-of select="$row/note" />
							</fo:block>							
						</fo:table-cell>	
					</fo:table-row>					
					</xsl:if>			
			</fo:table-body>																										
		</fo:table>
    </xsl:template>
	<xsl:template name="agent_note">	
	<xsl:param name="row" select="/all_results/results[@name = 'sel']/row[position() = 1]"></xsl:param>
	<xsl:variable name="agentsnote" select="concat('Payment made to Agent ', $row/agbus, ' - ', $row/agcd, ' (User: ', $row/username), ').'" />
		<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
		<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
		<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
		<fo:block xsl:use-attribute-sets="component-2"><xsl:value-of select="' '"/></fo:block>
		<fo:block xsl:use-attribute-sets="smallprint"><xsl:value-of select="$agentsnote" /></fo:block>		
    </xsl:template>    
</xsl:stylesheet>
