<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: arhistory.xsl,v 1.12 2018-09-04 18:03:03 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:saxon="http://saxon.sf.net/"
				xmlns:util="java:com.psasoft.reports.util.ReportUtilities"
				exclude-result-prefixes="java" 
				extension-element-prefixes="saxon"
				version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Account Receivable History'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set"/>
		<xsl:call-template name="make-body"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acct']/row"/>
	</xsl:call-template>
	<fo:block xsl:use-attribute-sets="category-label">
		Account Aging
	</fo:block>
	<xsl:variable name="billmonth" select="substring(/all_results/results[@name = 'acct']/row/cbdate, 5, 2)" />
	<xsl:variable name="cycle" select="/all_results/results[@name = 'acct']/row/cycle" />
	<xsl:variable name="age" select="util:convertToAgingValues($cycle, $billmonth, /all_results/results[@name = 'sum']/row/*)" />
	<fo:table table-layout="fixed" width="100%" space-before="8px">
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Current</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>30 Days</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>60 Days</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>90 Days</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Final Balance</fo:block>
						</fo:table-cell>						
					</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/curr_bill, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/day30, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>				
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/day60, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/day90, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number($age/age/due, '$ ##,###,##0.00;$ -#,###,##0.00')"/>							
							</fo:block>			
						</fo:table-cell>						
				</fo:table-row>					
			</fo:table-body>
		</fo:table> 	
	<xsl:if test="/all_results/results[@name = 'acct']/row/wtobal > 0">
			<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
				Write Off Summary
			</fo:block>	
			<fo:table table-layout="fixed" width="100%" space-before="8px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />		
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Write Off Date</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Write Off Amount</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Payment Amount</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Last Pay Date</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Last Payment Amount</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Write Off Adjustments</fo:block>
								</fo:table-cell>														
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Write Off Balance</fo:block>
								</fo:table-cell>
							</fo:table-row>
					</fo:table-header>					
					<fo:table-body>
						<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="/all_results/results[@name = 'acct']/row/wtocc"/>
											<xsl:with-param name="yy" select="/all_results/results[@name = 'acct']/row/wtoyy"/>
											<xsl:with-param name="mm" select="/all_results/results[@name = 'acct']/row/wtomm"/>
											<xsl:with-param name="dd" select="/all_results/results[@name = 'acct']/row/wtodd"/>
										</xsl:call-template>				
									</fo:block>										
								</fo:table-cell>		
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number(/all_results/results[@name = 'acct']/row/wtoamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number(/all_results/results[@name = 'acct']/row/wtopay, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:if test="/all_results/results[@name = 'acct']/row/wtpyy > 0">
											<xsl:call-template name="date4parm">
												<xsl:with-param name="cc" select="/all_results/results[@name = 'acct']/row/wtpcc"/>
												<xsl:with-param name="yy" select="/all_results/results[@name = 'acct']/row/wtpyy"/>
												<xsl:with-param name="mm" select="/all_results/results[@name = 'acct']/row/wtpmm"/>
												<xsl:with-param name="dd" select="/all_results/results[@name = 'acct']/row/wtpdd"/>
											</xsl:call-template>									
										</xsl:if>
									</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number(/all_results/results[@name = 'acct']/row/wtolpy, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number(/all_results/results[@name = 'acct']/row/wtoadj, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>
								</fo:table-cell>																	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="format-number(/all_results/results[@name = 'acct']/row/wtobal, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>
								</fo:table-cell>									
						</fo:table-row>		
				</fo:table-body>
		</fo:table>  		
	</xsl:if>
	<xsl:if test="/all_results/results[@name = 'detail']/row" >
		<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
			Monthly Summary
		</fo:block>	
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />		
			<fo:table-header>
					<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Month</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Bill Amount</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Adjustment Amount</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Payment Amount</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Payment Date</fo:block>
							</fo:table-cell>
						</fo:table-row>
				</fo:table-header>					
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'detail']/row"> 
							<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:choose>
												<xsl:when test="./month = 1">
													<xsl:value-of select="'January'"/>
												</xsl:when>
												<xsl:when test="./month = 2">
													<xsl:value-of select="'February'"/>
												</xsl:when>											
												<xsl:when test="./month = 3">
													<xsl:value-of select="'March'"/>
												</xsl:when>											
												<xsl:when test="./month = 4">
													<xsl:value-of select="'April'"/>
												</xsl:when>											
												<xsl:when test="./month = 5">
													<xsl:value-of select="'May'"/>
												</xsl:when>											
												<xsl:when test="./month = 6">
													<xsl:value-of select="'June'"/>
												</xsl:when>			
												<xsl:when test="./month = 7">
													<xsl:value-of select="'July'"/>
												</xsl:when>
												<xsl:when test="./month = 8">
													<xsl:value-of select="'August'"/>
												</xsl:when>											
												<xsl:when test="./month = 9">
													<xsl:value-of select="'September'"/>
												</xsl:when>											
												<xsl:when test="./month = 10">
													<xsl:value-of select="'October'"/>
												</xsl:when>											
												<xsl:when test="./month = 11">
													<xsl:value-of select="'November'"/>
												</xsl:when>											
												<xsl:when test="./month = 12">
													<xsl:value-of select="'December'"/>
												</xsl:when>											
												<xsl:otherwise>
													<xsl:value-of select="./month"/>
												</xsl:otherwise>
											</xsl:choose>
										</fo:block>
									</fo:table-cell>				
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./bill, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./adj, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
										</fo:block>
									</fo:table-cell>		
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./pay, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
										</fo:block>
									</fo:table-cell>								
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:if test="./paydate != 20000000">
												<xsl:call-template name="date1parm">
													<xsl:with-param name="date" select="./paydate"/>
												</xsl:call-template>								
											</xsl:if>
										</fo:block>
									</fo:table-cell>																											
							</fo:table-row>		
					 </xsl:for-each>
				</fo:table-body>
		</fo:table> 
	</xsl:if> 			
	<xsl:if test="/all_results/results[@name = 'notice']/row">
		<fo:block xsl:use-attribute-sets="category-label" space-before="15px">
			Notices Sent
		</fo:block>	
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.25in" />
			<fo:table-column column-width="2.0in" />	
			<fo:table-header>
					<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Date Sent</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Sent At Level</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Notice Type</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Notice Description</fo:block>
							</fo:table-cell>
						</fo:table-row>
				</fo:table-header>					
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'notice']/row"> 
							<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="./lsntcc"/>
											<xsl:with-param name="yy" select="./lsntyy"/>
											<xsl:with-param name="mm" select="./lsntmm"/>
											<xsl:with-param name="dd" select="./lsntdd"/>
										</xsl:call-template>										
									</fo:block>
								</fo:table-cell>														
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>	
										<xsl:choose>
											<xsl:when test="./balage = 1">
												<xsl:value-of select="'30 Days'"/>
											</xsl:when>
											<xsl:when test="./balage = 2">
												<xsl:value-of select="'60 Days'"/>
											</xsl:when>											
											<xsl:when test="./balage = 3">
												<xsl:value-of select="'90 Days'"/>
											</xsl:when>											
											<xsl:when test="./balage = 4">
												<xsl:value-of select="'Over 90 Days'"/>
											</xsl:when>											
											<xsl:otherwise>
												<xsl:value-of select="./balage"/>
											</xsl:otherwise>
										</xsl:choose>										
										</fo:block>
									</fo:table-cell>		
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./ntcnam"/>
									</fo:block>
								</fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
									<fo:block>
										<xsl:value-of select="./ntccmt"/>
									</fo:block>
								</fo:table-cell>										
							</fo:table-row>		
					 </xsl:for-each>
				</fo:table-body>
		</fo:table>  			
	</xsl:if>									
</xsl:template>

</xsl:stylesheet>






