<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: ccresponse.xsl,v 1.7 2018-05-21 17:34:51 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Credit Card Response History'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acct']/row"/>
	</xsl:call-template>
	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'resp']/row">	
			<fo:table table-layout="fixed" space-before="8px">
				<fo:table-column column-width="0.65in" />
				<fo:table-column column-width="0.65in" />
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width="0.50in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="0.50in" />
				<!-- <fo:table-column column-width="1.00in" /> -->
				<!-- <fo:table-column column-width="0.50in" /> -->
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width="1.75in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Date</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Trans Type</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Trans #</fo:block>
								</fo:table-cell>								
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>By</fo:block>
								</fo:table-cell>														
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Cardholder Name</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Card Type</fo:block>
								</fo:table-cell>
								<!-- <fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Card Type</fo:block>
								</fo:table-cell> -->
								<!-- <fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Expire Date</fo:block>
								</fo:table-cell> -->
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Charge Amount</fo:block>
								</fo:table-cell>								
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Response</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Trace ID</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Auth Code</fo:block>
								</fo:table-cell>
							</fo:table-row>
					</fo:table-header>					
					<fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'resp']/row">    
								<xsl:choose>
									<xsl:when test="upper-case(rsptext) != 'APPROVED' and upper-case(rsptext) != 'SUCCESS' and rsptext != 'This transaction has been approved.'">
										<fo:table-row background-color="#CCCC66">
												<xsl:call-template name="ccrow">
													<xsl:with-param name="row" select="."/>
												</xsl:call-template>		
										</fo:table-row>		
									</xsl:when>
									<xsl:otherwise>
										<fo:table-row background-color="#FFFFFF">
												<xsl:call-template name="ccrow">
													<xsl:with-param name="row" select="."/>
												</xsl:call-template>		
										</fo:table-row>		
									</xsl:otherwise>
								</xsl:choose>
						 </xsl:for-each>
						</fo:table-body>
				</fo:table>    
		</xsl:when>
		<xsl:otherwise>
				<fo:block space-before="16px">No Credit Card History Found</fo:block>
		</xsl:otherwise>
	</xsl:choose>		
</xsl:template>

<xsl:template name="ccrow">
		<xsl:param name="row" />
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/transdate"/>
				<xsl:value-of select="' '"/>
				<xsl:value-of select="$row/transtime"/>
			</fo:block>
		</fo:table-cell>	
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/authtype"/>
				<xsl:value-of select="' / '"/>
				<xsl:value-of select="$row/transtype"/>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:choose>
					<xsl:when test="$row/invcno != '' and $row/invcno != 0">
						<xsl:value-of select="$row/invcno"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' '"/>
					</xsl:otherwise>
				</xsl:choose>						
			</fo:block>
		</fo:table-cell>		
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:choose>
					<xsl:when test="substring($row/transdesc, 1, 3) = 'Web'">
						<xsl:value-of select="'Web'"/>
					</xsl:when>
					<xsl:when test="substring($row/transdesc, 1, 9) = 'Auto'">
						<xsl:value-of select="'AutoPay'"/>
					</xsl:when>					
					<xsl:otherwise>
						<xsl:value-of select="$row/chrgby"/>
					</xsl:otherwise>
				</xsl:choose>						
			</fo:block>
		</fo:table-cell>		
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
			<fo:block>
				<xsl:value-of select="$row/ccfname"/>
				<xsl:value-of select="' '"/>
				<xsl:value-of select="$row/cclname"/>									
			</fo:block>
		</fo:table-cell>										
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/cctype"/>
			</fo:block>
		</fo:table-cell>
		<!-- <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:choose>
					<xsl:when test="$row/authtype = 'EFT'">
						<xsl:value-of select="'***************'"/>
					</xsl:when>
					<xsl:when test="$row/cctype = 'AMER'">
						<xsl:value-of select="'****-******-*'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'****-****-****-'"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:value-of select="$row/ccnumb"/>
			</fo:block>
		</fo:table-cell> -->
		<!-- <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:if test="$row/authtype != 'EFT'">
						<xsl:value-of select="format-number($row/ccexpmm, '#0')"/>
						<xsl:value-of select="'/'"/>
						<xsl:choose>
							<xsl:when test="string-length($row/ccexpyy) = 2">
									<xsl:value-of select="'20'"/>
									<xsl:value-of select="format-number($row/ccexpyy, '00')"/>					
							</xsl:when>
							<xsl:otherwise>
									<xsl:value-of select="format-number($row/ccexpyy, '0000')"/>
							</xsl:otherwise>
						</xsl:choose>
				</xsl:if>
			</fo:block>
		</fo:table-cell> -->
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
			<xsl:choose>
				<xsl:when test="valid = '1' or valid = 'A'">
					<xsl:choose>
						<xsl:when test="normalize-space(./ccamt) = ''">
							<fo:block font-size="6.5pt" font-weight="bold" color="336666" font-style="italic">
								<xsl:value-of select="'&lt;'" />
								<xsl:value-of select="./amtraw" />
								<xsl:value-of select="'&gt;'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="./ccamt &lt; 0">
							<fo:block font-size="6.5pt" font-weight="bold" color="#FF0000">
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block font-size="6.5pt">
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="normalize-space(./ccamt) = ''">
							<fo:block font-size="6.5pt" font-weight="bold" color="336666" font-style="italic">
								<xsl:value-of select="'&lt;'" />
								<xsl:value-of select="./amtraw" />
								<xsl:value-of select="'&gt;'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="./ccamt &lt; 0">
							<fo:block font-size="6.5pt" font-weight="bold" color="#FF0000" font-style="italic">
								<xsl:value-of select="'&lt;'" />
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
								<xsl:value-of select="'&gt;'" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block font-size="6.5pt" font-style="italic">
								<xsl:value-of select="'&lt;'" />
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
								<xsl:value-of select="'&gt;'" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</fo:table-cell>				
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/rsptext"/>
			</fo:block>
		</fo:table-cell>						
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/rsptrace"/>
				<xsl:value-of select="' '"/>
			</fo:block>
		</fo:table-cell>						
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/authcode"/>
				<xsl:value-of select="' '"/>
			</fo:block>
		</fo:table-cell>		
</xsl:template>		

</xsl:stylesheet>






