<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
			    xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:saxon="http://saxon.sf.net/" 
				xmlns:java="http://xml.apache.org/xslt/java"
				extension-element-prefixes="saxon" 
			    exclude-result-prefixes="java"
				version="2.0">

	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	
	<xsl:variable name="rcvprice" select="0" saxon:assignable="yes" />
	<xsl:variable name="rtnprice" select="0" saxon:assignable="yes" />
	<xsl:variable name="netprice" select="0" saxon:assignable="yes" />
	<xsl:variable name="totalsold" select="0" saxon:assignable="yes" />
	<xsl:variable name="totalrcvprice" select="0" saxon:assignable="yes" />
	<xsl:variable name="totalrtn" select="0" saxon:assignable="yes" />
	<xsl:variable name="totalrtnprice" select="0" saxon:assignable="yes" />
	<xsl:variable name="totalnet" select="0" saxon:assignable="yes" />
	<xsl:variable name="totalnetprice" select="0" saxon:assignable="yes" />
	
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="concat('Cost of Goods Sold by Item ', $sold_date[1], ' to ', $sold_date[2])" />

	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>

	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="/all_results/results[@name = 'detail']/row">
				<xsl:call-template name="report">
					<xsl:with-param name="results" select="/all_results/results[@name = 'detail']" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="/all_results/results[@name = 'detail2']/row">
				<xsl:call-template name="report">
					<xsl:with-param name="results" select="/all_results/results[@name = 'detail2']" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>Sold information for selected date range not found</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="report">
		<xsl:param name="results" />
		
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.50in" />
			<fo:table-column column-width="3.00in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="0.75in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="2">
						<fo:block>Item</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="2">
						<fo:block>Sold</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="2">
						<fo:block>Returned</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="2">
						<fo:block>Net</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Description</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Count</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cost</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Count</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cost</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Count</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Cost</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each-group select="$results/row" group-by="unitid">
					<xsl:variable name="unitid" select="current-group()[position() = 1]/unitid" />
					<saxon:assign name="rcvprice" select="0" />
					<saxon:assign name="rtnprice" select="0" />
					<saxon:assign name="netprice" select="0" />
					<xsl:variable name="cost" select="/all_results/results[@name = 'costprices']/row[unitid = $unitid]/unitamt" />
					<xsl:variable name="sold" select="sum($results/row[unitid = $unitid]/sold)" />
					<xsl:variable name="rtn" select="sum($results/row[unitid = $unitid]/returned)" />
					<xsl:variable name="net" select="sum($results/row[unitid = $unitid]/netsold)" />

					<xsl:for-each select="$results/row[unitid = $unitid]">
						<xsl:choose>
						<xsl:when test="./sold &gt; 0 and ./rcvprice &gt; 0">
							<saxon:assign name="rcvprice" select="$rcvprice + ./rcvprice" />
						</xsl:when>
						<xsl:when test="./sold &gt; 0 and exists($cost)">
							<saxon:assign name="rcvprice" select="$rcvprice + $cost" />
						</xsl:when>
						</xsl:choose>
						<xsl:choose>
						<xsl:when test="./returned &gt; 0 and ./rtnprice &gt; 0">
							<saxon:assign name="rtnprice" select="$rtnprice + ./rtnprice" />
						</xsl:when>
						<xsl:when test="./returned &gt; 0 and ./rcvprice &gt; 0">
							<saxon:assign name="rtnprice" select="$rtnprice + ./rcvprice" />
						</xsl:when>
						<xsl:when test="./returned &gt; 0 and exists($cost)">
							<saxon:assign name="rtnprice" select="$rtnprice + $cost" />
						</xsl:when>
						</xsl:choose>


					</xsl:for-each>
					<saxon:assign name="netprice" select="$rcvprice - $rtnprice" />
					<saxon:assign name="totalrcvprice" select="$totalrcvprice + $rcvprice" />
					<saxon:assign name="totalrtnprice" select="$totalrtnprice + $rtnprice" />
					<saxon:assign name="totalnetprice" select="$totalnetprice + $netprice" />
					<saxon:assign name="totalsold" select="$totalsold + $sold" />
					<saxon:assign name="totalrtn" select="$totalrtn + $rtn" />
					<saxon:assign name="totalnet" select="$totalnet + $net" />

					<xsl:call-template name="detailrow">
						<xsl:with-param name="unitcode" select="current-group()[position() = 1]//unitcode" />
						<xsl:with-param name="externalcd" select="current-group()[position() = 1]/externalcd" />
						<xsl:with-param name="itemdesc" select="current-group()[position() = 1]/itemdesc" />
						<xsl:with-param name="sold" select="$sold" />
						<xsl:with-param name="rtn" select="$rtn" />
						<xsl:with-param name="net" select="$net" />
					</xsl:call-template>
				</xsl:for-each-group>

				<xsl:call-template name="totalrow" />
			</fo:table-body>
		</fo:table>	
	</xsl:template>

	<xsl:template name="detailrow">
		<xsl:param name="unitcode" />
		<xsl:param name="externalcd" />
		<xsl:param name="itemdesc" />
		<xsl:param name="sold" />
		<xsl:param name="rtn" />
		<xsl:param name="net" />
		
		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<xsl:choose>
					<xsl:when test="$unitcode != ''">
						<fo:block>
							<xsl:value-of select="$unitcode" />
						</fo:block>
					</xsl:when>
					<xsl:otherwise>
						<fo:block>
							<xsl:value-of select="$externalcd" />
						</fo:block>
					</xsl:otherwise>
				</xsl:choose>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
					<xsl:value-of select="$itemdesc" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($sold, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($rcvprice, '##,###,##0.00')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($rtn, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($rtnprice, '##,###,##0.00')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($net, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($netprice, '##,###,##0.00')" />
				</fo:block>
			</fo:table-cell>
		</fo:table-row>	
	</xsl:template>
	
	<xsl:template name="totalrow">
		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center" number-columns-spanned="2">
				<fo:block>
					<xsl:value-of select="'Totals'" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($totalsold, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($totalrcvprice, '##,###,##0.00')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($totalrtn, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($totalrtnprice, '##,###,##0.00')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($totalnet, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($totalnetprice, '##,###,##0.00')" />
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
</xsl:stylesheet>