<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:exsl="http://exslt.org/functions" 
								xmlns:img="java:com.psasoft.util.ImageUtilities"
								extension-element-prefixes="exsl" 
								exclude-result-prefixes="java" version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/>  

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
<xsl:variable name="title" select="' '" />

<xsl:template match="/">
		<fo:root>
				<xsl:call-template name="make-layout-master-small-margin" />
				<xsl:call-template name="make-body" />
		</fo:root>
</xsl:template>
<xsl:template name="body_process">
		<xsl:variable name="rowcount" select="'1'" />
		<xsl:variable name="acct" select="/all_results/results[@name = 'acct']/row" />
		<xsl:variable name="serv" select="/all_results/results[@name = 'serv']/row" />
		<xsl:variable name="logo" select="img:getImageBase64Encoded('/images/northwest_logo_new.jpg')"/>
		<fo:block-container absolute-position="fixed" left=".5in" top=".25in">
				<fo:block>
					<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="1.75in"/>
				</fo:block>
		</fo:block-container>
		<fo:block-container  absolute-position="fixed" width="6in" start-indent="2.5in" top=".25in" text-align="center">
				<fo:block xsl:use-attribute-sets="report-title" font-size="16pt" font-weight="bold"><fo:inline color="lightblue" background-color="black" padding="5px">Service Commitment</fo:inline></fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" left=".5in" top="1.25in" width="3.75in">
				<xsl:call-template name="leftcol">
						<xsl:with-param name="acct" select="$acct"/>
						<xsl:with-param name="serv" select="$serv"/>
				</xsl:call-template>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" left="4.25in" top="1.25in" width="3.75in">
				<xsl:call-template name="rightcol">
						<xsl:with-param name="acct" select="$acct"/>
						<xsl:with-param name="serv" select="$serv"/>
				</xsl:call-template>				
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" left=".5in" top="6.5in" text-align="left">
				<fo:block xsl:use-attribute-sets="smallprint-8" font-weight="bold" color="black" space-before=".1in" space-after="0in">You have contracted to have NWMC provide you with service for the term specified on this contract.   At the end of your service commitment, the term of this contract shall be deemed automatically renewed on the same terms and conditions and shall continue until terminated by either party.  </fo:block>
				<fo:block xsl:use-attribute-sets="smallprint-8" font-weight="bold" color="black" space-before=".1in" space-after="0in">You may terminate your service by contacting NWMC.  If you terminate service before the completion of any service commitment, you agree to pay the early termination charge to NWMC for liquidated damages in the amount of $10.00 per remaining month of the contract, for a maximum charge of $120.00.</fo:block>
				<fo:block xsl:use-attribute-sets="smallprint-8" font-weight="bold" color="black" space-before=".1in" space-after="0in">NWMC requires that you maintain a physical address within Atchison, Gentry, Holt, Nodaway and Worth counties in order to continue service.  NWMC reserves the right at any time for any reason, including excessive usage outside NWMC Local Coverage Area, to discontinue service provided, or change customers<fo:character character="&#8217;" /> plan and features, with 30-day notice to customer.</fo:block>
				<fo:block xsl:use-attribute-sets="smallprint-8" font-weight="bold" color="black" space-before=".1in" space-after="0in">If signing on behalf of an entity, I represent that I am a duly authorized representative of the entity shown under <fo:character character="&#8220;" />Billing Name<fo:character character="&#8221;" />.  If I am representing a corporation, I acknowledge that the execution of this document has been authorized by all necessary corporate action.</fo:block>
				<fo:block xsl:use-attribute-sets="smallprint-8" font-weight="bold" color="black" space-before=".1in" space-after="0in">I ACKNOWLEDGE THAT I HAVE READ AND UNDERSTAND ALL OF THE TERMS OF THIS CONTRACT AND AGREE TO BE BOUND THEREBY.</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" left=".5in" top="8in" text-align="left">
				<fo:table table-layout="fixed" keep-together="always">
						<fo:table-column column-width="3.75in"/>
						<fo:table-column column-width="3.75in"/>
						<fo:table-body>
								<fo:table-row height="1.5in">
										<fo:table-cell display-align="after">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black">Subscriber Signature:  
											</fo:block>
										</fo:table-cell>
										<fo:table-cell display-align="after">
											<fo:block xsl:use-attribute-sets="summary-cells" border-bottom-style="solid" border-bottom-width="1px">
											<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="auto" content-height="1in"/>
											</fo:block>
										</fo:table-cell>
								</fo:table-row>										
								<fo:table-row>
										<fo:table-cell padding-before="0.1in">
											<fo:block xsl:use-attribute-sets="summary-cells">
													<fo:inline color="black"><xsl:value-of select="'Printed Name: '"/></fo:inline>
													<xsl:value-of select="$acct/fname"/>
													<xsl:value-of select="' '"/>
													<xsl:value-of select="$acct/lname"/>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell padding-before="0.1in">
											<fo:block xsl:use-attribute-sets="summary-cells">
													<fo:inline color="black"><xsl:value-of select="'Title: '"/></fo:inline>
											</fo:block>
										</fo:table-cell>
								</fo:table-row>										
								<fo:table-row>
										<fo:table-cell padding-before="0.1in">
											<fo:block xsl:use-attribute-sets="summary-cells">
													<fo:inline color="black"><xsl:value-of select="'Sales Manager Authorization: '"/></fo:inline>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell padding-before="0.1in">
											<fo:block xsl:use-attribute-sets="summary-cells">
													<fo:inline color="black"><xsl:value-of select="'Date: '"/></fo:inline>
													<xsl:value-of select="$serv/ctcstrdte"/>											
											</fo:block>
										</fo:table-cell>								
								</fo:table-row>   
						</fo:table-body>
				</fo:table>				
		</fo:block-container>				

		<fo:block break-before="page" />
		<xsl:call-template name="backpage"/> 
</xsl:template>

<xsl:template name="leftcol">
<xsl:param name="acct" />
<xsl:param name="serv" />
		<fo:table table-layout="fixed" keep-together="always">
				<fo:table-column column-width="3.5in" />
				<fo:table-body>
						<fo:table-row>
								<fo:table-cell text-align="left">
										<fo:block xsl:use-attribute-sets="summary-headings" color="lightblue" background-color="black">
												<xsl:value-of select="'Account Information'" />
										</fo:block>
								</fo:table-cell>
						</fo:table-row>				
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Activation Date:	'" /></fo:inline>
											<xsl:value-of select="$serv/ctcstrdte"/>
									</fo:block>	
								</fo:table-cell>
						</fo:table-row>				
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Agent/Sales Person:	'" /></fo:inline>
											<xsl:value-of select="$serv/agfsnm"/>
											<xsl:value-of select="' '"/>
											<xsl:value-of select="$serv/aglsnm"/>
									</fo:block>	
								</fo:table-cell>
						</fo:table-row>						
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Account Number:	'" /></fo:inline>
											<xsl:value-of select="format-number($acct/cycle, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number($acct/bacct, '0000000')" />
									</fo:block>	
								</fo:table-cell>
						</fo:table-row>	
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
										<fo:inline color="black"><xsl:value-of select="'Mobile Number (MDN):	'" /></fo:inline>
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="$serv/cnpa"/>
											<xsl:with-param name="nxx" select="$serv/cnxx"/>
											<xsl:with-param name="line" select="$serv/cline"/>
										</xsl:call-template>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>		
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
										<fo:inline color="black"><xsl:value-of select="'MIN:	'" /></fo:inline>
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="$serv/xnpa"/>
											<xsl:with-param name="nxx" select="$serv/xnxx"/>
											<xsl:with-param name="line" select="$serv/xline"/>
										</xsl:call-template>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>									
						<fo:table-row>
								<fo:table-cell text-align="left">
										<fo:block xsl:use-attribute-sets="summary-headings" color="lightblue" background-color="black">
												<xsl:value-of select="'Customer Billing Information'" />
										</fo:block>
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
										<fo:inline color="black"><xsl:value-of select="'Account Name:	'" /></fo:inline>
										<xsl:value-of select="$acct/fname"/>
										<xsl:value-of select="' '"/>
										<xsl:value-of select="$acct/lname"/>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>                   		
						<fo:table-row>
								<fo:table-cell>
									<xsl:if test="$acct/bdisc">
										<fo:block xsl:use-attribute-sets="summary-cells">
											<xsl:value-of select="$serv/bdisc"/>
										</fo:block>
									</xsl:if>
									<xsl:if test="$acct/adln1">
										<fo:block xsl:use-attribute-sets="summary-cells">
											<xsl:value-of select="$acct/adln1"/>
										</fo:block>
									</xsl:if>												
									<xsl:if test="$acct/adln2">
										<fo:block xsl:use-attribute-sets="summary-cells">
											<xsl:value-of select="$acct/adln2"/>
										</fo:block>
									</xsl:if>												
									<xsl:if test="$acct/adln3">
										<fo:block xsl:use-attribute-sets="summary-cells">
											<xsl:value-of select="$acct/adln3"/>
										</fo:block>
									</xsl:if>												
									<fo:block xsl:use-attribute-sets="summary-cells">
										<fo:inline>
											<xsl:value-of select="$acct/adcity"/>
											<xsl:value-of select="', '"/>
											<xsl:value-of select="$acct/adst"/>
											<xsl:value-of select="' '"/>
											<xsl:value-of select="substring($acct/adzip, 1, 5)"/>
											<xsl:if test="substring($acct/adzip, 6, 4) != '0000'" >
												<xsl:value-of select="'-'"/>
												<xsl:value-of select="substring($acct/adzip, 6, 4)"/>
											</xsl:if>
										</fo:inline>
									</fo:block>                   		
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
										<fo:inline color="black"><xsl:value-of select="'Business Phone:	'" /></fo:inline>
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="$acct/ctnpa2"/>
											<xsl:with-param name="nxx" select="$acct/ctnxx2"/>
											<xsl:with-param name="line" select="$acct/ctlin2"/>
										</xsl:call-template>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>	
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
										<fo:inline color="black"><xsl:value-of select="'Home Phone:	'" /></fo:inline>
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="$acct/ctnpa"/>
											<xsl:with-param name="nxx" select="$acct/ctnxx"/>
											<xsl:with-param name="line" select="$acct/ctline"/>
										</xsl:call-template>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>						
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells" color="black">
											<xsl:value-of select="'Authorized Users:	'" />
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<xsl:value-of select="$acct/aunam1"/>
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<xsl:value-of select="$acct/aunam2"/>
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<xsl:value-of select="$acct/aunam3"/>
									</fo:block>									
								</fo:table-cell>
						</fo:table-row>				
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Email:	'" /></fo:inline>
											<xsl:value-of select="$acct/emladr"/>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>							
						<fo:table-row>
								<fo:table-cell text-align="left">
										<fo:block xsl:use-attribute-sets="summary-headings" color="lightblue" background-color="black">
												<xsl:value-of select="'Identification Verification'" />
										</fo:block>
								</fo:table-cell>
						</fo:table-row>														
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Drivers License #:	'" /></fo:inline>
											<xsl:value-of select="$acct/driverslis"/>
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Social Security #:	'" /></fo:inline>
											<xsl:value-of select="substring($acct/ssn, 1, 3)" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="substring($acct/ssn, 4, 2)" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="substring($acct/ssn, 6, 4)" />
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-cells">
										<fo:inline color="black"><xsl:value-of select="'Date of Birth:	'" /></fo:inline>
										<xsl:call-template name="date4parm">
											<xsl:with-param name="cc" select="$acct/btcc"/>
											<xsl:with-param name="yy" select="$acct/btyy"/>
											<xsl:with-param name="mm" select="$acct/btmm"/>
											<xsl:with-param name="dd" select="$acct/btdd"/>
										</xsl:call-template>		
									</fo:block>										
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
								<fo:table-cell text-align="left">
										<fo:block xsl:use-attribute-sets="summary-headings" color="lightblue" background-color="black">
												<xsl:value-of select="'Credit Information'" />
										</fo:block>
								</fo:table-cell>
						</fo:table-row>		
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Credit Check #:	'" /></fo:inline>
											<xsl:value-of select="' '"/>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Deposit Amount:	'" /></fo:inline>
											<xsl:value-of select="format-number($serv/depamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>						
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Tax Exempt:	'" /></fo:inline>
											<xsl:choose>
											<xsl:when test="$serv/txexcd = 'N'">
													<xsl:value-of select="'Take All Taxes'"/>
											</xsl:when>
											<xsl:when test="$serv/txexcd = 'Y'">
													<xsl:value-of select="'Tax Exempt'"/>
											</xsl:when>
											<xsl:when test="$serv/txexcd = 'A'">
													<xsl:value-of select="'Federal Tax Exempt'"/>
											</xsl:when>
											<xsl:when test="$serv/txexcd = 'B'">
													<xsl:value-of select="'State/City/County Tax Exempt'"/>
											</xsl:when>
											<xsl:when test="$serv/txexcd = 'C'">
													<xsl:value-of select="'County Tax Exempt'"/>
											</xsl:when>
											<xsl:when test="$serv/txexcd = 'D'">
													<xsl:value-of select="'City Tax Exempt'"/>
											</xsl:when>
											<xsl:when test="$serv/txexcd = 'E'">
													<xsl:value-of select="'County/City Tax Exempt'"/>
											</xsl:when>											
											<xsl:otherwise>
													<xsl:value-of select="$serv/txexcd"/>
											</xsl:otherwise>
											</xsl:choose>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>						
				</fo:table-body>
		</fo:table>
</xsl:template>

<xsl:template name="rightcol">
<xsl:param name="acct" />
<xsl:param name="serv" />
		<fo:table table-layout="fixed" keep-together="always">
				<fo:table-column column-width="3.5in" />
				<fo:table-body>
						<fo:table-row>
								<fo:table-cell>
										<fo:block xsl:use-attribute-sets="summary-headings" color="lightblue" background-color="black">
												<xsl:value-of select="'Mobile Equipment Information'" />
										</fo:block>
								</fo:table-cell>
						</fo:table-row>		
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'ESN:	'" /></fo:inline>
											<xsl:value-of select="' '" />
											<xsl:if test="$serv/esn &gt; 0">
													<xsl:value-of select="format-number($serv/esn, '00000000000')" />
											</xsl:if>
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'MEID:	'" /></fo:inline>
											<xsl:value-of select="' '" />
											<xsl:if test="normalize-space($serv/meid) > ''">
													<xsl:value-of select="$serv/meid" />
											</xsl:if>											
									</fo:block>									
								</fo:table-cell>
						</fo:table-row>	
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Manufacturer/Model:	'" /></fo:inline>
											<xsl:value-of select="$serv/mfgmdl" />											
											<xsl:value-of select="' / '" />
											<xsl:value-of select="$serv/eqpdsc" />											
									</fo:block>
								</fo:table-cell>
						</fo:table-row>						
						<fo:table-row>
								<fo:table-cell text-align="left">
										<fo:block xsl:use-attribute-sets="summary-headings" color="lightblue" background-color="black">
												<xsl:value-of select="'Service Committment'" />
										</fo:block>
								</fo:table-cell>
						</fo:table-row>		
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Contract Length:	'" /></fo:inline>
											<xsl:value-of select="format-number($serv/ctclen, '##0')" />
											<xsl:value-of select="' Month(s)'" />
									</fo:block>								
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'Contract End Date:	'" /></fo:inline>
											<xsl:call-template name="date4parm">
												<xsl:with-param name="cc" select="$serv/scexcc"/>
												<xsl:with-param name="yy" select="$serv/scexyy"/>
												<xsl:with-param name="mm" select="$serv/scexmm"/>
												<xsl:with-param name="dd" select="$serv/scexdd"/>
											</xsl:call-template>
									</fo:block>
								</fo:table-cell>
						</fo:table-row>				
						<fo:table-row>
								<fo:table-cell>
									<fo:block xsl:use-attribute-sets="summary-cells">
											<fo:inline color="black"><xsl:value-of select="'EARLY TERMINATION CHARGE:	'" /></fo:inline>
											<xsl:value-of select="format-number($serv/etchg, '$ ##,###,##0.00;$ -#,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
						</fo:table-row>						
						<fo:table-row>
								<fo:table-cell text-align="left">
										<fo:block xsl:use-attribute-sets="summary-headings" color="lightblue" background-color="black">
												<xsl:value-of select="'Service Charges'" />
										</fo:block>
								</fo:table-cell>
						</fo:table-row>														
						<fo:table-row height="75px">
								<fo:table-cell>
								  <xsl:if test="/all_results/results[@name = 'seitems']/row">
											<fo:table table-layout="fixed" keep-together="always">
													<fo:table-column column-width="2.5in"/>
													<fo:table-column column-width="1.0in" />
													<fo:table-body>                    
														<xsl:for-each select="/all_results/results[@name = 'seitems']/row">
															<fo:table-row>
																	<fo:table-cell>
																		<fo:block xsl:use-attribute-sets="summary-cells">
																			<xsl:value-of select="./itmdsc"/>
																		</fo:block>																	
																	</fo:table-cell>														
																	<fo:table-cell text-align="right">
																		<fo:block xsl:use-attribute-sets="summary-cells">
																			<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
																		</fo:block>																	
																	</fo:table-cell>														
															</fo:table-row>
														</xsl:for-each>
														<xsl:for-each select="/all_results/results[@name = 'acitems']/row">
															<fo:table-row>
																	<fo:table-cell>
																		<fo:block xsl:use-attribute-sets="summary-cells">
																			<xsl:value-of select="./itmdsc"/>
																		</fo:block>																	
																	</fo:table-cell>														
																	<fo:table-cell text-align="right">
																		<fo:block xsl:use-attribute-sets="summary-cells">
																			<xsl:value-of select="format-number(./aitrat, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
																		</fo:block>																	
																	</fo:table-cell>														
															</fo:table-row>
														</xsl:for-each>														
													</fo:table-body>
											</fo:table>		   
									</xsl:if>
								</fo:table-cell>
						</fo:table-row>
				</fo:table-body>
		</fo:table>
</xsl:template>

<xsl:template name="backpage">
		<fo:block xsl:use-attribute-sets="component-1" font-size="6.5pt" font-weight="bold" space-before="0px" space-after="0px">PART <fo:character character="&#8544;" />: TERMS <fo:character character="&amp;" /> CONDITIONS OF CELLULAR SERVICE</fo:block>  
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >Northwest Missouri Cellular (NWMC) provides cellular service on the terms and conditions specified herein and at rates, and charges established from time to time. These terms of service are subject to change.  Any changes to the terms and conditions of service are effective when we publish them on our website or monthly bill. If you activated your cellular services before the effective date of these terms and conditions, these terms and conditions replace and supersede any previous terms and conditions. The terms and conditions included with your wireless device may not be the most current version. For the most current version of the terms and conditions, please visit our website at www.nwmcell.com or call customer service toll free at 1-800-331-6341. Every use of the term <fo:character character="&#8220;" />you<fo:character character="&#8221;" /> or <fo:character character="&#8220;" />your<fo:character character="&#8221;" /> in this Contract includes you, individually, as well as any company or other entity on whose behalf you are acting in submitting this application for service and/or equipment.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">ACCEPTANCE — </fo:inline>You agree to the then current terms and conditions of service when you do any of the following: (1) sign a contract with us on paper or electronically; (2) tell us orally or electronically that you accept; (3) activate services or attempt to use our services (including, without limitation, attempting to place a call on the NWMC network, or off the network when roaming, including "911" or similar calls); (4) pay for the services; (5) open any package or start any program that says you are accepting the contract when doing so; and (6) use your service after making any change or addition in your service plan or equipment.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">AVAILABILITY OF LIMITED SERVICE — </fo:inline>Service is generally available to cellular mobile radio units (also referred to as cellular telephones or wireless devices) equipped for this service and when within the range of cell sites located in the service area. Even within the service area of a cell site, many factors can affect the availability and quality of your service, including network capacity, your device, terrain, buildings, foliage and weather.  Service is furnished for use by you or your authorized user. A telephone number may not appear in more than one mobile radio unit. Orders including those which involve the start, change or discontinuance of service, will be accepted by NWMC only from you or your authorized user.  If you port a number to NWMC, NWMC may not be able to provide some services right away, such as 911 location services.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">SERVICE NUMBER — </fo:inline>You have no property right in the service number.  NWMC reserves the right to assign, designate, or change such number when in its sole judgment, such assignment, designation or change is reasonably necessary in the conduct of its business.  NWMC will give you prior notice of any such number change. You may not: (1) modify the number we program into any phone or other equipment; (2) transfer or duplicate the number to any phone or other equipment other than that authorized by us or as expressly allowed by the rules and regulations of the Federal Communications Commission regarding number portability; or (3) transfer the number to any other individual or entity without our permission.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">SERVICE COMMITMENT — </fo:inline>You have contracted to have NWMC provide you service for the term specified on the front of this Contract under the heading of Service Commitment. The term of your Service Commitment begins with the first day your service is activated. At the end of your Service Commitment the term of this Contract shall be deemed automatically renewed on a month-to-month basis under the same terms and conditions contained herein and shall continue until terminated by either party.</fo:block>
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >You understand and agree that NWMC<fo:character character="&#8217;" />s damages arising out of any breach of your service commitment will be difficult, if not impossible, to determine. THEREFORE, IF BEFORE EXPIRATION OF THE TERM OF YOUR SERVICE COMMITMENT, YOU TERMINATE YOUR SERVICE, OR NWMC TERMINATES FOR GOOD CAUSE, YOU HEREBY AGREE TO PAY THE EARLY TERMINATION CHARGES FOR LIQUIDATION DAMAGES IN THE AMOUNT SPECIFIED HEREIN TO COMPENSATE NWMC FOR ITS COSTS, INCLUDING COSTS OF ACTIVATION OF YOUR SERVICE, INSTALLATION, EQUIPMENT, ANTENNA, MINUTES OF USE AND/ OR OTHER SERVICES WHICH WERE PROVIDED BY NWMC TO YOU IN EXCHANGE FOR AND IN RELIANCE UPON YOUR AGREEMENT TO THE SERVICE COMMITMENT. Cancellations will become effective on the date of notification, and you are responsible for all charges incurred until then. Your Service Contract and commitment cannot be assigned without the consent of NWMC.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">DEPOSITS — </fo:inline>At any time, NWMC may require you to make a suitable deposit to be held by NWMC, and you hereby grant NWMC a security interest in such deposit, to secure the payment of all sums due hereunder and on other accounts for which you are responsible for payment, as well as for the performance of all other obligations you may have to NWMC, whether now existing or hereafter arising. Upon termination of service, or after 1 year of good payment history, up to the discretion of NWMC, NWMC may apply your deposit against the outstanding amounts due hereunder, or against the outstanding amounts due on any other account for which you are responsible for payment, or any other amounts you owe NWMC. The balance of the deposit, after all obligations to NWMC have been satisfied shall be returned to you. NWMC may require an additional deposit at any time during your service commitment.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">RATES, CHARGES, AND PAYMENT — </fo:inline>You will receive monthly bills which are due and to be paid in full on the due date shown on the bill. You are responsible to pay NWMC for all charges assessed to your wireless device, including cellular airtime charges on the subscribed system and charges incurred on other cellular systems (roamer charges), text charges, data charges, recurring monthly access, optional features, if any, toll charges assessed to your mobile number, collect calls, third party billed charges to wireless device, roaming administrative charges, interconnection/land charges, applicable taxes and other charges for calls billed to your service number or wireless device. You may also have to pay a non-refundable activation fee to begin service, reconnect service, or activate additional devices. We also charge monthly fees (such as universal service and regulatory fees) to help defray the costs of complying with governmental regulations and requirements. These fees are not taxes, are not required by law, and are subject to change. We set these charges, and may keep the amounts in whole or in part.  You accept responsibility for outgoing and incoming calls, messages, and data to and from your wireless device. Chargeable time for calls or data sessions originated or received by a wireless device begins when the signal connection is established to the carrier facilities and ends when the wireless device signals call or data session disconnects at the carrier<fo:character character="&#8217;" />s facilities. These charges are assessed based upon connection to the carrier facilities, regardless of whether the call or data session is completed. When using the Call Waiting or 3 - Way Calling Features, you will be billed for the duration of each connected call from connection to final disconnect. Local airtime rates and peak/off peak hours vary by market.</fo:block>
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >There is a minimum charge for each connected call. Airtime is billed in minutes. Actual airtime usage is rounded up to the next minute for billing purposes. Monthly recurring charges are billed a billing cycle in advance. You agree that proration of charges has been explained to you. For charges based on the amount of data sent or received, we'll round up any fraction to the next full kilobyte, megabyte or gigabyte, depending on how you're billed for data usage.  Data transfer amounts will vary by application.  NWMC reserves the right to increase any and all rates or features, make changes to your subscribed airtime plan or features, and change its peak/ off peak hours upon thirty (30) days notice to you. NWMC reserves the right during the term of this Contract to discontinue offering certain airtime rate plans or features and to change available rate plans and features if you no longer qualify for the rate plan or feature to which you are subscribed, upon thirty (30) days notice to you. You may, during that thirty (30) day period choose from other available rate plans or features. Should you fail to select another available rate plan or features within that thirty (30) day period, you agree that NWMC may assign your service to a comparable available rate plan or features. You are responsible to notify NWMC in writing of any disputed charges within sixty (60) days of the date of the initial charge. Unless otherwise provided by law, you still have to pay all charges until the dispute is resolved. If you do not notify NWMC within that time period in the manner stated, you have waived your right to dispute those amounts or procedures in question. You hereby authorize NWMC to periodically review your account information for the purposes of evaluating NWMC<fo:character character="&#8217;" />s offerings to you.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">PAYMENT TERMS — </fo:inline>Payment is due in full with the execution of this contract by you, or as otherwise agreed to by the parties. Additionally, you must pay, by each invoice date, all charges for services provided to each wireless device that our records show you activated no matter who actually uses or has possession of wireless devices at the time services are provided. A monthly late charge shall accrue on any amount remaining unpaid, at the lesser of one and one half percent (1 <fo:character character="&#189;" /><fo:character character="%" />) per month or the maximum rate permitted by applicable law.  If you have authorized payment for services or equipment by credit card or by debiting a bank account, no additional notice or consent is required before we invoice your credit card or debit your bank account, for all amounts (including any late charges, reactivation charges, taxes or other regulatory related charges) due to us or billed by us on behalf of a third party. You must promptly notify us of any change in your address, the credit card used for payment, or the bank account used for bank debits. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">TAXES — </fo:inline>The price of the Service does not include sales, use, excise, ad valorem, property or any other tax now or which may be hereafter imposed, directly or indirectly, by any governmental authority or agency with respect to the Service. Customer shall pay such taxes directly or reimburse NWMC for any such taxes which NWMC may be required to collect or pay immediately upon the invoicing of any such taxes. Some cities may also impose a telephone license tax or gross receipt tax. Federal, State and Local taxes as well as other fees also apply. Taxes imposed by governmental authorities may change without notice.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">NON-PAYMENT/BREACH — </fo:inline>A charge in an amount of no less than $30.00 will be made by NWMC for any check or other negotiable instrument tendered by you and returned unpaid by a financial institution for any reason, and NWMC may demand payment by money order, cashier<fo:character character="&#8217;" />s check or similarly secure form of payment, at NWMC<fo:character character="&#8217;" />s discretion. You shall pay to NWMC all costs and expenses, including without limitation, reasonable attorneys<fo:character character="&#8217;" /> fees, the fees of any collection agency, and court costs incurred by NWMC in exercising any of its rights or remedies hereunder.  The collection fee shall in no event exceed the amount prescribed by law.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">CREDIT INFORMATION — </fo:inline>You consent to NWMC<fo:character character="&#8217;" />s disclosure of account information to or from credit reporting agencies, credit bureaus, private credit reporting associations, or to or from other providers of cellular service at any time during your service with NWMC.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">TERMINATION OF SERVICE — </fo:inline>You may terminate service by notifying NWMC. If you terminate service before the completion of any service commitment other than a month-to-month term, you agree to pay the early termination charge to NWMC for liquidated damages in the amount set out on the front of this contract and as described in the Service Commitment section, above. NWMC may terminate your service for non-payment of any sum due NWMC hereunder, or non-payment of any amount due NWMC on any other account for which you are responsible for payment, or for non-payment for any other service, repairs or equipment furnished in connection with your wireless device or upon violation of any of the conditions of this Contract, including violation of NWMC<fo:character character="&#8217;" />s Acceptable Use Policy, and/or fraud. Subject to any applicable regulation or tariff, NWMC may by notice to you, without incurring any liability, either temporarily discontinue your service, or terminate your service and this Contract. NWMC may also terminate service in the event of your insolvency, receivership, voluntary or involuntary bankruptcy, assignment for the benefit of creditors or sale of substantially all of your assets. You agree to pay the early termination charge to NWMC for liquidated damages in the amount set out on the front of this contract and as described in Service Commitment for all above mentioned reasons of termination.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt">NWMC requires that you maintain a physical address within Atchison, Gentry, Holt, Nodaway, or Worth counties in order to continue service. NWMC reserves the right at any time, and for any reason, including excessive usage outside NWMC local coverage area, to discontinue service provided, or change your plan and features, with 30 days<fo:character character="&#8217;" /> notice to customer. Service may also be refused or discontinued without notice in the event that: 1) service is used in such a manner that will adversely affect NWMC service to others, is in violation of NWMC<fo:character character="&#8217;" />s Acceptable Use Policy, available at www.nwmcell.com, or is otherwise in violation of any Federal Communication Commission Rule or Regulation or state, federal or local laws; 2) services are not available from the network provider or its successor; 3) your credit information provided to NWMC is inaccurate; or 4) NWMC becomes aware of facts indicating that your credit standing has deteriorated. NWMC reserves the right to require a deposit for continuation of service, if NWMC deems such advisable if your services are interrupted or disconnected, a reconnect fee may be applicable. If you are a new customer and are not satisfied with the cellular service provided by NWMC, you may cancel your new contract within fifteen (15) days of the date of activation. If you are an existing customer and change your contract and are not satisfied with your cellular service, you may or revert back to your prior contract within (15) days of the date of entering into the new contract. All equipment including your wireless device and any accessories associated with the contract that you are cancelling must be returned within the fifteen (15) day period in like new condition and in original packaging with all components and paperwork. A fee may apply for excessive wear or use of the equipment, left up to the discretion of NWMC, up to $200.00. Applicable taxes and surcharges are nonrefundable and will be billed to you for the period up to the 15 days in which you have service. If the bill is left unpaid, you will be in default of the signed contract. If federal law requires, you will be allowed to have your wireless service number moved to another provider of cellular service (ported). An early termination fee may apply.  Only currently active numbers may be ported. In order to be eligible to port a wireless service number, you must have your new service provider request that your then current number be ported on your behalf prior to terminating your service under this Contract. Porting of a wireless service number does not relieve you of any obligations remaining or otherwise owed under this agreement, including, but not limited to any unpaid balances, and early termination fees.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">NUMBERS THAT HAVE BEEN DEACTIVATED ARE NOT CURRENTLY ACTIVE WIRELESS SERVICE NUMBERS AND CANNOT BE PORTED.</fo:inline></fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">UNLIMITED VOICE SERVICES — </fo:inline>Unlimited voice services (if applicable) are provided solely for live dialog between two individuals.  Unlimited voice services may not be used for conference calling, call forwarding, monitoring services, data transmissions, transmission of broadcasts, transmission of recorded material, or other connections which do not consist of uninterrupted live dialog between two individuals.  If we find that you are using an unlimited voice service offering for other than live dialog between two individuals, we may, at our option, terminate your service or change your plan to one with no unlimited usage components.  We will provide you with notice that we intend to take any of the above actions.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">DATA SERVICES — </fo:inline>Data Plans or features are for your use only and you may not offer them for resale.  Use of Data Plans and features must be in accordance with NWMC<fo:character character="&#8217;" />s Acceptable Use Policy, which is subject to change.  We may monitor your compliance with these terms and conditions. NWMC reserves the right to take measures to protect our network and other users from harm, compromised capacity or degradation in performance. These measures may impact your service.  NWMC reserves the right to deny, limit, modify or terminate service, with or without notice, to anyone we believe is using Data Plans or features in a manner that adversely impacts the network or other users.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">WIRELESS DEVICES — </fo:inline>Except as provided in Part II, below, NWMC is not responsible for the installation, operation, quality of transmission or maintenance of your wireless device. If your equipment is stolen, you are responsible for all wireless service charges (including taxes, fee, and third-party charges) until the theft is reported to NWMC and evidence of the theft is provided to NWMC (i.e., stolen police report), directly, by calling the customer service number at 1-800-331-6341.</fo:block>
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >You understand that in the event of non-payment of charges, your service may be suspended and the cellular radio system may be programmed to refuse service to the equipment on which the delinquent charges were incurred until payment in full is made. You agree to advise any prospective purchaser of the equipment of any such charges outstanding. We may change a wireless device<fo:character character="&#8217;" />s software or programming over the air without notice and without your prior consent. This might affect data stored on your wireless device, or the way you<fo:character character="&#8217;" />ve programmed it. Your wireless device may also contain software that prevents it from being used with any other company<fo:character character="&#8217;" />s wireless service, even if you leave us. Your wireless device may not be compatible with another wireless carrier<fo:character character="&#8217;" />s network and may not be capable of accessing all services or features offered by NWMC or another wireless carrier.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">PRIVACY — </fo:inline>NWMC may collect personal information about you. NWMC also may gather some information through our relationship with you, such as information about the quantity, technical configuration, type, destination and amount of your use of our telecommunications services. You can find out how we use, share, and protect the information we collect about you in the NWMC Privacy Policy, available at www.nwmcell.com.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">THIRD PARTY SERVICES AND APPLICATIONS — </fo:inline>Many services and applications offered through your device may be provided by third parties. Some of these services and applications may involve charges for which you will be billed. The amount and frequency of the charges will be disclosed to you by such third party. Before you use, link to or download a service or application provided by a third party, you should review the terms of such service or application and applicable privacy policy. Personal information you submit may be read, collected or used by the third party service or application provider and/or other users of those forums. NWMC is not responsible for any third–party information, content, applications or services you access, download or use on your wireless device. You are responsible for maintaining virus and other Internet security protections when accessing these third–party products or services.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">NWMC LIMITATION AND CONDITIONS OF LIABILITY; INDEMNITY — </fo:inline>Service may be temporarily interrupted, including dropped calls, delayed or otherwise limited due to: 1) transmission limitations caused by atmospheric and other conditions; 2) the availability of radio frequency channels; 3) system capacity limitations; 4) coordination with adjacent cellular companies; 5) equipment modifications, upgrades, relocations, failures, repairs and/or similar activities; and 6) negligence of NWMC. NWMC therefore assumes no duty to provide uninterrupted service to you or your authorized user. NWMC makes no representations or warranties, express or implied, including, to the extent permitted by applicable law, any implied warranty of merchantability or fitness for a particular purpose, about your service, your wireless device, or any applications you access through your wireless device.  NWMC shall have no liability and no credits shall be given for any of the above referenced conditions arising out of interruptions, delays, or failures in transmission as well as: 1) your negligent or willful act; 2) the failure of equipment or service not provided through NWMC facilities; or 3) the failure of services not provided to NWMC; or 4) acts of God, fire, riots, Government authorities or other causes beyond the control of NWMC.</fo:block>
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >You agree that the liability of NWMC, if any, for delays and failure in transmission of service (service problems) to you, whether caused by the negligence of NWMC or otherwise, is hereby limited to the allowance of a credit in the form of an adjustment for no more than the charges billed by NWMC to you for service for the period during which the service problem occurred, except that no credit shall be given for recurring monthly charges, if any, for a service problem of less than 24 hours duration. No credits shall be given for dropped calls. NWMC has the right to require that credits be applied for upon written request and to deny any request for credit for an alleged service problem where the evidence of such problem is inconclusive, or the request is otherwise unwarranted or insufficient.</fo:block>
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >Except as provided above, you hereby agree that NWMC shall not be liable for, and shall be held harmless by you from and against, and you agree to indemnify NWMC for, any and all claims and damages, of every kind, including damages to your vehicle, personal injury and specifically special or consequential damages, arising out of the use of any service and/or equipment provided under this Contract, as well as any damages arising out of or attributed, directly or indirectly, to service problems or use of the service and/or equipment by you and any third party. You understand that, for an additional fee, handsfree equipment is available from numerous sources. This service enables you to use your wireless device without holding the receiver, thereby allowing you to use both hands while operating your motor vehicle.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">GOVERNING LAW — </fo:inline>This Contract shall be governed by the laws of the State of Missouri.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">LONG DISTANCE INDEMNIFICATION — </fo:inline>Calling plans which include long distance service are based upon the use of NWMC<fo:character character="&#8217;" />s designated long distance carrier. Designation of an alternate long distance carrier by you may result in your incurring toll charges even under such calling plans. NWMC will not be responsible for any charges incurred by you with another distance carrier or any other charges.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">ELECTRONIC CONTRACTS — </fo:inline>NWMC will retain all signed contracts in electronic format only. You understand that if requesting a copy of your contract, it will be provided from electronic format.</fo:block>
		<fo:block xsl:use-attribute-sets="component-1" font-size="6.5pt" font-weight="bold" space-before="6.5pt">PART <fo:character character="&#8545;" />: TERMS <fo:character character="&amp;" /> CONDITIONS FOR SALES OF CELLULAR EQUIPMENT</fo:block>
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >The following additional provisions apply to sales of wireless equipment.</fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">LIMITED WARRANTY — </fo:inline>NWMC is the owner of the equipment free from all liens and encumbrances other than any purchase money security interest retained by NWMC <fo:character character="&#8217;" /> s supplier. </fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">EXCEPT AS PROVIDED IN ANY APPLICABLE, EFFECTIVE MANUFACTURER <fo:character character="&#8217;" />S WARRANTY, OR AS OTHERWISE PROVIDED IN THIS PARAGRAPH, NWMC MAKES NO WARRANTIES OF ANY KIND, STATUTORY, EXPRESS OR IMPLIED, TO YOU OR TO ANY OTHER PURCHASER OR LESSEE OF THE EQUIPMENT. WITHOUT LIMITING THE FOREGOING, NWMC SPECIFICALLY MAKES NO WARRANTY THAT THE EQUIPMENT SOLD HEREUNDER IS FIT FOR ANY PARTICULAR PURPOSE. YOU ALSO AGREE THAT THE LIABILITY OF NWMC FOR ANY BREACH OF THE IMPLIED WARRANTY OF MERCHANTABILITY SHALL BE LIMITED TO THE REPAIR OR REPLACEMENT OF ANY DEFECTIVE PART OF THE EQUIPMENT SOLD HEREUNDER. YOU HEREBY WAIVE ALL OTHER WARRANTIES, GUARANTEES, CONDITIONS, OR LIABILITIES, EXPRESS OR IMPLIED, ARISING BY LAW OR OTHERWISE INCLUDING WITHOUT LIMITATION, CONSEQUENTIAL, SPECIAL, OR INCIDENTAL DAMAGES, WHETHER OR NOT OCCASIONED BY NWMC<fo:character character="&#8217;" />S NEGLIGENCE AND INCLUDING WITHOUT LIMITATION, LIABILITY FOR ANY LOSS OR DAMAGE RESULTING FROM THE INTERRUPTION OR FAILURE IN THE OPERATION OF ANY EQUIPMENT PROVIDED HEREUNDER.</fo:inline></fo:block>
		<fo:block xsl:use-attribute-sets="smallprint-8" font-size="6pt" space-before="6.5pt"><fo:inline color="black" font-weight="bold">FCC MATTERS — </fo:inline>You are solely responsible for compliance with Federal Communication Commission rules and with the rules and regulations of any other federal, state or local regulatory agency in connection with the use of the equipment. Neither NWMC nor any of its employees is an agent or representative of you in Federal Communication Commission matters or otherwise. </fo:block>
		<fo:block space-before="2px" xsl:use-attribute-sets="smallprint-8" font-size="6pt" >I understand that this Contract for Cellular Service and additional documents will be stored electronically by NWMC.</fo:block>
</xsl:template>

</xsl:stylesheet>
