<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:exsl="http://exslt.org/functions" 
								xmlns:img="java:com.psasoft.util.ImageUtilities"
								extension-element-prefixes="exsl" 
								exclude-result-prefixes="java" version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/>  

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
<xsl:variable name="title" select="' '" />

<xsl:template match="/">
		<fo:root>
				<xsl:call-template name="make-layout-master-small-margin" />
				<xsl:call-template name="make-body" />
		</fo:root>
</xsl:template>
<xsl:template name="body_process">
		<xsl:variable name="rowcount" select="'1'" />
		<xsl:variable name="acct" select="/all_results/results[@name = 'acct']/row" />
		<xsl:variable name="serv" select="/all_results/results[@name = 'serv']/row" />
		<xsl:variable name="logo" select="img:getImageBase64Encoded('/images/northwest_logo_new.jpg')"/>
		<fo:block-container absolute-position="fixed" left=".5in" top=".25in">
				<fo:block>
					<fo:external-graphic src="data:image/jpeg;base64,{$logo}" content-height="auto" content-width="1.75in"/>
				</fo:block>
		</fo:block-container>
		<fo:block-container  absolute-position="fixed" width="6in" start-indent="2.5in" top=".25in" text-align="center">
				<fo:block xsl:use-attribute-sets="report-title" font-size="12pt" font-weight="bold"><fo:inline color="black" padding="5px">Prepay/Advanced Pay Service Agreement</fo:inline></fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="3.75in" left=".5in" top="1.5in" text-align="left">
			<fo:block xsl:use-attribute-sets="summary-cells">
				<fo:inline color="black"><xsl:value-of select="'Account Number:	'" /></fo:inline>
				<xsl:value-of select="format-number($acct/cycle, '000')" />
				<xsl:value-of select="'-'" />
				<xsl:value-of select="format-number($acct/bacct, '0000000')" />
			</fo:block>	
		</fo:block-container> 
		<fo:block-container absolute-position="fixed" width="3.75in" left="4.5in" top="1.5in" text-align="left">
			<fo:block xsl:use-attribute-sets="summary-cells">
				<fo:inline color="black"><xsl:value-of select="'Mobile Number (MDN):	'" /></fo:inline>
				<xsl:call-template name="phone">
					<xsl:with-param name="npa" select="$serv/cnpa"/>
					<xsl:with-param name="nxx" select="$serv/cnxx"/>
					<xsl:with-param name="line" select="$serv/cline"/>
				</xsl:call-template>
			</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" left=".5in" top="2.0in" text-align="left">
				<fo:block xsl:use-attribute-sets="smallprint-8" font-weight="bold" color="black" space-before=".1in" space-after="0in">I understand that this agreement for Prepay/Advance Pay Cellular Service and additional documents will be stored electronically by NWMC.  I acknowledge that I have read and understand all of the terms and conditions for the prepay/advance pay service and agree to be bound thereby.</fo:block>
		</fo:block-container>
		<fo:block-container absolute-position="fixed" width="7.5in" left=".5in" top="3.5in" text-align="left">
				<fo:table table-layout="fixed" keep-together="always">
						<fo:table-column column-width="3.75in"/>
						<fo:table-column column-width="3.75in"/>
						<fo:table-body>
								<fo:table-row height="1.5in">
										<fo:table-cell display-align="after">
											<fo:block xsl:use-attribute-sets="summary-cells" color="black">Subscriber Signature:  
											</fo:block>
										</fo:table-cell>
										<fo:table-cell display-align="after">
											<fo:block xsl:use-attribute-sets="summary-cells" border-bottom-style="solid" border-bottom-width="1px">
											<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="1.5in" content-height="auto"/>
											</fo:block>
										</fo:table-cell>
								</fo:table-row>										
								<fo:table-row>
										<fo:table-cell padding-before="0.1in">
											<fo:block xsl:use-attribute-sets="summary-cells">
													<fo:inline color="black"><xsl:value-of select="'Printed Name: '"/></fo:inline>
													<xsl:value-of select="$acct/fname"/>
													<xsl:value-of select="' '"/>
													<xsl:value-of select="$acct/lname"/>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell padding-before="0.1in">
											<fo:block xsl:use-attribute-sets="summary-cells">
													<fo:inline color="black"><xsl:value-of select="'Title: '"/></fo:inline>
											</fo:block>
										</fo:table-cell>
								</fo:table-row>										
								<fo:table-row>
										<fo:table-cell padding-before="0.1in" number-columns-spanned="2">
											<fo:block xsl:use-attribute-sets="summary-cells">
													<fo:inline color="black"><xsl:value-of select="'Date: '"/></fo:inline>
													<xsl:value-of select="$serv/ctcstrdte"/>											
											</fo:block>
										</fo:table-cell>								
								</fo:table-row>   
						</fo:table-body>
				</fo:table>				
		</fo:block-container>				

		<fo:block break-before="page" />
		<xsl:call-template name="backpage"/> 
</xsl:template>

<xsl:template name="backpage">
	<!-- keep-together="always" -->
    <fo:block xsl:use-attribute-sets="component-1" font-size="7.0pt" font-weight="bold" space-before="0px" space-after="0px">Part I:  Prepay/Advance Pay Service Cellular Service Terms and Conditions</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >Northwest Missouri Cellular (NWMC) provides Prepay/Advance Pay cellular service on the terms and conditions specified herein and at rates, and charges established from time to time.  These terms of service are subject to change.  Any changes to the terms and conditions of service are effective when we publish them on our website.  If you activated your cellular services before the effective date of these terms and conditions, these terms and conditions replace and supersede any previous terms and conditions.  The terms and conditions included with your wireless device may not be the most current version.  For the most current version of the terms and conditions, please visit our website at www.nwmcell.com or call customer service toll free at 1-800-331-6341.  Every use of the term <fo:character character="&#8220;" />you<fo:character character="&#8221;" /> or <fo:character character="&#8220;" />your<fo:character character="&#8221;" /> in this agreement includes you individually, as well as any company or other entity on whose behalf you are acting in, regarding services provided by NWMC.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">ACCEPTANCE – </fo:inline>You agree to the then current terms and conditions of service when you do any of the following:  (1) Sign an agreement with us on paper or electronically; (2) tell us orally or electronically that you accept; (3) activate service or attempt to use our services (including without limitation, attempting to place a call on the NWMC network, or off the network when roaming, including <fo:character character="&#8220;" />911<fo:character character="&#8221;" /> or similar calls); (4) pay for the services (5) open any package or start any program that says you are accepting the agreement when doing so; and (6) use your service after making any change or addition in your prepaid plan, or change or addition of equipment.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">AVAILABILITY OF LIMITED SERVICE – </fo:inline>Service is generally available to cellular mobile radio units (also referred to as cellular telephones or wireless devices) equipped for this service and when within the range of cell sites located in the service area.  Even within the service area of a cell site, many factors and affect the availability and quality of your service including network capacity, your device, terrain, buildings, foliage, and weather.  Service is furnished for use by you or your authorized user.  A telephone number may not appear in more than one mobile radio unit.  Orders including those which involve the start, change or discontinuance of service will be accepted by NWMC only from you or your authorized user.  If you port a number to NWMC, NWMC may not be able to provide some services right away, such as 911 location services.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">SERVICE NUMBER – </fo:inline>You have no property right in the service number.  NWMC reserves the right to assign, designate, or change such number when in its sole judgment, such assignment, designation or change is reasonably necessary in the conduct of its business. NWMC will give you prior notice of any such number change.  You may not (1) modify the number we program into any phone or other equipment; (2) transfer or duplicate the number to any phone or other equipment other than that authorized by us or as expressly allowed by the rules and regulations of the Federal Communications Commission regarding number portability; or (3) transfer the number to any other individual or entity without our permission.   If federal law requires, you will be allowed to have your wireless service number moved to another provider (ported).  Only current active numbers may be ported.  In order to be eligible to port a wireless service number, you must have your new service provider request that your then current number be ported on your behalf prior to terminating your service.  Porting of a wireless service number doesn<fo:character character="&#8217;" />t relieve you of any obligations remaining or otherwise owed under this agreement.  Numbers that have been deactivated are not currently active and cannot be ported.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">SERVICE AGREEMENT – </fo:inline>You have agreed to have NWMC provide you with Prepay/Advance Pay service.  The agreement begins with the first day your service is activated.  Upon payment received, prepay/advance pay service will extend for the designated service period.  Other terms and conditions contained herein shall continue until terminated by either party.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">RATES, CHARGES, AND PAYMENT – </fo:inline>You are responsible to pay NWMC for all prepay/advance pay charges assessed in advance for your wireless service.  You may also have to pay a non-refundable activation fee to begin service, reconnect service, or activate additional devices.  Taxes and regulatory fees are built into the prepay/advance pay plans, but this is subject to change.  </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >You accept responsibility for outgoing and incoming calls, messages and data to and from your wireless device.  Chargeable time for calls or data sessions originated or received by a wireless device begins when the signal connection is established to the carrier facilities and ends when the wireless device signals call or data session disconnects at the carrier<fo:character character="&#8217;" />s facilities. The charges are assessed based upon connection to the carrier facilities and ends when the wireless device signals call or data session disconnects at the carrier<fo:character character="&#8217;" />s facilities.  These charges are assessed based upon connection to the carrier facilities, regardless of whether the call or data session is completed. NWMC reserves the right to increase any and all rates or features, make changes to your prepaid/advance pay plan or features upon thirty (30) days notice to you.  Notice will be sent via call or text message.  NWMC reserves the right to discontinue offering certain plans and features and to change available plans.  You hereby authorize NWMC to periodically review your account information for the purposes of evaluating NWMC<fo:character character="&#8217;" />s offerings to you.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">DATA SERVICES – </fo:inline>Data usage is calculated from the amount of data sent and received. We will round up any fraction of usage to the next full kilobyte, megabyte or gigabyte, depending on your data usage plans and features. Data transfer amounts will vary by application. Data plans and features are for your use only and you may not offer them for resale. Use of data plans and features must be in accordance with NWMC<fo:character character="&#8217;" />s Acceptable Use Policy, which is subject to change. WE may monitor your compliance with these terms and conditions. NWMC reserves the right to take measures to protect our network and other users from harm, compromised capacity or degradation in performance. These measures may impact your service. NWMC reserves the right to deny, limit, modify, or terminate service, with or without notice, to anyone we believe is using the data plans or features in a manner that adversely impacts the network or other users.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">PAYMENT TERMS – </fo:inline>Payment is due in full for prepay/advance pay services along with any equipment charges, at start of service with NWMC.  You must pay by each renewal date all charges for services provided to keep the device active.  Payment is required in the form of cash, money order or debit/credit card.  Checks are not accepted on prepay/advance pay services.  If you have authorized payment for services by credit card, debit card, or by debiting a bank account, no additional notice or consent is required before we invoice your credit card or debit your bank account for all amounts due to us.  You must promptly notify us of any change in your address, the credit card used for payment or the bank account used for bank debits.  If service is not renewed by due date, service will be disconnected.  You have 30 days to pay to reactivate the service number, before it is reassigned.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">TERMINATION OF SERVICE – </fo:inline>You may terminate service by notifying NWMC.  NWMC may terminate your service for non-payment of any amount due NWMC for any other service, repair, or equipment furnished in connection with your wireless device or upon violation of any of the conditions of this agreement, including violation of NWMC<fo:character character="&#8217;" />s Acceptable Use Policy, and/or fraud.  </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >NWMC does require that you maintain a physical address within Atchison, Gentry, Holt, Nodaway, or Worth counties in order to continue service.  NWMC reserves the right at any time, and for any reason including excessive usage outside NWMC local coverage area, to discontinue service provided, or change your plan and features with 30 days notice to you.  Service may also be refused or discontinued without notice in the event that (1) service is used in such a manner that will adversely affect NWMC service to others, is in violation of NWMC<fo:character character="&#8217;" />s Acceptable Use Policy, available at www.nwmcell.com, or is otherwise in violation of any Federal Communication Commission Rule or Regulation or state, federal or local laws; (2) services are not available from the network provider or its successor.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">UNLIMITED VOICE SERVICES – </fo:inline>Unlimited voice services are provided solely for live dialog between two individuals.  Unlimited voice services may not be used for conference calling, call forwarding, monitoring services, data transmissions, transmission of broadcasts, transmission of recorded material, or other connections which do not consist of uninterrupted live dialog between two individuals.  If we find that you are using unlimited voice service offering for other than live dialog between two individuals, we may at our option terminate your service.  We will provide you with notice that we intend to take any of the above actions.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">WIRELESS DEVICES - </fo:inline>NWMC is not responsible for the installation, operation, quality of transmission, or maintenance of your wireless device.  If you re equipment is stolen, you are responsible for the service until the theft is reported to NWMC and evidence of the theft is provided to NWMC (i.e. police report)), directly by calling the customer service number at 1-800-331-6341. </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >You understand that in the event of nonpayment of renewal charges, your service may be suspended and the cellular radio system may be reprogrammed to refuse service to the equipment.  We may also change software or programming over the air without notice and without your prior consent.  This might affect data stored on your wireless device or the way you have programmed it.  Your wireless device may contain software that prevents it from being used with any other company<fo:character character="&#8217;" />s wireless service, even if you leave us.  Your wireless device may not be compatible with another wireless carrier<fo:character character="&#8217;" />s network and may not be capable of accessing all service or features offered by NWMC or another wireless carrier.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">PRIVACY – </fo:inline>NWMC may collect personal information about you.  NWMC also may gather some information through our relationship with you, such as information about the quantity, technical configuration, type, destination and amount of your use of our telecommunication services.  You can find out how we use, share and protect the information we collect about you in the NWMC Privacy Policy, available at www.nwmcell.com.  </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">NWMC LIMITATION AND CONDITIONS OF LIABILITY; INDEMNITY – </fo:inline>Service may be temporarily interrupted, including dropped calls, delayed or otherwise limited due to: (1) transmission limitations caused by atmospheric and other conditions; (2) the availability of radio frequency channels; (3) system capacity limitations (4) coordination with adjacent cellular companies; (5) equipment modifications, upgrades, relocations, failures, repairs and/or similar activities; and (6) negligence of NWMC.  NWMC therefore assumes no duty to provide uninterrupted service to you or your authorized user.  NWMC makes no representations or warranties express or implied including, to the extent permitted by applicable law, any implied warranty of merchantability or fitness for a particular purpose, about your service or wireless device.  NWMC shall have no liability and no credits shall be given for any of the above referenced conditions arising out of interruptions, delays or failures in transmission as well as: (1) your negligent or willful act; (2) the failure of equipment or service not provided through NWMC facilities; or (3) the failure of services not provided to NWMC; or (4) acts of God, fire, riots, Government authorities or other causes beyond the control of NWMC.  </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >You agree that the liability of NWMC, if any, for delays and failure in transmission of service (service problems) to you, whether caused by the negligence of NWMC or otherwise, is hereby limited to the allowance of a credit in the form of an adjustment for no more than the charges billed by NWMC to you for the service for the period during which the service problem occurred, except that no credit shall be given for a service problem of less than 24 hours duration.  No credits shall be given for dropped calls.  NWMC has the right to require that credits be applied for upon written request and to deny any request for credit for an alleged service problem where the evidence of such problem is inconclusive, or the request is otherwise unwarranted or insufficient.  </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >Except as provided above, you hereby agree that NWMC shall not be liable for, and shall be held harmless by you from and against and you agree to indemnify NWMC for any and all claims and damages, of every kind, including damages to your vehicle, personal injury and specifically special or consequential damages arising out of the use of any service and/or equipment provided under this agreement, as well as any damages arising out of or attributed, directly or indirectly, to service problems or use of the service and/or equipment by you and any third party.  You understand that, for an additional fee, handsfree equipment is available from NWMC and numerous sources.  This service enables you to use your wireless device without holding the receiver, thereby allowing you to use both hands while operating your motor vehicle.  </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">GOVERNING LAW – </fo:inline>This agreement shall be governed by the laws of the State of Missouri.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">LONG DISTANCE INDEMNIFICATION – </fo:inline>Long distance service is designated by NWMC<fo:character character="&#8217;" />s preferred carrier.   Designation of another carrier by you may result in you incurring toll charges, though the prepay/advance pay service is nationwide.  NWMC will not be responsible for any charges incurred by you with another long distance carrier or any other charges.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">ELECTRONIC AGREEMENTS – </fo:inline>NWMC will retain all agreements in electronic format only.  You understand that if requesting a copy of your agreement, it will be provided in electronic format.</fo:block>
    <fo:block xsl:use-attribute-sets="component-1" font-size="7.0pt" font-weight="bold" space-before="10px" space-after="0px">PART II:  TERMS AND CONDITIONS OF SALES OF CELLULAR EQUIPMENT</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >The following additional provisions apply to the sales of wireless equipment.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">LIMITED WARRANTY – </fo:inline>NWMC is the owner of the equipment free from all liens and encumbrances other than any purchase money security interest retained by NWMC<fo:character character="&#8217;" />s supplier.</fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" >Except as provided in any applicable effective manufacturer<fo:character character="&#8217;" />s warranty, or as otherwise provided in this paragraph,  NWMC makes no warranties of any kind, statutory, express or implied, to you or any other purchaser or lessee of the equipment, without limiting the foregoing, NWMC specifically makes no warranty that the equipment sold hereunder is fit for any particular purpose.  You also agree that the liability of NWMC for any breach of the implied warranty of merchantability shall be limited to the repair or replacement of any defective part of the equipment sold hereunder, you hereby waive all other warranties, guarantees, conditions, or liabilities, express or implied, arising by law or otherwise including without limitation, consequential, special, or incidental damages, whether or not occasioned by NWMC<fo:character character="&#8217;" />s negligence and including without limitation, liability for any loss or damage resulting from the interruption or failure in the operation of any equipment provided hereunder.  </fo:block>
    <fo:block space-before="2.5px" xsl:use-attribute-sets="smallprint-8" font-size="6.0pt" ><fo:inline color="black" font-weight="bold">FCC MATTERS – </fo:inline>You are solely responsible for compliance with Federal Communication Commission rules and with the rules and regulations of any other federal, state, or local regulatory agency in connection with the use of the equipment.  Neither NWMC nor any of its employees is an agent or representative of you in Federal Communication Commission matters or otherwise.</fo:block>
</xsl:template>

</xsl:stylesheet>
