<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: creditreports.xsl,v 1.2 2010-02-10 18:11:43 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:saxon="http://saxon.sf.net/" 
                xmlns:util="java:com.psasoft.util.TextUtilities"
				extension-element-prefixes="saxon" 
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  

  <xsl:variable name="oldrecordid" select="0" saxon:assignable="yes" />
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="concat('Credit Reports ', $report_date_range[1], ' to ', $report_date_range[2])" />  


<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'data']/row">
			<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="uname">
				<xsl:variable name="username" select="current-group()[position() = 1]/uname" />
				<xsl:variable name="name" select="current-group()[position() = 1]/name" />
				<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" keep-with-nex="always">
					<xsl:value-of select="$username" />
					<xsl:value-of select="' - '" />
					<xsl:value-of select="$name" />
				</fo:block>
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<fo:table-column column-width="0.75in" />
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.5in" />
					<fo:table-column column-width="1.25in" />
					<fo:table-column column-width="1.25in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-header>
						<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Report Date</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Score</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Level</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Deposit</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>SSN</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Name</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Account</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Service</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Disconnect Date</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-header>
					<fo:table-body>
						<saxon:assign name="oldrecordid" select="0" />
						<xsl:for-each select="/all_results/results[@name = 'data']/row[uname = $username]">
							<xsl:call-template name="detail">
								<xsl:with-param name="row" select="." />
							</xsl:call-template>
							<saxon:assign name="oldrecordid" select="./recordid" />
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
			<fo:block>No Reports Found</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="detail">
	<xsl:param name="row" />
	
	<fo:table-row>
		<xsl:choose>
			<xsl:when test="$row/recordid != $oldrecordid">
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="$row/createddt" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:if test="normalize-space($row/crscore) &gt; ''">
							<xsl:value-of select="format-number($row/crscore, '###0')" />
						</xsl:if>
						<xsl:value-of select="' '" />				
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="$row/lvlcode" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:if test="normalize-space($row/depamt) &gt; ''">
							<xsl:value-of select="format-number($row/depamt, '##,##0.00;$ -#,##0.00')" />
						</xsl:if>
						<xsl:value-of select="' '" />				
					</fo:block>
				</fo:table-cell>
			</xsl:when>
			<xsl:otherwise>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right" number-columns-spanned="4">
					<fo:block>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
			</xsl:otherwise>
		</xsl:choose>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="substring($row/ssn, 1, 3)" />
				<xsl:value-of select="'-'" />
				<xsl:value-of select="substring($row/ssn, 4, 2)" />
				<xsl:value-of select="'-'" />
				<xsl:value-of select="substring($row/ssn, 6, 4)" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/fname" />
				<xsl:value-of select="' '" />
				<xsl:value-of select="$row/mname" />
				<xsl:value-of select="' '" />
				<xsl:value-of select="$row/lname" />
			</fo:block>
		</fo:table-cell>
  		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:if test="normalize-space($row/cycle) &gt; ''">
					<xsl:value-of select="format-number($row/cycle, '000')" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="format-number($row/account, '0000000')" />
				</xsl:if>
				<xsl:value-of select="' '" />				
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
			<fo:block>
				<xsl:if test="normalize-space($row/cnpa) &gt; ''">
					<xsl:call-template name="phone">
						<xsl:with-param name="npa" select="$row/cnpa"/>
						<xsl:with-param name="nxx" select="$row/cnxx"/>
						<xsl:with-param name="line" select="$row/cline"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:value-of select="' '" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:if test="normalize-space($row/dcmm) &gt; '' and $row/dcmm &gt; 0">
					<xsl:call-template name="date4parm">
						<xsl:with-param name="cc" select="$row/dccc" />
						<xsl:with-param name="yy" select="$row/dcyy" />
						<xsl:with-param name="mm" select="$row/dcmm" />
						<xsl:with-param name="dd" select="$row/dcdd" />
					</xsl:call-template>
				</xsl:if>
				<xsl:value-of select="' '" />
			</fo:block>
		</fo:table-cell>
	</fo:table-row>
</xsl:template>

</xsl:stylesheet>






