<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:convert="java:com.psasoft.util.ConversionUtilities"								
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/> 
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Customers Equipment ', $contract_start_date[1], ' to ', $contract_start_date[2])" />
	
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	
	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="$report_type = 1 and exists(/all_results/results[@name = 'summary']/row)">
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<xsl:call-template name="sumheader" />
					<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'summary']/row">					
						<xsl:call-template name="summrow">
							<xsl:with-param name="manu" select="./mfgmdl" />
							<xsl:with-param name="model" select="./eqpdsc" />
							<xsl:with-param name="active" select="./active" />
							<xsl:with-param name="discon" select="./disconnected" />
						</xsl:call-template>
					</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</xsl:when>
			<xsl:when test="($report_type = 2 or $report_type = 3) and exists(/all_results/results[@name = 'detail']/row)">
				<xsl:for-each-group select="/all_results/results[@name = 'detail']/row" group-by="cumrkt">
					<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
					<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="detailheader">
							<xsl:with-param name="market" select="$market" />
							<xsl:with-param name="marketname" select="$marketname" />
						</xsl:call-template>
						<fo:table-body>
							<xsl:call-template name="detailrow">
								<xsl:with-param name="market" select="$market" />
							</xsl:call-template>
						</fo:table-body>
					</fo:table>
				</xsl:for-each-group>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>No Equipment Found for selection(s)</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="sumheader">
		<fo:table-column column-width="2.0in" />
		<fo:table-column column-width="2.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings"  text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Manufacturer
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Model
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Active Customer Count
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Disconnected Customer Count
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</fo:table-header>		
	</xsl:template>

	<xsl:template name="summrow">
		<xsl:param name="manu" />
		<xsl:param name="model" />
		<xsl:param name="active" />
		<xsl:param name="discon" />

		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
					<xsl:value-of select="$manu" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
					<xsl:value-of select="$model" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($active, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($discon, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
		</fo:table-row>

	</xsl:template>

	<xsl:template name="detailheader">
		<xsl:param name="market" />
		<xsl:param name="marketname" />

		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="1.25in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="2.0in" />
		<fo:table-header>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="9" text-align="left">
					<fo:block xsl:use-attribute-sets="summary-headings">
						<xsl:value-of select="$market" />
						<xsl:value-of select="' - '" />
						<xsl:value-of select="$marketname" />
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings"  text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Account
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Account Name
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Service Number
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Disc Date
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Install Date
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Service Exp Date
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Manufacturer
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Model
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Equipment Serial
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</fo:table-header>		
	</xsl:template>
	
	<xsl:template name="detailrow">
		<xsl:param name="market" />
		<xsl:for-each select="/all_results/results[@name = 'detail']/row[cumrkt = $market]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:if test="./cycle &gt; '0' and ./account &gt; '0'">
							<xsl:value-of select="format-number(./cycle, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number(./account, '0000000')" />
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
					<fo:block>
						<xsl:value-of select="./fname" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./lname" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:if test="./cnpa &gt; '0' and ./cnxx &gt; '0'">
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="./cnpa" />
								<xsl:with-param name="nxx" select="./cnxx" />
								<xsl:with-param name="line" select="./cline" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:if test="./dcmm &gt; '0' and ./dcmm != '99'">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./dccc" />
								<xsl:with-param name="yy" select="./dcyy" />
								<xsl:with-param name="mm" select="./dcmm" />
								<xsl:with-param name="dd" select="./dcdd" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:if test="./inmm &gt; '0' and ./inmm != '99'">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./incc" />
								<xsl:with-param name="yy" select="./inyy" />
								<xsl:with-param name="mm" select="./inmm" />
								<xsl:with-param name="dd" select="./indd" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:if test="./scexmm &gt; '0' and ./scexmm != '99'">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./scexcc" />
								<xsl:with-param name="yy" select="./scexyy" />
								<xsl:with-param name="mm" select="./scexmm" />
								<xsl:with-param name="dd" select="./scexdd" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
					<fo:block>
						<xsl:value-of select="./mfgmdl" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
					<fo:block>
						<xsl:value-of select="./eqpdsc" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
					<xsl:choose>
					<xsl:when test="normalize-space(./meid) &gt; ''">
						<fo:block>
							<xsl:value-of select="'MEID: '" />
							<xsl:value-of select="./meid" />
						</fo:block>
						<xsl:if test="string-length(./meid) = 14" >
							<xsl:variable name="altser" select="convert:getMEIDHexToDecimal(./meid)" />
							<fo:block>
								<xsl:value-of select="'Dec MEID: '" />
								<xsl:value-of select="$altser" />
							</fo:block>						
						</xsl:if>
						<xsl:if test="string-length(./meid) = 18" >
							<xsl:variable name="altser" select="convert:getMEIDDecimalToHex(./meid)" />
							<fo:block>
								<xsl:value-of select="'Hex MEID: '" />
								<xsl:value-of select="$altser" />
							</fo:block>						
						</xsl:if>						
					</xsl:when>
					<xsl:when test="normalize-space(./imei) &gt; '' and ./imei &gt; 1">
						<fo:block>
							<xsl:value-of select="'IMEI: '" />
							<xsl:value-of select="./imei" />
						</fo:block>
					</xsl:when>		
					<xsl:when test="normalize-space(./esn) &gt; '' and ./esn &gt; 1">
						<fo:block>
							<xsl:value-of select="'ESN: '" />
							<xsl:value-of select="./esn" />
						</fo:block>
					</xsl:when>													
					<xsl:otherwise>
						<fo:block>
							<xsl:value-of select="'Other: '" />
							<xsl:value-of select="./serial" />
						</fo:block>
					</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
