<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:convert="java:com.psasoft.util.ConversionUtilities"								
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/> 
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="'User Defined Fields Report'" />
	
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	
	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="$report_type = 1 and exists(/all_results/results[@name = 'summary']/row)">
				<xsl:for-each-group select="/all_results/results[@name = 'summary']/row" group-by="cumrkt">
					<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
					<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />	
							
					<xsl:for-each-group select="/all_results/results[@name = 'summary']/row[cumrkt = $market]" group-by="udfmsid">
						<xsl:sort select="udflevl" />
						<xsl:sort select="udftext" />
					
						<xsl:variable name="udfmaster" select="current-group()[position() = 1]/udfmsid" />
						<xsl:variable name="udflevel" select="current-group()[position() = 1]/udflevl" />
						<xsl:variable name="udftext" select="current-group()[position() = 1]/udftext" />

						<fo:table table-layout="fixed" width="100%" space-before="16px">
							<xsl:call-template name="sumheader">
								<xsl:with-param name="market" select="$market" />
								<xsl:with-param name="marketname" select="$marketname" />						
								<xsl:with-param name="udflevel" select="$udflevel" />						
								<xsl:with-param name="udftext" select="$udftext" />						
							</xsl:call-template>
							<fo:table-body>
								
							<xsl:for-each select="/all_results/results[@name = 'summary']/row[cumrkt = $market and udfmsid = $udfmaster]">					
								<xsl:call-template name="summrow">
									<xsl:with-param name="udfentry" select="./udfentry" />
									<xsl:with-param name="count" select="./cnt" />
								</xsl:call-template>
							</xsl:for-each>
							</fo:table-body>
						</fo:table>
					</xsl:for-each-group>
				</xsl:for-each-group>
			</xsl:when>
			<xsl:when test="($report_type = 2 or $report_type = 3) and exists(/all_results/results[@name = 'detail']/row)">
				<xsl:for-each-group select="/all_results/results[@name = 'detail']/row" group-by="cumrkt">
					<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
					<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />

					<xsl:call-template name="detailrow">
						<xsl:with-param name="market" select="$market" />
						<xsl:with-param name="marketname" select="$marketname" />						
					</xsl:call-template>

				</xsl:for-each-group>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>No Accounts or Services Found for selection(s)</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="sumheader">
		<xsl:param name="market" />
		<xsl:param name="marketname" />
		<xsl:param name="udflevel" />
		<xsl:param name="udftext" />
			
		<fo:table-column column-width="3.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="2" text-align="left">
					<fo:block xsl:use-attribute-sets="summary-headings">
						<xsl:value-of select="$market" />
						<xsl:value-of select="' - '" />
						<xsl:value-of select="$marketname" />
					</fo:block>
				</fo:table-cell>
			</fo:table-row>		
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings"  text-align="left">
					<fo:block xsl:use-attribute-sets="summary-headings">
						<xsl:choose>
						<xsl:when test="$udflevel = 'A'">
							<xsl:value-of select="'Account - '" />
						</xsl:when>
						<xsl:when test="$udflevel = 'S'">
							<xsl:value-of select="'Service - '" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$udflevel" />
							<xsl:value-of select="' - '" />
						</xsl:otherwise>
						</xsl:choose>
						<xsl:value-of select="$udftext" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Count
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</fo:table-header>		
	</xsl:template>

	<xsl:template name="summrow">
		<xsl:param name="udfentry" />
		<xsl:param name="count" />

		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
					<xsl:value-of select="$udfentry" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($count, '##,###,##0')" />
				</fo:block>
			</fo:table-cell>
		</fo:table-row>

	</xsl:template>
	
	<xsl:template name="detailrow">
		<xsl:param name="market" />
		<xsl:param name="marketname" />
		
		<xsl:for-each-group select="/all_results/results[@name = 'detail']/row[cumrkt = $market]" group-by="udfmsid">
			<xsl:sort select="udflevl" />
			<xsl:sort select="udftext" />

			<xsl:variable name="udfmaster" select="current-group()[position() = 1]/udfmsid" />
			<xsl:variable name="udflevel" select="current-group()[position() = 1]/udflevl" />
			<xsl:variable name="udftext" select="current-group()[position() = 1]/udftext" />		

			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<xsl:call-template name="detailheader">
					<xsl:with-param name="market" select="$market" />
					<xsl:with-param name="marketname" select="$marketname" />
					<xsl:with-param name="udflevel" select="$udflevel" />						
					<xsl:with-param name="udftext" select="$udftext" />	
				</xsl:call-template>
				<fo:table-body>		

					<xsl:choose>
					<xsl:when test="$udflevel = 'S'">					
						<xsl:call-template name="detailservicerow">
							<xsl:with-param name="market" select="$market" />
							<xsl:with-param name="udfmaster" select="$udfmaster" />
						</xsl:call-template>
					</xsl:when>
					
					<xsl:otherwise>
						<xsl:call-template name="detailaccountrow">
							<xsl:with-param name="market" select="$market" />
							<xsl:with-param name="udfmaster" select="$udfmaster" />
						</xsl:call-template>					
					</xsl:otherwise>
					</xsl:choose>
				</fo:table-body>
			</fo:table>
		</xsl:for-each-group>
				
	</xsl:template>
	
	<xsl:template name="detailheader">
		<xsl:param name="market" />
		<xsl:param name="marketname" />
		<xsl:param name="udflevel" />						
		<xsl:param name="udftext" />	

		<xsl:choose>
		<xsl:when test="$udflevel = 'S'">		
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="8" text-align="left">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="$market" />
							<xsl:value-of select="' - '" />
							<xsl:value-of select="$marketname" />						
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings"  text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Account
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Account Name
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Service Number
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Disconnected Date
						</fo:block>
					</fo:table-cell>
					<xsl:if test="$report_type = 2">
						<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
							<fo:block xsl:use-attribute-sets="summary-headings">
								Account Address
							</fo:block>
						</fo:table-cell>					
					</xsl:if>
					<xsl:if test="$report_type = 3">
						<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
							<fo:block xsl:use-attribute-sets="summary-headings">
								Equipment Serial
							</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Curr Plan						
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Plan Rate						
						</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="$udftext" />						
						</fo:block>
					</fo:table-cell>					
				</fo:table-row>
			</fo:table-header>	
		
		</xsl:when>
		<xsl:otherwise>
			<xsl:variable name="cols">
				<xsl:choose>
				<xsl:when test="$report_type = 2" >
					<xsl:value-of select="4"/>
				</xsl:when>											
				<xsl:otherwise>
					<xsl:value-of select="3"/>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
					
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="2.0in" />
			<xsl:if test="$report_type = 2">
				<fo:table-column column-width="2.0in" />
			</xsl:if>
			<fo:table-column column-width="0.75in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="2.0in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="{$cols}" text-align="left">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="$market" />
							<xsl:value-of select="' - '" />
							<xsl:value-of select="$marketname" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings"  text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Account
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							Account Name
						</fo:block>
					</fo:table-cell>
					<xsl:if test="$report_type = 2">
						<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
							<fo:block xsl:use-attribute-sets="summary-headings">
								Account Address
							</fo:block>
						</fo:table-cell>
					</xsl:if>										
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="$udftext" />						
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>			
		</xsl:otherwise>
		</xsl:choose>
			
	</xsl:template>

	<xsl:template name="detailservicerow">
		<xsl:param name="market" />
		<xsl:param name="udfmaster" />
	
		<xsl:for-each select="/all_results/results[@name = 'detail']/row[cumrkt = $market and udfmsid = $udfmaster]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:choose>
						<xsl:when test="normalize-space(./cycle) &gt; '' and normalize-space(./account) &gt; '' and ./cycle &gt; 0 and ./account &gt; 0">
							<xsl:value-of select="format-number(./cycle, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number(./account, '0000000')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="' '" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="./fname" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./lname" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:if test="normalize-space(./cnpa) &gt; '' and normalize-space(./cnxx) &gt; '' and ./cnpa &gt; 0 and ./cnxx &gt; 0">
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="./cnpa" />
								<xsl:with-param name="nxx" select="./cnxx" />
								<xsl:with-param name="line" select="./cline" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:if test="normalize-space(./dcmm) &gt; '' and ./dcmm &gt; 0 and ./dcmm != 99">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="./dccc" />
								<xsl:with-param name="yy" select="./dcyy" />
								<xsl:with-param name="mm" select="./dcmm" />
								<xsl:with-param name="dd" select="./dcdd" />
							</xsl:call-template>
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>
				<xsl:if test="$report_type = 2">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<xsl:if test="normalize-space(./adln1)">
							<fo:block>
								<xsl:value-of select="./adln1" />
							</fo:block>
						</xsl:if>
						<xsl:if test="normalize-space(./adln2)">
							<fo:block>
								<xsl:value-of select="./adln2" />
							</fo:block>
						</xsl:if>
						<xsl:if test="normalize-space(./adln3)">
							<fo:block>
								<xsl:value-of select="./adln3" />
							</fo:block>
						</xsl:if>
						<fo:block>
							<xsl:value-of select="./adcity" />
							<xsl:value-of select="', '" />
							<xsl:value-of select="./adst" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="substring(./adzip, 1, 5)" />
							<xsl:if test="substring(./adzip, 6, 4) != '0000'">
								<xsl:value-of select="'-'" />
								<xsl:value-of select="substring(./adzip, 6, 4)" />
							</xsl:if>
						</fo:block>	
					</fo:table-cell>				
				</xsl:if>
				<xsl:if test="$report_type = 3">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<xsl:choose>
						<xsl:when test="normalize-space(./meid) &gt; ''">
							<fo:block>
								<xsl:value-of select="'MEID: '" />
								<xsl:value-of select="./meid" />
							</fo:block>
							<xsl:if test="string-length(./meid) = 14" >
								<xsl:variable name="altser" select="convert:getMEIDHexToDecimal(./meid)" />
								<fo:block>
									<xsl:value-of select="'Dec MEID: '" />
									<xsl:value-of select="$altser" />
								</fo:block>						
							</xsl:if>
							<xsl:if test="string-length(./meid) = 18" >
								<xsl:variable name="altser" select="convert:getMEIDDecimalToHex(./meid)" />
								<fo:block>
									<xsl:value-of select="'Hex MEID: '" />
									<xsl:value-of select="$altser" />
								</fo:block>						
							</xsl:if>						
						</xsl:when>
						<xsl:when test="normalize-space(./imei) &gt; '' and ./imei &gt; 1">
							<fo:block>
								<xsl:value-of select="'IMEI: '" />
								<xsl:value-of select="./imei" />
							</fo:block>
						</xsl:when>		
						<xsl:when test="normalize-space(./esn) &gt; '' and ./esn &gt; 1">
							<fo:block>
								<xsl:value-of select="'ESN: '" />
								<xsl:value-of select="./esn" />
							</fo:block>
						</xsl:when>													
						<xsl:otherwise>
							<xsl:value-of select="'Other: '" />
							<xsl:value-of select="./serial" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:table-cell>
				</xsl:if>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./plan" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:if test="./itmrat > ''">
							<xsl:value-of select="format-number(./itmrat, '##,##0.00;$ -#,##0.00')"/>
						</xsl:if>
					</fo:block>
				</fo:table-cell>								
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="./udfentry" />
					</fo:block>
				</fo:table-cell>				
			</fo:table-row>
		</xsl:for-each>	
	</xsl:template>
	
	<xsl:template name="detailaccountrow">
		<xsl:param name="market" />
		<xsl:param name="udfmaster" />
	
		<xsl:for-each select="/all_results/results[@name = 'detail']/row[cumrkt = $market and udfmsid = $udfmaster]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:choose>
						<xsl:when test="normalize-space(./cycle) &gt; '' and normalize-space(./account) &gt; '' and ./cycle &gt; 0 and ./account &gt; 0">
							<xsl:value-of select="format-number(./cycle, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number(./account, '0000000')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="' '" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="./fname" />
						<xsl:value-of select="' '" />
						<xsl:value-of select="./lname" />
					</fo:block>
				</fo:table-cell>
				<xsl:if test="$report_type = 2">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<xsl:if test="normalize-space(./adln1)">
								<fo:block>
										<xsl:value-of select="./adln1" />
								</fo:block>
						</xsl:if>
						<xsl:if test="normalize-space(./adln2)">
								<fo:block>
										<xsl:value-of select="./adln2" />
								</fo:block>
						</xsl:if>
						<xsl:if test="normalize-space(./adln3)">
								<fo:block>
										<xsl:value-of select="./adln3" />
								</fo:block>
						</xsl:if>
						<fo:block>
								<xsl:value-of select="./adcity" />
								<xsl:value-of select="', '" />
								<xsl:value-of select="./adst" />
								<xsl:value-of select="' '" />
								<xsl:value-of select="substring(./adzip, 1, 5)" />
								<xsl:if test="substring(./adzip, 6, 4) != '0000'">
										<xsl:value-of select="'-'" />
										<xsl:value-of select="substring(./adzip, 6, 4)" />
								</xsl:if>
						</fo:block>	
					</fo:table-cell>				
				</xsl:if>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="./udfentry" />
					</fo:block>
				</fo:table-cell>				
			</fo:table-row>
		</xsl:for-each>	
	</xsl:template>	
</xsl:stylesheet>
