<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: datadetail.xsl,v 1.23 2017-02-23 17:55:12 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:util="java:com.psasoft.util.DelegateUtilities"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  <xsl:import href="callsummary.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Data Usage Report'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set-landscape" />
		<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acct']/row"/>
	</xsl:call-template>
	<xsl:variable name="rating" select="util:getDataAreaString('RATING')" />
	<xsl:if test="$rating != 'N'">
		<fo:block xsl:use-attribute-sets="component-1" color="red">
			** NOTE ** - Rating is in progress.  Information subject to change
		</fo:block>
	</xsl:if>	
	<xsl:if test="$customerCode = 'NWMC' or $customerCode = 'nwmc'">
		<fo:block xsl:use-attribute-sets="component-1" color="red">
			** NOTE ** - This report does not reflect real time customer usage. Only usage records that have been processed will be displayed.  Therefore, you may have outstanding usage that could affect your plan.
		</fo:block>
	</xsl:if>
	
	<xsl:call-template name="datasum-new" />

	<xsl:call-template name="data-detail">
		<xsl:with-param name="from-web" select="'N'" />
	</xsl:call-template>

	<xsl:call-template name="aaahist" />	
	
</xsl:template>	
	
<xsl:template name="data-detail">
	<xsl:param name="from-web" />
	<xsl:choose>
		<xsl:when test="exists(/all_results/results[@name = 'datadetail']/row)">
			<fo:block xsl:use-attribute-sets="summary-headings" space-before="30px" space-after="7px">
				<xsl:value-of select="'Detail For Service#: '" />
				<xsl:call-template name="phone">
					<xsl:with-param name="npa" select="/all_results/results[@name = 'datadetail']/row[position() = 1]/cnpa"/>
					<xsl:with-param name="nxx" select="/all_results/results[@name = 'datadetail']/row[position() = 1]/cnxx"/>
					<xsl:with-param name="line" select="/all_results/results[@name = 'datadetail']/row[position() = 1]/cline"/>
				</xsl:call-template>
			</fo:block>
			
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<xsl:if test="$from-web = 'N'">
					<fo:table-column column-width="0.2in" />
				</xsl:if>
				<fo:table-column column-width="0.2in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="1.30in" />
				<fo:table-column column-width="0.70in" />
				<fo:table-column column-width="0.25in" />
				<xsl:if test="$from-web = 'N'">
					<fo:table-column column-width="0.70in" />
				</xsl:if>
				<fo:table-column column-width="0.70in" />
				<fo:table-column column-width="0.75in" />
				<xsl:if test="$from-web = 'N'">
					<fo:table-column column-width="1.0in" />
				</xsl:if>
				<xsl:if test="$from-web = 'Y'">
					<fo:table-column column-width="1.5in" />
				</xsl:if>
				<fo:table-column column-width="0.25in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="1.05in" />
				<fo:table-column column-width="0.45in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-header>
					<xsl:if test="$from-web = 'N'">
						<fo:table-row>
							<fo:table-cell number-columns-spanned="15">
								<fo:block>* = Denotes data certificate code</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:if>
					<fo:table-row keep-with-next="always">
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Rt</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>To</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Called Number</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Called Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Place</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>St</fo:block>
						</fo:table-cell>
						<xsl:if test="$from-web = 'N'">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>Srv Sid</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Origin</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Caller ID</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Data Feature</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Unit</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Unit Count</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Network Id</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Desc</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Charges</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'datadetail']/row">
						<xsl:variable name="certcount">
							<xsl:choose>
								<xsl:when test="./ctcert1 = ''">
									<xsl:value-of select="0"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./dqtytp = ./ctqtytp1">
									<xsl:value-of select="./ctusg1"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'BT' and ./dqtytp = 'KB' ">
									<xsl:value-of select="./ctusg1 div 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'BT' and ./dqtytp = 'MB' ">
									<xsl:value-of select="./ctusg1 div (1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'BT' and ./dqtytp = 'GB' ">
									<xsl:value-of select="./ctusg1 div (1024 * 1024 * 1024)"/>
								</xsl:when>
								
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'KB' and ./dqtytp = 'BT' ">
									<xsl:value-of select="./ctusg1 * 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'KB' and ./dqtytp = 'MB' ">
									<xsl:value-of select="./ctusg1 div 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'KB' and ./dqtytp = 'GB' ">
									<xsl:value-of select="./ctusg1 div (1024 * 1024)"/>
								</xsl:when>

								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'MB' and ./dqtytp = 'BT' ">
									<xsl:value-of select="./ctusg1 * (1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'MB' and ./dqtytp = 'KB' ">
									<xsl:value-of select="./ctusg1 * 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'MB' and ./dqtytp = 'GB' ">
									<xsl:value-of select="./ctusg1 div 1024"/>
								</xsl:when>

								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'GB' and ./dqtytp = 'BT' ">
									<xsl:value-of select="./ctusg1 * (1024 * 1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'GB' and ./dqtytp = 'KB' ">
									<xsl:value-of select="./ctusg1 * (1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert1 &gt; '' and ./ctqtytp1 = 'GB' and ./dqtytp = 'MB' ">
									<xsl:value-of select="./ctusg1 * 1024"/>
								</xsl:when>
								
								<xsl:otherwise>
									<xsl:value-of select="0"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="certcount2">
							<xsl:choose>
								<xsl:when test="./ctcert2 = ''">
									<xsl:value-of select="0"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./dqtytp = ./ctqtytp2">
									<xsl:value-of select="./ctusg2"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'BT' and ./dqtytp = 'KB' ">
									<xsl:value-of select="./ctusg2 div 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'BT' and ./dqtytp = 'MB' ">
									<xsl:value-of select="./ctusg2 div (1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'BT' and ./dqtytp = 'GB' ">
									<xsl:value-of select="./ctusg2 div (1024 * 1024 * 1024)"/>
								</xsl:when>
								
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'KB' and ./dqtytp = 'BT' ">
									<xsl:value-of select="./ctusg2 * 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'KB' and ./dqtytp = 'MB' ">
									<xsl:value-of select="./ctusg2 div 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'KB' and ./dqtytp = 'GB' ">
									<xsl:value-of select="./ctusg2 div (1024 * 1024)"/>
								</xsl:when>

								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'MB' and ./dqtytp = 'BT' ">
									<xsl:value-of select="./ctusg2 * (1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'MB' and ./dqtytp = 'KB' ">
									<xsl:value-of select="./ctusg2 * 1024"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'MB' and ./dqtytp = 'GB' ">
									<xsl:value-of select="./ctusg2 div 1024"/>
								</xsl:when>

								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'GB' and ./dqtytp = 'BT' ">
									<xsl:value-of select="./ctusg2 * (1024 * 1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'GB' and ./dqtytp = 'KB' ">
									<xsl:value-of select="./ctusg2 * (1024 * 1024)"/>
								</xsl:when>
								<xsl:when test="./ctcert2 &gt; '' and ./ctqtytp2 = 'GB' and ./dqtytp = 'MB' ">
									<xsl:value-of select="./ctusg2 * 1024"/>
								</xsl:when>								
								<xsl:otherwise>
									<xsl:value-of select="0"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="unitcount">
							<xsl:choose>
								<xsl:when test="./unitcount and ./dqtytp = 'EA'">
									<xsl:value-of select="format-number(./unitcount, '###,##0;-##,##0')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = ./ctqtytp1 and ./ctcert1 &gt; ''">
									<xsl:value-of select="format-number(./adj_unitcount - ./ctusg1, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>								
								<xsl:when test="./adj_unitcount and ./dqtytp = 'BT' and ./ctcert1 &gt; ''">
									<xsl:value-of select="format-number(./adj_unitcount - $certcount - $certcount2, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = 'KB' and ./ctcert1 &gt; ''">
									<xsl:value-of select="format-number(./adj_unitcount - $certcount - $certcount2, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = 'MB' and ./ctcert1 &gt; ''">
									<xsl:value-of select="format-number(./adj_unitcount - $certcount - $certcount2, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = 'GB' and ./ctcert1 &gt; ''">
									<xsl:value-of select="format-number(./adj_unitcount - $certcount - $certcount2, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = 'BT'">
									<xsl:value-of select="format-number(./adj_unitcount, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = 'KB'">
									<xsl:value-of select="format-number(./adj_unitcount, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = 'MB'">
									<xsl:value-of select="format-number(./adj_unitcount, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:when test="./adj_unitcount and ./dqtytp = 'GB'">
									<xsl:value-of select="format-number(./adj_unitcount, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(./unitcount, '###,##0;-##,##0')" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<fo:table-row>
							<xsl:if test="$from-web = 'N'">
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:choose>
											<xsl:when test="./rated = '1'">
												<xsl:value-of select="'Y'" />
											</xsl:when>
											<xsl:when test="./rated = '-1'">
												<xsl:value-of select="'-'" />
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="'N'" />
											</xsl:otherwise>
										</xsl:choose>
									</fo:block>
								</fo:table-cell>
							</xsl:if>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<xsl:choose>
									<xsl:when test="./cldi = '1' or ./cldi = '2' or ./cldi = '3' or ./cldi = '4' ">
										<fo:block>
											<xsl:value-of select="'R'" />
										</fo:block>
									</xsl:when>
									<xsl:when test="./cldi = '6' or ./cldi = '7' or ./cldi = '8' or ./cldi = '9' ">
										<fo:block>
											<xsl:value-of select="'H'" />
										</fo:block>
									</xsl:when>
									<xsl:otherwise>
										<fo:block>
											<xsl:value-of select="'-'" />
										</fo:block>
									</xsl:otherwise>
								</xsl:choose>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:choose>
										<xsl:when test="./cdnpa != 0 and ./cdnxx != 0">
											<xsl:value-of select="'('" />
											<xsl:value-of select="format-number(./cdnpa, '000')" />
											<xsl:value-of select="')'" />
											<xsl:value-of select="format-number(./cdnxx, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number(./cdline, '0000')" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:if test="./cdnpa != 0">
												<xsl:value-of select="./cdnpa" />
												<xsl:value-of select="' '" />
											</xsl:if>
											<xsl:if test="./cdnxx != 0">
												<xsl:value-of select="./cdnxx" />
												<xsl:value-of select="' '" />
											</xsl:if>
											<xsl:if test="./cdline != 0">
												<xsl:value-of select="./cdline" />
											</xsl:if>
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:choose>
									<xsl:when test="./rated = -1">
										<xsl:value-of select="'-'" />
									</xsl:when>
									<xsl:when test="./cdcc != 0 and ./cdyy != 0 and ./cdmm != 0 and ./cddd != 0">
										<xsl:value-of select="format-number(./cdmm, '00')" />
										<xsl:value-of select="'/'" />
										<xsl:value-of select="format-number(./cddd, '00')" />
										<xsl:value-of select="'/'" />
										<xsl:value-of select="format-number(./cdcc, '00')" />
										<xsl:value-of select="format-number(./cdyy, '00')" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="format-number(./c1cnhh, '00')" />
										<xsl:value-of select="':'" />
										<xsl:value-of select="format-number(./c1cnmm, '00')" />
										<xsl:value-of select="':'" />
										<xsl:value-of select="format-number(./c1cnss, '00')" />
									</xsl:when>
									</xsl:choose>
									<xsl:value-of select="' '" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./svpc" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
									<xsl:value-of select="./svst" />
								</fo:block>
							</fo:table-cell>
							<xsl:if test="$from-web = 'N'">
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:choose>
										<xsl:when test="./svsid = 0">
											<xsl:value-of select="'-'" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="./svsid" />
										</xsl:otherwise>
										</xsl:choose>
									</fo:block>
								</fo:table-cell>
							</xsl:if>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">  
								<xsl:choose>
									<xsl:when test="./cldi = '1' or ./cldi = '6'">
										<fo:block font-size="7pt">
											<xsl:value-of select="./svpc" />
										</fo:block>
									</xsl:when>
									<xsl:when test="./cldi = '2' or ./cldi = '7'">
										<fo:block>
											<xsl:value-of select="'Incoming'" />
										</fo:block>
									</xsl:when>
									<xsl:otherwise>
										<fo:block>
											<xsl:value-of select="'-'" />
										</fo:block>
									</xsl:otherwise>
								</xsl:choose>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">  
								<fo:block>
									<xsl:choose>
										<xsl:when test="./cinpa != 0 and ./cinxx != 0">
											<xsl:value-of select="'('" />
											<xsl:value-of select="format-number(./cinpa, '000')" />
											<xsl:value-of select="')'" />
											<xsl:value-of select="format-number(./cinxx, '000')" />
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number(./ciline, '0000')" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:if test="./cinpa != 0">
												<xsl:value-of select="./cinpa" />
												<xsl:value-of select="' '" />
											</xsl:if>
											<xsl:if test="./cinxx != 0">
												<xsl:value-of select="./cinxx" />
												<xsl:value-of select="' '" />
											</xsl:if>
											<xsl:if test="./ciline != 0">
												<xsl:value-of select="./ciline" />
											</xsl:if>
										</xsl:otherwise>
									</xsl:choose>
								</fo:block>
							</fo:table-cell>
							<xsl:choose>
								<xsl:when test="./c1in = 12 and ./itmdsc = ''">
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
										<fo:block>
											<xsl:value-of select="' - '" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
										<fo:block>
											<xsl:value-of select="' - '" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./msacdg, '###,##0;-##,##0')" />
										</fo:block>
									</fo:table-cell>
								</xsl:when>
								<xsl:when test="./c1in != 12">
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
										<xsl:if test="./ctcert1 &gt; ''"> 
											<fo:block>
												<xsl:value-of select="./chargedesc" />
												<xsl:value-of select="' - '" />
												<xsl:if test="$from-web = 'N'">
													<xsl:value-of select="./ctcert1" />
												</xsl:if>
												<xsl:if test="$from-web = 'Y'">
													<xsl:value-of select="./crtdsc"/>
												</xsl:if>
											</fo:block>
										</xsl:if>									
										<xsl:if test="./ctcert2 &gt; ''"> 
											<fo:block>
												<xsl:value-of select="./chargedesc" />
												<xsl:value-of select="' - '" />
												<xsl:if test="$from-web = 'N'">
													<xsl:value-of select="./ctcert2" />
												</xsl:if>
												<xsl:if test="$from-web = 'Y'">
													<xsl:value-of select="./crtdsc2"/>
												</xsl:if>
											</fo:block>
										</xsl:if>									
										<xsl:if test="./dataft &gt; ''">
											<fo:block>
												<xsl:value-of select="./chargedesc" />
												<xsl:value-of select="' - '" />
												<xsl:if test="$from-web = 'N'">
													<xsl:value-of select="./dataft" />
												</xsl:if>
												<xsl:if test="$from-web = 'Y'">
													<xsl:value-of select="./itmdsc"/>
												</xsl:if>
											</fo:block>
										</xsl:if>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
										<xsl:if test="./ctcert1 &gt; ''"> 
											<fo:block>
												<xsl:value-of select="./ctqtytp1" />
											</fo:block>
										</xsl:if>											
										<xsl:if test="./dataft &gt; ''">									
											<fo:block>
												<xsl:choose>
													<xsl:when test="$from-web = 'Y' and ((./rated = 1 and ./qtytyp = 'EA') or (./rated != 1 and ./dqtyty = '') or ./dqtyty = 'EA')" >										
														<xsl:value-of select="'EA'"/>
													</xsl:when>
													<xsl:when test="./rated = '1'">
														<xsl:value-of select="./qtytyp" />
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="./dqtyty" />
													</xsl:otherwise>
												</xsl:choose>
											</fo:block>
										</xsl:if>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
										<xsl:if test="./ctcert1 &gt; ''"> 
											<fo:block>
												<xsl:value-of select="format-number(./ctusg1, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
											</fo:block>
										</xsl:if>											
										<xsl:if test="./ctcert2 &gt; ''"> 
											<fo:block>
												<xsl:value-of select="format-number(./ctusg2, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
											</fo:block>
										</xsl:if>											
										<xsl:if test="./dataft &gt; ''">									
											<fo:block>
												<xsl:value-of select="$unitcount" />
											</fo:block>
										</xsl:if>
									</fo:table-cell>
								</xsl:when>
								<xsl:otherwise>
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
										<fo:block>
											<xsl:value-of select="./chargedesc" />
											<xsl:value-of select="' - '" />
											<xsl:if test="$from-web = 'N'">
												<xsl:value-of select="./dataft" />
											</xsl:if>
											<xsl:if test="$from-web = 'Y'">
												<xsl:value-of select="./itmdsc"/>
											</xsl:if>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
										<fo:block>
											<xsl:choose>
												<xsl:when test="$from-web = 'Y' and ((./rated = 1 and ./qtytyp = 'EA') or (./rated != 1 and ./dqtyty = '') or ./dqtyty = 'EA')" >										
													<xsl:value-of select="'EA'"/>
												</xsl:when>
												<xsl:when test="$from-web = 'Y'">
													<xsl:value-of select="'KB'"/>
												</xsl:when>
												<xsl:when test="./rated = '1'">
													<xsl:value-of select="./qtytyp" />
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="./dqtyty" />
												</xsl:otherwise>
											</xsl:choose>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
										<xsl:if test="./ctcert1 &gt; ''"> 
											<fo:block>
												<xsl:value-of select="format-number(./ctusg1, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
											</fo:block>
										</xsl:if>									
										<xsl:if test="./ctcert2 &gt; ''"> 
											<fo:block>
												<xsl:value-of select="format-number(./ctusg2, '###,###,###,##0.000000;-##,###,###,##0.000000')" />
											</fo:block>
										</xsl:if>									
										<xsl:if test="./dataft &gt; ''">
											<fo:block>
												<xsl:value-of select="$unitcount" />
											</fo:block>
										</xsl:if>
									</fo:table-cell>
								</xsl:otherwise>
							</xsl:choose>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center" font-size="4pt">
								<fo:block>
									<xsl:value-of select="./apnni" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center" font-size="4pt"> 
								<fo:block>
									<xsl:value-of select="./prtcll" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<xsl:if test="./ctcert1 &gt; ''"> 
									<fo:block>
										<xsl:value-of select="' - '" />
									</fo:block>
								</xsl:if>									
								<xsl:if test="./dataft &gt; ''">
									<fo:block>								
										<xsl:choose>
											<xsl:when test="./c1in = 12 and ./itmdsc = ''">
												<xsl:value-of select="' - '" />
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format-number(./c1cg, '###,##0.00;-##,##0.00')" />
											</xsl:otherwise>
										</xsl:choose>
									</fo:block>
								</xsl:if>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="3px"><xsl:value-of select="'   '" /></fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
</xsl:stylesheet>






