<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: disconnects.xsl,v 1.7 2016-06-09 20:29:39 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
   <xsl:import href="subtemplates.xsl"/> 
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="concat('Deactivations Report ', $disconnect_date[1], ' to ', $disconnect_date[2])" />  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set-landscape" />
		<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>

<xsl:template name="body_process">

	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'data']/row) and $sort_type = 1">
		<xsl:for-each-group select="/all_results/results[@name='data']/row" group-by="./cumrkt">
			<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />
	
			<xsl:for-each-group select="/all_results/results[@name='data']/row[cumrkt = $market]"  group-by="concat(./cnpa, ./cnxx)">
					<xsl:variable name="areacode" select="current-group()[position() = 1]/cnpa"/>
					<xsl:variable name="exchange" select="current-group()[position() = 1]/cnxx"/>
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="header">
							<xsl:with-param name="market" select="$market"/>
							<xsl:with-param name="marketname" select="$marketname"/>
							<xsl:with-param name="npa" select="$areacode"/>
							<xsl:with-param name="nxx" select="$exchange"/>
							<xsl:with-param name="agent" select="0"/>
							<xsl:with-param name="agbus" select="''"/>
							<xsl:with-param name="agfsnm" select="''"/>
							<xsl:with-param name="aglsnm" select="''"/>							
						</xsl:call-template>					
						<fo:table-body>
								<xsl:for-each select="/all_results/results[@name = 'data']/row[cumrkt = $market and cnpa = $areacode and cnxx = $exchange]">
										<xsl:call-template name="detail">
											<xsl:with-param name="row" select="."/>
										</xsl:call-template>							
							 </xsl:for-each>
							</fo:table-body>
					</fo:table>			
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="10px" space-after="10px">
		    				<xsl:value-of select="'Total Deactivations for Area Code / Exchange ( '"/>
		    				<xsl:value-of select="$areacode"/>
		    				<xsl:value-of select="'-'"/>
		    				<xsl:value-of select="$exchange"/>
		    				<xsl:value-of select="' ): '"/>
		    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cnpa = $areacode and cnxx = $exchange]), '###,##0')"/>
		    		</fo:block>		
		    								
				</xsl:for-each-group>	
	    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="0px" space-after="10px">
	    				<xsl:value-of select="'Total Activations for Market ( '"/>
	    				<xsl:value-of select="$market"/>
	    				<xsl:value-of select="' - '"/>
	    				<xsl:value-of select="$marketname"/>
	    				<xsl:value-of select="' ): '"/>
	    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market]), '###,##0')"/>
	    		</fo:block>	
	    							
			</xsl:for-each-group>			
			<fo:block xsl:use-attribute-sets="summary-headings">
					<xsl:value-of select="'Total Deactivations:  '"/>
					<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '###,##0')"/>
			</fo:block>								
		</xsl:when>

	<xsl:when test="exists(/all_results/results[@name = 'data']/row) and $sort_type = 2">
		<xsl:for-each-group select="/all_results/results[@name='data']/row" group-by="./cumrkt">
			<xsl:variable name="market" select="current-group()[position() = 1]/cumrkt" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />	
			
			<xsl:for-each-group select="/all_results/results[@name='data']/row[cumrkt = $market]"  group-by="./agcd1">
					<xsl:variable name="agent" select="current-group()[position() = 1]/agcd1"/>
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="header">
								<xsl:with-param name="market" select="$market"/>
								<xsl:with-param name="marketname" select="$marketname"/>
								<xsl:with-param name="npa" select="0"/>
								<xsl:with-param name="nxx" select="0"/>
								<xsl:with-param name="agent" select="$agent"/>
								<xsl:with-param name="agbus" select="./agbus"/>
								<xsl:with-param name="agfsnm" select="./agfsnm"/>
								<xsl:with-param name="aglsnm" select="./aglsnm"/>
						</xsl:call-template>					
						<fo:table-body>
								<xsl:for-each select="/all_results/results[@name = 'data']/row[cumrkt = $market and agcd1 = $agent]">
										<xsl:call-template name="detail">
											<xsl:with-param name="row" select="."/>
										</xsl:call-template>							
							 </xsl:for-each>
							</fo:table-body>
					</fo:table>			
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="10px" space-after="10px">
		    				<xsl:value-of select="'Total Deactivations for Agent ( '"/>
		    				<xsl:value-of select="$agent"/>
		    				<xsl:value-of select="' ): '"/>
		    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market and agcd1 = $agent]), '###,##0')"/>
		    		</fo:block>								
				</xsl:for-each-group>
							
	    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-previous="always" space-before="0px" space-after="10px">
	    				<xsl:value-of select="'Total Activations for Market ( '"/>
	    				<xsl:value-of select="$market"/>
	    				<xsl:value-of select="' - '"/>
	    				<xsl:value-of select="$marketname"/>
	    				<xsl:value-of select="' ): '"/>
	    				<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row[cumrkt = $market]), '###,##0')"/>
	    		</fo:block>	
	    							
			</xsl:for-each-group>						
			<fo:block xsl:use-attribute-sets="summary-headings">
					<xsl:value-of select="'Total Deactivations:  '"/>
					<xsl:value-of select="format-number(count(/all_results/results[@name = 'data']/row), '###,##0')"/>
			</fo:block>								
		</xsl:when>
		
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No Information Found
			</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="header">
	<xsl:param name="market" />
	<xsl:param name="marketname" />
	<xsl:param name="npa" />
	<xsl:param name="nxx" />
	<xsl:param name="agent" />
	<xsl:param name="agbus" />
	<xsl:param name="agfsnm" />
	<xsl:param name="aglsnm" />
	
	<fo:table-column column-width="0.75in" />
	<fo:table-column column-width="0.75in" />
	<fo:table-column column-width="1.00in" />
	<fo:table-column column-width="1.00in" />
	<fo:table-column column-width="2.00in" />
	<fo:table-column column-width="0.50in" />
	<fo:table-column column-width="1.5in" />
	<fo:table-column column-width="0.50in" />
	<fo:table-column column-width="0.50in" />
	<xsl:if test="$customerCode = 'BUGT' or $customerCode = 'bugt'">
		<fo:table-column column-width="1.50in" />
	</xsl:if>
	<fo:table-header>
		<fo:table-row keep-with-next="always">
			<fo:table-cell number-columns-spanned="9">
				<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always">
						<xsl:value-of select="'Market:  '"/>
						<xsl:value-of select="$market"/>
						<xsl:value-of select="' - '"/>
						<xsl:value-of select="$marketname"/>
				</fo:block>			
			</fo:table-cell>
		</fo:table-row>	
		<fo:table-row keep-with-next="always">
				<fo:table-cell number-columns-spanned="9">
					<xsl:choose>
							<xsl:when test="$npa > 0 and $nxx > 0">
									<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always">
											<xsl:value-of select="'Area Code / Exchange:  '"/>
											<xsl:value-of select="$npa"/>
											<xsl:value-of select="' - '"/>
											<xsl:value-of select="$nxx"/>
									</fo:block>			
							</xsl:when>
							<xsl:otherwise>
									<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always">
											<xsl:value-of select="'Agent:  '"/>
											<xsl:value-of select="$agent"/>
											<xsl:value-of select="' - '"/>
											<xsl:value-of select="$agbus"/>
											<xsl:value-of select="' '"/>
											<xsl:value-of select="$agfsnm"/>
											<xsl:value-of select="' '"/>
											<xsl:value-of select="$aglsnm"/>
									</fo:block>			
							</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
		</fo:table-row>		
		<fo:table-row keep-with-next="always">
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Connect Date</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Disconnect Date</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Account</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>MDN</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Customer Name</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Plan Code</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Disconnect Reason</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Agent Code</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Agent Type</fo:block>
			</fo:table-cell>
			<xsl:if test="$customerCode = 'BUGT' or $customerCode = 'bugt'">
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Tower Name</fo:block>
				</fo:table-cell>
			</xsl:if>
		</fo:table-row>
	</fo:table-header>
</xsl:template>

<xsl:template name="detail">
		<xsl:param name="row" />
		<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:call-template name="date4parm">
							<xsl:with-param name="cc" select="$row/cncc"/>
							<xsl:with-param name="yy" select="$row/cnyy"/>
							<xsl:with-param name="mm" select="$row/cnmm"/>
							<xsl:with-param name="dd" select="$row/cndd"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>	
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:call-template name="date4parm">
							<xsl:with-param name="cc" select="$row/dccc"/>
							<xsl:with-param name="yy" select="$row/dcyy"/>
							<xsl:with-param name="mm" select="$row/dcmm"/>
							<xsl:with-param name="dd" select="$row/dcdd"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>																			
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="format-number($row/cycle, '000')" />
						<xsl:value-of select="'-'" />
						<xsl:value-of select="format-number($row/account, '0000000')" />
					</fo:block>
				</fo:table-cell>																		
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:call-template name="phone">
							<xsl:with-param name="npa" select="$row/cnpa"/>
							<xsl:with-param name="nxx" select="$row/cnxx"/>
							<xsl:with-param name="line" select="$row/cline"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
							<xsl:value-of select="$row/fname" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="$row/lname" />									
					</fo:block>
				</fo:table-cell>	
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:choose>
						<xsl:when test="$row/plan > ''">
							<xsl:value-of select="$row/plan"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$row/crtpln" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>									
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="$row/dscdds"/>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="$row/agcd1"/>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="$row/agtype"/>
					</fo:block>
				</fo:table-cell>
				<xsl:if test="$customerCode = 'BUGT' or $customerCode = 'bugt'">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="$row/towerdesc"/>
						</fo:block>
					</fo:table-cell>
				</xsl:if>				
			</fo:table-row>			
</xsl:template>
		
		
</xsl:stylesheet>






