<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:xs="http://www.w3.org/2001/XMLSchema"
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Edit Provision Type Report ', $change_date_range[1], ' to ', $change_date_range[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'data']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="./name">
						<xsl:variable name="uname" select="current-group()[position() = 1]/uname"/>
						<xsl:variable name="name" select="current-group()[position() = 1]/name"/>
						<fo:table table-layout="fixed" width="100%" space-before="16px">
								<fo:table-column column-width="0.75in" />
								<fo:table-column column-width="0.75in" />
								<fo:table-column column-width="1.00in" />
								<fo:table-column column-width="0.75in" />
								<fo:table-column column-width="0.75in" />
								<fo:table-column column-width="0.75in" />
								<fo:table-column column-width="0.25in" />
								<fo:table-column column-width="0.50in" />
								<fo:table-column column-width="1.50in" />
								<fo:table-column column-width="0.50in" />
								<fo:table-column column-width="0.75in" />
								<fo:table-column column-width="0.50in" />
								<fo:table-column column-width="1.00in" />
								<fo:table-header>
										<fo:table-row keep-with-next="always">
												<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="13" text-align="left">
														<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
																<xsl:value-of select="'User: '"/>
																<xsl:value-of select="$uname"/>
																<xsl:value-of select="' - '"/>
																<xsl:value-of select="$name"/>
														</fo:block>		
												</fo:table-cell>
										</fo:table-row>
										<fo:table-row keep-with-next="always">
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Account
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														MDN
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Date Time
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Edit Type
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Contract Start
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Contract Expire
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Len
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Promo Code
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Plan
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Plan Rate
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Equipment
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Equip Sale Price
														</fo:block>
												</fo:table-cell>
												<fo:table-cell xsl:use-attribute-sets="table-headings">
														<fo:block>
														Serial
														</fo:block>
												</fo:table-cell>
										</fo:table-row>
								</fo:table-header>

								<fo:table-body>
									<xsl:call-template name="detailrow">
											<xsl:with-param name="name" select="$name"/>
									</xsl:call-template>									
							</fo:table-body>
						</fo:table>

				</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
					No Information Found
				</fo:block>		
		</xsl:otherwise>
		</xsl:choose>
</xsl:template>

<xsl:template name="detailrow">
		<xsl:param name="name" />    
  	
		<xsl:for-each select="/all_results/results[@name = 'data']/row[name = $name]">
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
								<fo:block>
										<xsl:if test="./cycle != 0 and ./acct != 0">
												<xsl:value-of select="format-number(./cycle, '000')" />
												<xsl:value-of select="'-'" />
												<xsl:value-of select="format-number(./acct, '0000000')" />																
										</xsl:if>
										<xsl:value-of select="' '"/>
								</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
									<xsl:if test="./cnpa != 0 and ./cnxx != 0">
											<xsl:call-template name="phone">
												<xsl:with-param name="npa" select="./cnpa"/>
												<xsl:with-param name="nxx" select="./cnxx"/>
												<xsl:with-param name="line" select="./cline"/>
											</xsl:call-template>															
									</xsl:if>							
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
									<xsl:value-of select="./auditdate" />		
									<xsl:value-of select="' '" />		
									<xsl:value-of select="./audittime" />					
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
							<fo:block>
									<xsl:value-of select="./edittype" />	
							</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./ctcstrdte > ''">
									<xsl:value-of select="format-date(./ctcstrdte cast as xs:date, '[M01]/[D01]/[Y0001]')" />	
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./scexcc > '0'">
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="./scexcc"/>
										<xsl:with-param name="yy" select="./scexyy"/>
										<xsl:with-param name="mm" select="./scexmm"/>
										<xsl:with-param name="dd" select="./scexdd"/>
									</xsl:call-template>						
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>										
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
									<xsl:value-of select="format-number(./ctclen, '##0')" />	
							</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
							<fo:block>
									<xsl:value-of select="./prmcod" />	
							</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
							<fo:block>
									<xsl:value-of select="./plan" />	
									<xsl:value-of select="' - '" />	
									<xsl:value-of select="./plandesc" />	
							</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./itmrat != ''">
											<xsl:value-of select="format-number(./itmrat, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="''"/>							
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
							<fo:block>
								<xsl:value-of select="./eqpdsc"/>
								<xsl:if test="normalize-space(./eqpdsc) != normalize-space(./mfgmdl)">
										<xsl:value-of select="' '"/>
										<xsl:value-of select="./mfgmdl"/>
								</xsl:if>
							</fo:block>
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
							<fo:block>
								<xsl:choose>
									<xsl:when test="./pitamt != ''">
											<xsl:value-of select="format-number(./pitamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="''"/>							
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
							<fo:block>
								<xsl:choose>
									<xsl:when test="normalize-space(./meid) > ''">
										<xsl:value-of select="./meid"/>							
									</xsl:when>
									<xsl:when test="normalize-space(./esn) > '' and ./esn != 0">
										<xsl:value-of select="format-number(./esn, '00000000000')"/>							
									</xsl:when>
									<xsl:when test="normalize-space(./imei) > '' and ./imei != 0">
										<xsl:value-of select="format-number(./imei, '000000000000000')"/>							
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="' '" />
									</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>									
						
			  </fo:table-row>
		</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
