<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: esnmeid.xsl,v 1.4 2014-07-16 15:34:37 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:saxon="http://saxon.sf.net/"
				xmlns:util="java:com.psasoft.util.ConversionUtilities"
				exclude-result-prefixes="java" 
				extension-element-prefixes="saxon"
				version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'ESN / MEID Conversions'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set"/>
		<xsl:call-template name="make-body"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:variable name="meiddec">
			<xsl:choose>
			<xsl:when test="string-length($serial) = 18">
					<xsl:value-of select="$serial"/>
			</xsl:when>
			<xsl:when test="string-length($serial) = 14">
					<xsl:value-of select="util:getMEIDHexToDecimal($serial)"/>
			</xsl:when>			
			<xsl:otherwise>
					<xsl:value-of select="'MEID Decimal Cannot be calculated'"/>
			</xsl:otherwise>
			</xsl:choose>		
	</xsl:variable>
	<xsl:variable name="meidhex">
			<xsl:choose>
			<xsl:when test="string-length($serial) = 14">
					<xsl:value-of select="$serial"/>
			</xsl:when>
			<xsl:when test="string-length($serial) = 18">
					<xsl:value-of select="util:getMEIDDecimalToHex($serial)"/>
			</xsl:when>			
			<xsl:otherwise>
					<xsl:value-of select="'MEID Hex Cannot be calculated'"/>
			</xsl:otherwise>
			</xsl:choose>		
	</xsl:variable>	
	<xsl:variable name="esn10">
			<xsl:choose>
			<xsl:when test="string-length($serial) = 10">
					<xsl:value-of select="$serial"/>
			</xsl:when>
			<xsl:when test="string-length($serial) = 11">
					<xsl:value-of select="util:getHexESNtoLength10(util:getESNtoHex($serial))"/>
			</xsl:when>
			<xsl:when test="string-length($serial) = 18">
					<xsl:value-of select="util:getHexESNtoLength10(util:getESNtoHex(util:getMEIDToESNDecimal($serial)))"/>
			</xsl:when>			
			<xsl:when test="string-length($serial) = 14">
					<xsl:value-of select="util:getHexESNtoLength10(util:getESNtoHex(util:getMEIDToESNDecimal($serial)))"/>
			</xsl:when>			
			<xsl:otherwise>
					<xsl:value-of select="'ESN Length 10 Cannot be calculated'"/>
			</xsl:otherwise>
			</xsl:choose>
	</xsl:variable>
	<xsl:variable name="esn11">
			<xsl:choose>
			<xsl:when test="string-length($serial) = 18">
					<xsl:value-of select="util:getMEIDToESNDecimal($serial)"/>
			</xsl:when>			
			<xsl:when test="string-length($serial) = 14">
					<xsl:value-of select="util:getMEIDToESNDecimal($serial)"/>
			</xsl:when>			
			<xsl:when test="string-length($serial) = 11">
					<xsl:value-of select="$serial"/>
			</xsl:when>
			<xsl:when test="string-length($serial) = 10">
					<xsl:value-of select="util:getESN11fromESN10($serial)"/>
			</xsl:when>
			<xsl:otherwise>
					<xsl:value-of select="'ESN Length 11 Cannot be calculated'"/>
			</xsl:otherwise>
			</xsl:choose>	
	</xsl:variable>	
	<xsl:variable name="esnhex">
			<xsl:choose>
			<xsl:when test="string-length($serial) = 18">
					<xsl:value-of select="util:getMEIDToESNHex($serial)"/>
			</xsl:when>			
			<xsl:when test="string-length($serial) = 14">
					<xsl:value-of select="util:getESNtoHex(util:getMEIDToESNDecimal($serial))"/>
			</xsl:when>			
			<xsl:when test="string-length($serial) = 8">
					<xsl:value-of select="$serial"/>
			</xsl:when>
			<xsl:when test="string-length($serial) = 11">
					<xsl:value-of select="util:getESNtoHex($serial)"/>
			</xsl:when>	
			<xsl:when test="string-length($serial) = 10">
					<xsl:value-of select="util:getESNtoHex($serial)"/>
			</xsl:when>		
			<xsl:otherwise>
					<xsl:value-of select="'ESN Hex Cannot be calculated'"/>
			</xsl:otherwise>
			</xsl:choose>	
	</xsl:variable>	
	
	<fo:table table-layout="fixed" width="100%" space-before="8px">
		<fo:table-column column-width="2.0in" />
		<fo:table-column column-width="3.0in" />
		<fo:table-body>
			<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left">
						<fo:block>Decimal MEID</fo:block>			
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="$meiddec"/>							
						</fo:block>			
					</fo:table-cell>				
			</fo:table-row>
			<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left">
						<fo:block>Hex MEID</fo:block>			
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="$meidhex"/>							
						</fo:block>			
					</fo:table-cell>				
			</fo:table-row>	
			<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left">
						<fo:block>11 Digit ESN</fo:block>			
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="$esn11"/>							
						</fo:block>			
					</fo:table-cell>				
			</fo:table-row>
			<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left">
						<fo:block>10 Digit ESN</fo:block>			
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="$esn10"/>							
						</fo:block>			
					</fo:table-cell>				
			</fo:table-row>					
			<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left">
						<fo:block>Hex ESN</fo:block>			
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="$esnhex"/>							
						</fo:block>			
					</fo:table-cell>				
			</fo:table-row>			
		</fo:table-body>
		</fo:table> 	
</xsl:template>

</xsl:stylesheet>






