<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: installment_psa.xsl,v 1.3 2014-11-05 16:27:04 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:pos="java:com.psasoft.pos.util.POSUtil"
				exclude-result-prefixes="java" version="2.0">
  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="''"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		<xsl:call-template name="make-layout-master-set"/>
		<xsl:call-template name="make-body-web"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'install']/row)">
		<xsl:call-template name="pageone" />
	</xsl:when>
	<xsl:otherwise>
		<fo:block>No installment information found</fo:block>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="pageone"> 
	<xsl:variable name="cust" select="/all_results/results[@name = 'cust']/row"/>
	<xsl:variable name="install" select="/all_results/results[@name = 'install']/row"/>
	<xsl:variable name="calcpay" select="pos:calculateInstallmentsPaymentReport(number($install/beginbal), number($install/origterm), number($install/instintrt), 10)"/>
	<xsl:variable name="lastpay">
		<xsl:choose>
		<xsl:when test="($install/itmrat * $install/origterm) = ($calcpay * $install/origterm)">
			<xsl:value-of select="$install/itmrat" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="($calcpay * $install/origterm) - ($install/itmrat * ($install/origterm - 1))" />
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<fo:block-container absolute-position="fixed" left="2.8cm" top="0.5in" width="6.25in">
		<fo:block xsl:use-attribute-sets="report-title" font-size="16pt" font-weight="bold" text-align="center">
		    <xsl:value-of select="' Installment Financing Agreement '" />
		</fo:block>
	</fo:block-container>
	<fo:block-container absolute-position="fixed" left="3cm" top="1.25in" width="3.75in" padding="5pt">
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Account: </fo:inline>		                        
			<xsl:value-of select="format-number($cust/ptcyc, '000')" />
			<xsl:value-of select="'-'" />
			<xsl:value-of select="format-number($cust/ptacct, '0000000')" />
		</fo:block>
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Buyer's Name: </fo:inline>		                        
			<xsl:value-of select="$cust/fname" />
			<xsl:value-of select="$cust/lname" />
		</fo:block>
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Phone # : </fo:inline>		                        
			<xsl:value-of select="format-number($cust/cnpa, '000')" />
			-
			<xsl:value-of select="format-number($cust/cnxx, '000')" />
			-
			<xsl:value-of select="format-number($cust/cline, '0000')" />
		</fo:block>		
		<fo:block>
			<fo:inline xsl:use-attribute-sets="category-label">Address: </fo:inline>		                        
		</fo:block>
		<xsl:if test="normalize-space($cust/adln1)">
			<fo:block margin-left=".5in">
				<xsl:value-of select="$cust/adln1" />
			</fo:block>
		</xsl:if>
		<xsl:if test="normalize-space($cust/adln2)">
			<fo:block margin-left=".5in">
				<xsl:value-of select="$cust/adln2" />
			</fo:block>
		</xsl:if>
		<xsl:if test="normalize-space($cust/adln3)">
			<fo:block margin-left=".5in">
				<xsl:value-of select="$cust/adln3" />
			</fo:block>
		</xsl:if>
		<fo:block margin-left=".5in">
			<xsl:value-of select="$cust/adcity" />
			<xsl:value-of select="', '" />
			<xsl:value-of select="$cust/adst" />
			<xsl:value-of select="' '" />
			<xsl:value-of select="substring($cust/adzip, 1, 5)"/>
			<xsl:if test="substring($cust/adzip, 6, 4) != '0000' and substring($cust/adzip, 6, 4) != ''" >
				<xsl:value-of select="'-'"/>
				<xsl:value-of select="substring($cust/adzip, 6, 4)"/>
			</xsl:if>
		</fo:block>
		<fo:block space-before="15pt">
			<fo:inline xsl:use-attribute-sets="category-label">Device Description : </fo:inline>		                        
			<xsl:value-of select="$install/itemdesc" />
		</fo:block>
	</fo:block-container>
	<fo:block-container absolute-position="fixed" left="3cm" top="3.5in" width="6.25in">
		<fo:table table-layout="fixed">
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-column column-width="1.0in"/>
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="6" color="black" text-align="center">
						<fo:block>Federal Truth-In-Lending Disclosures</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block>Annual Percentage Rate.</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block>Finance Charge</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block>Amount Financed</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block>Total of Payments</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block>Total Downpayment</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings" color="black">
						<fo:block>Total Sale Price</fo:block>
					</fo:table-cell>					
				</fo:table-row>
			</fo:table-header>						
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="8pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/instintrt, '##0.00 %')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="8pt" xsl:use-attribute-sets="summary-headings">
							<xsl:choose>
							<xsl:when test="(($calcpay * $install/origterm) - $install/beginbal) > 0.00">
								<xsl:value-of select="format-number((($calcpay * $install/origterm) - $install/beginbal), '$ ##,##0.00;$ -##,##0.00')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(0, '$ ##,##0.00')" />
							</xsl:otherwise>
							</xsl:choose>							
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="8pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/beginbal, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="8pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($calcpay * $install/origterm, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="8pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/pitamt, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border-style="solid" border-width="1px" padding="5px" text-align="right">
						<fo:block font-size="8pt" xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="format-number($install/beginbal + $install/pitamt, '$ ##,##0.00;$ -##,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="6pt">
							The cost of Buyer<fo:character character="&#8217;" />s credit as a yearly rate.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="6pt">
							The dollar amount the credit will cost Buyer.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="6pt">
							The amount of credit provided to Buyer or on Buyer<fo:character character="&#8217;" />s behalf.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="6pt">
							The amount Buyer will have paid after all payments have been made as scheduled.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="6pt">
							The Buyer<fo:character character="&#8217;" />s down payment.
						</fo:block>
					</fo:table-cell>
					<fo:table-cell  color="black" text-align="left" display-align="before" xsl:use-attribute-sets="table-headings">
						<fo:block font-size="6pt">
							The total cost of Buyer<fo:character character="&#8217;" />s purchase on credit, including Buyer<fo:character character="&#8217;" />s down payment.
						</fo:block>
					</fo:table-cell>
				</fo:table-row>				
			</fo:table-body>
		</fo:table>
		<fo:block space-before=".25in" xsl:use-attribute-sets="category-label">
			Your payment schedule will be:
		</fo:block>	
		<xsl:choose>
			<xsl:when test="$install/itmrat = $lastpay">
				<fo:block space-before=".10in">
					<fo:inline xsl:use-attribute-sets="category-label">Number of monthly payments: </fo:inline>		                        
					<xsl:value-of select="format-number($install/origterm, '##0')" />
				</fo:block>		
				<fo:block>
					<fo:inline xsl:use-attribute-sets="category-label">Payment amount: </fo:inline>		                        
					<xsl:value-of select="format-number($install/itmrat, '$ ##,##0.00;$ -##,##0.00')" />
				</fo:block>		
			</xsl:when>
			<xsl:otherwise>
				<fo:block space-before=".10in">
					<fo:inline xsl:use-attribute-sets="category-label">Number of monthly payments: </fo:inline>		                        
					<xsl:value-of select="format-number($install/origterm - 1, '##0')" />
				</fo:block>		
				<fo:block>
					<fo:inline xsl:use-attribute-sets="category-label">Payment amount: </fo:inline>		                        
					<xsl:value-of select="format-number($install/itmrat, '$ ##,##0.00;$ -##,##0.00')" />
				</fo:block>
				<fo:block>
					<fo:inline xsl:use-attribute-sets="category-label">Plus 1 final payment of: </fo:inline>		
					<xsl:value-of select="format-number(number($lastpay), '$ ##,##0.00;$ -##,##0.00')" /> 
				</fo:block>				
			</xsl:otherwise>
		</xsl:choose>
		<fo:block space-before="15pt">
			Your installment payments will be included in the monthly bill, and will be due on the date shown on your monthly statement.	                        
		</fo:block>		

	</fo:block-container>
	
	<fo:block-container absolute-position="fixed" left="2.8cm" top="8in" width="6.25in">
		<fo:block xsl:use-attribute-sets="summary-headings" space-before="10pt" color="black">By signing this Financing Agreement (the <fo:character character="&#8220;" />Agreement<fo:character character="&#8221;" />), you, the Buyer, choose to buy they Device identified above (the <fo:character character="&#8220;" />Device<fo:character character="&#8221;" />) on credit under the terms and conditions disclosed in this Agreement.  You agree to pay the Company (also, <fo:character character="&#8220;" />We<fo:character character="&#8221;" /> or <fo:character character="&#8220;" />Us<fo:character character="&#8221;" />) the Amount Financed and any Finance Charge in U.S. funds according to the payment schedule above.  The Truth-in-Lending Disclosures above are part of this Agreement.</fo:block>
		<fo:block height="1.5in" space-before="0.5in">
			<xsl:value-of select="' Signature: '" />
			<fo:inline xsl:use-attribute-sets="summary-headings" border-bottom-style="solid" border-bottom-width="1px">
				<xsl:choose>
					<xsl:when test="$sigpng > ''">
						<fo:external-graphic src="data:image/png;base64,{$sigpng}" content-width="1.5in" content-height="auto" />
					</xsl:when>
					<xsl:when test="$sigimg > ''">
						<fo:external-graphic src="data:image/jpeg;base64,{$sigimg}" content-width="3.0in" content-height="auto" />
					</xsl:when>
					<xsl:otherwise>
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
						<fo:character character="&#x2000;" />
					</xsl:otherwise>
				</xsl:choose>
			</fo:inline>
		</fo:block>
		<fo:block space-before="50px">
			<xsl:value-of select="' Date: '" /> 
			<xsl:value-of select="$install/schedate" />
		</fo:block>
	</fo:block-container> 
	
</xsl:template>

</xsl:stylesheet>






