<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="'Item Price Book'" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="$report_type = 1">
		<xsl:call-template name="main">
				<xsl:with-param name="posfrom" select="0" />    
				<xsl:with-param name="posto" select="8" /> 	
				<xsl:with-param name="costid" select="0" />									
		</xsl:call-template>
		<xsl:if test="/all_results/results[@name = 'types']/row[position() &gt; 7]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="7" />    
						<xsl:with-param name="posto" select="15" /> 										
						<xsl:with-param name="costid" select="0" />									
				</xsl:call-template>		
		</xsl:if>
		<xsl:if test="/all_results/results[@name = 'types']/row[position() &gt; 14]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="14" />    
						<xsl:with-param name="posto" select="22" /> 										
						<xsl:with-param name="costid" select="0" />									
				</xsl:call-template>		
		</xsl:if>		
	</xsl:when>
	<xsl:when test="$report_type = 2 and not(exists(/all_results/results[@name = 'types']/row[contains(lower-case(typedesc), 'cost')]/ptypeid))" >
		<fo:block>
			Cost Price Type Not Defined
		</fo:block>
	</xsl:when>
	<xsl:when test="$report_type = 2">
	    <xsl:variable name="costid" select="/all_results/results[@name = 'types']/row[contains(lower-case(typedesc), 'cost')]/ptypeid" />
		<xsl:call-template name="main">
				<xsl:with-param name="posfrom" select="0" />    
				<xsl:with-param name="posto" select="8" />
				<xsl:with-param name="costid" select="$costid" />									
		</xsl:call-template>
		<xsl:if test="/all_results/results[@name = 'types']/row[ptypeid != $costid and position() &gt; 7]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="7" />    
						<xsl:with-param name="posto" select="15" /> 										
						<xsl:with-param name="costid" select="$costid" />									
				</xsl:call-template>		
		</xsl:if>
		<xsl:if test="/all_results/results[@name = 'types']/row[ptypeid != $costid and position() &gt; 14]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="14" />    
						<xsl:with-param name="posto" select="22" /> 										
						<xsl:with-param name="costid" select="$costid" />									
				</xsl:call-template>		
		</xsl:if>		
	</xsl:when>	
	</xsl:choose>
</xsl:template>

<xsl:template name="main">
	<xsl:param name="posfrom" />
	<xsl:param name="posto" />
	<xsl:param name="costid" />

	<xsl:choose>
	<xsl:when test="$report_type = 1">
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="2.0in" />
			<fo:table-column column-width="1.0in" />
			<xsl:for-each select="/all_results/results[@name = 'types']/row[position() &gt; $posfrom and position() &lt; $posto]">
				<fo:table-column column-width="1.0in" />
			</xsl:for-each>
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Description</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Code</fo:block>
					</fo:table-cell>
					<xsl:for-each select="/all_results/results[@name = 'types']/row[position() &gt; $posfrom and position() &lt; $posto]">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								<xsl:value-of select="./typedesc" />
							</fo:block>
						</fo:table-cell>
					</xsl:for-each>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:call-template name="detail">
					<xsl:with-param name="posfrom" select="$posfrom" />
					<xsl:with-param name="posto" select="$posto" />
					<xsl:with-param name="costid" select="$costid" />
				</xsl:call-template>
			</fo:table-body>
		</fo:table>
	</xsl:when>
	<xsl:when test="$report_type = 2">
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="2.0in" />
			<fo:table-column column-width="1.0in" />
			<xsl:for-each select="/all_results/results[@name = 'types']/row[position() &gt; $posfrom and position() &lt; $posto]">
				<fo:table-column column-width="1.0in" />
			</xsl:for-each>
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Description</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Code</fo:block>
					</fo:table-cell>
					<xsl:for-each select="/all_results/results[@name = 'types']/row[position() &gt; $posfrom and position() &lt; $posto]">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								<xsl:value-of select="./typedesc" />
							</fo:block>
						</fo:table-cell>
					</xsl:for-each>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:call-template name="detail">
					<xsl:with-param name="posfrom" select="$posfrom" />
					<xsl:with-param name="posto" select="$posto" />
					<xsl:with-param name="costid" select="$costid" />
				</xsl:call-template>
			</fo:table-body>
		</fo:table>	
	</xsl:when>	
	</xsl:choose>
</xsl:template>

<xsl:template name="detail">
	<xsl:param name="posfrom" />
	<xsl:param name="posto" />
	<xsl:param name="costid" />

	<xsl:choose>
	<xsl:when test="$report_type = 1">
		<xsl:for-each select="/all_results/results[@name = 'items']/row">
			<xsl:variable name="unitdesc" select="./unitdesc" />
			<xsl:variable name="unitid" select="./unitid" />
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="$unitdesc" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<xsl:choose>
						<xsl:when test="./unitcode != ''">
							<fo:block>
								<xsl:value-of select="./unitcode" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="./externalcd" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<xsl:for-each select="/all_results/results[@name = 'types']/row[position() &gt; $posfrom and position() &lt; $posto]">
					<xsl:variable name="type" select="./typedesc" />
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:choose>
								<xsl:when test="/all_results/results[@name = 'prices']/row[./typedesc = $type and ./unitid = $unitid]/unitamt != 0">
									<xsl:value-of select="format-number(/all_results/results[@name = 'prices']/row[./typedesc = $type and ./unitid = $unitid]/unitamt, '##,###,##0.00')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(0, '##,###,##0.00')" />
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
				</xsl:for-each>
			</fo:table-row>
		</xsl:for-each>
	</xsl:when>	
	<xsl:when test="$report_type = 2">
		<xsl:for-each select="/all_results/results[@name = 'items']/row">
			<xsl:variable name="unitdesc" select="./unitdesc" />
			<xsl:variable name="unitid" select="./unitid" />
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="$unitdesc" />
					</fo:block>
					<fo:block margin-left="10px" font-style="italic" font-size="9pt" color="black">
						<xsl:value-of select="'Margin'" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<xsl:choose>
						<xsl:when test="./unitcode != ''">
							<fo:block>
								<xsl:value-of select="./unitcode" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="./externalcd" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<xsl:for-each select="/all_results/results[@name = 'types']/row[position() &gt; $posfrom and position() &lt; $posto]">
					<xsl:variable name="type" select="./typedesc" />
					<xsl:variable name="price">
						<xsl:choose>
						<xsl:when test="exists(/all_results/results[@name = 'prices']/row[./typedesc = $type and ./unitid = $unitid]/unitamt)">
							<xsl:value-of select="/all_results/results[@name = 'prices']/row[./typedesc = $type and ./unitid = $unitid]/unitamt" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="0" />
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="cost">
						<xsl:choose>
						<xsl:when test="exists(/all_results/results[@name = 'prices']/row[./ptypeid = $costid and ./unitid = $unitid]/unitamt)">
							<xsl:value-of select="/all_results/results[@name = 'prices']/row[./ptypeid = $costid and ./unitid = $unitid]/unitamt" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="0" />
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="margin" select="$price - $cost" />
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($price, ' ##,###,##0.00;-##,###,##0.00')" />
						</fo:block>
						<xsl:choose>
						<xsl:when test="./ptypeid = $costid">
							<fo:block>
								<xsl:value-of select="' '" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block font-style="italic" color="black">
								<xsl:value-of select="format-number($margin, ' ##,###,##0.00;-##,###,##0.00')" />
							</fo:block>
						</xsl:otherwise>
						</xsl:choose>
					</fo:table-cell>
				</xsl:for-each>
			</fo:table-row>
		</xsl:for-each>		
	</xsl:when>	
	</xsl:choose>	
</xsl:template>

</xsl:stylesheet>
