<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: inv_statusrpt.xsl,v 1.4 2016-08-11 20:34:44 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:fo="http://www.w3.org/1999/XSL/Format" 
                xmlns:java="http://xml.apache.org/xslt/java" 
                xmlns:exsl="http://exslt.org/functions"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
				xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
				xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				xmlns:saxon="http://saxon.sf.net/"
                exclude-result-prefixes="java" version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="concat('Inventory Status Report ', $status_date_range[1], ' to ', $status_date_range[2])" />
    
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>
    <xsl:template name="body_process">
    	<xsl:choose>
    	<xsl:when test="/all_results/results[@name = 'data']/row">
	    	<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="company">
    			<xsl:variable name="company" select="current-grouping-key()"/>

				<xsl:for-each-group select="current-group()" group-by="current-group()/location">
					<xsl:variable name="location" select="current-grouping-key()"/>	

					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="header">
							<xsl:with-param name="company" select="$company" />
							<xsl:with-param name="location" select="$location" />
						</xsl:call-template>
	
						<fo:table-body>
							<xsl:for-each-group select="current-group()" group-by="current-group()/status">
								<xsl:variable name="status" select="current-grouping-key()"/>	
		
								<xsl:if test="/all_results/results[@name = 'data']/row[company = $company and location = $location and status = $status]" >
									<fo:table-row>
										<fo:table-cell xsl:use-attribute-sets="table-cells" number-columns-spanned="6">
											<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left" >
												<xsl:value-of select="'Status: '" />
												<xsl:call-template name="inventorystatus">
													<xsl:with-param name="status" select="$status" />
													<xsl:with-param name="unitqty" select="0" />
												</xsl:call-template>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</xsl:if>
								<xsl:call-template name="row">
									<xsl:with-param name="company" select="$company" />
									<xsl:with-param name="location" select="$location" />
									<xsl:with-param name="status" select="$status" />
								</xsl:call-template>				
							</xsl:for-each-group>
							<xsl:if test="/all_results/results[@name = 'data']/row[company = $company and location = $location]">
								<fo:table-row keep-with-next="always">
									<fo:table-cell xsl:use-attribute-sets="summary-title" number-columns-spanned="4">
										<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left" >
											<xsl:value-of select="'Total For Location: '"/>
										</fo:block>			
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[company = $company and location = $location]/rcvprice), '##,##0.00')" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block>
											<xsl:value-of select="' '" />
										</fo:block>
									</fo:table-cell>			
								</fo:table-row>			
							</xsl:if>
						</fo:table-body>
					</fo:table>
				</xsl:for-each-group>
			</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
				<fo:block space-before="16px">No Inventory Found for Date Range</fo:block>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="header">
		<xsl:param name="company" />
		<xsl:param name="location" />

		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="2.00in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="2.00in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="2.00in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="summary-title" number-columns-spanned="6">
						<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left" >
							<xsl:value-of select="'Company: '"/>
							<xsl:value-of select="$company" />
						</fo:block>			
						<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="0px" space-after="6px" text-align="left" >								
							<xsl:value-of select="'Location: '"/>
							<xsl:value-of select="$location" />
						</fo:block>	
					</fo:table-cell>
				</fo:table-row>			
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Billing Id</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Unit Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Item Description</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Status Change Date</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Last Updated By</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Recv Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Serial Number</fo:block>
					</fo:table-cell>											
			</fo:table-row>			
		</fo:table-header>
	</xsl:template>
	
	<xsl:template name="row">
		<xsl:param name="company" />
		<xsl:param name="location" />
		<xsl:param name="status" />

		<xsl:for-each select="/all_results/results[@name = 'data']/row[company = $company and location = $location and status = $status]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:choose>
							<xsl:when test="./externalcd != ''">
								<xsl:value-of select="./externalcd" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="' '" />
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
					<fo:block>
						<xsl:value-of select="./unitcode" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block wrap-option="wrap">
						<xsl:value-of select="./item" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block wrap-option="wrap">
						<xsl:value-of select="./statuschdt" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block wrap-option="wrap">
						<xsl:value-of select="./updateby" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:value-of select="format-number(./rcvprice, '##,##0.00')" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<fo:inline space-end="0.2in" space-start.precedence="force" wrap-option="wrap">
							<xsl:call-template name="formatserial">
								<xsl:with-param name="serial" select="./serialno2" />
								<xsl:with-param name="serial0" select="./serialno" />
								<xsl:with-param name="serial2typ" select="./serial2typ" />
								<xsl:with-param name="unitid" select="./unitid" />
								<xsl:with-param name="actpin" select="./actpin" />
								<xsl:with-param name="npa" select="./npa" />
								<xsl:with-param name="nxx" select="./nxx" />
								<xsl:with-param name="line" select="./line" />
							</xsl:call-template>
						</fo:inline>
					</fo:block>
				</fo:table-cell>				
			</fo:table-row>
		</xsl:for-each>
		<xsl:if test="/all_results/results[@name = 'data']/row[company = $company and location = $location and status = $status]">
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="summary-title" number-columns-spanned="4">
					<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left" >
						<xsl:value-of select="'Total For Status: '"/>
					</fo:block>			
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[company = $company and location = $location and status = $status]/rcvprice), '##,##0.00')" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:value-of select="' '" />
					</fo:block>
				</fo:table-cell>			
			</fo:table-row>			
		</xsl:if>
				
	</xsl:template>
</xsl:stylesheet>