<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">
<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/>      
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Miscellaneous Tax Code ', $bill_date[1], ' to ', $bill_date[2])" />

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
	</fo:root>
</xsl:template>
<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="/all_results/results[@name = 'data']/row">  
			<xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="item">
					<xsl:variable name="taxcode" select="./item" />

					<fo:table table-layout="fixed" width="100%" space-before="16px">
							<fo:table-column column-width="0.75in" />
							<fo:table-column column-width="0.80in" />
							<fo:table-column column-width="0.75in" />
							<fo:table-column column-width="1.75in" />
							<fo:table-column column-width="1.50in" />
							<fo:table-column column-width="1.00in" />
							<fo:table-column column-width="0.75in" />
							<fo:table-column column-width="0.75in" />
							<fo:table-column column-width="0.75in" />
							<fo:table-column column-width="0.25in" />
							<fo:table-header>
									<fo:table-row keep-with-next="always">
											<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="10">
													<fo:block>
															<xsl:value-of select="'Tax Code: '"/>
															<xsl:value-of select="/all_results/results[@name = 'taxmst']/row[taxcode = $taxcode]/mtaxcd"/>
															<xsl:value-of select="' - '"/>
															<xsl:value-of select="/all_results/results[@name = 'taxmst']/row[taxcode = $taxcode]/mtaxds" />
													</fo:block>											
											</fo:table-cell>
									</fo:table-row>
									<fo:table-row keep-with-next="always">
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Account
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													MDN
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Disconnect Date 
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Account Name
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Address
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													City / State
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Zip
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Bill Date
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Tax Amount
													</fo:block>
											</fo:table-cell>											
											<fo:table-cell xsl:use-attribute-sets="table-headings">
													<fo:block>
													Src
													</fo:block>
											</fo:table-cell>											
									</fo:table-row>
							</fo:table-header>
							<fo:table-body>    
									<xsl:call-template name="detail">
										<xsl:with-param name="taxcode" select="$taxcode"/>
									</xsl:call-template>    		
									<fo:table-row keep-with-next="always">
											<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="8">
													<fo:block>
															Total Tax
													</fo:block>											
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
												<fo:block>
													<xsl:if test="./trnamt > ''">
																<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[item = $taxcode]/trnamt), '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:if>
												</fo:block>
											</fo:table-cell>												
											<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left">
													<fo:block>
															<xsl:value-of select="' '" />
													</fo:block>											
											</fo:table-cell>
									</fo:table-row>									
							</fo:table-body>
						</fo:table>				
				</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No Information Found
			</fo:block>
		</xsl:otherwise>
	</xsl:choose>				
</xsl:template>
    
<xsl:template name="detail">
		<xsl:param name="taxcode" />

		<xsl:for-each select="/all_results/results[@name = 'data']/row[item = $taxcode]">
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
							<fo:block>
								<xsl:if test="./cycle &gt; 0 and ./acct &gt; 0">
									<xsl:value-of select="format-number(./cycle, '000')" />
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number(./acct, '0000000')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
							<fo:block>
								<xsl:if test="./cnpa &gt; 0 and ./cnxx &gt; 0">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="./cnpa"/>
										<xsl:with-param name="nxx" select="./cnxx"/>
										<xsl:with-param name="line" select="./cline"/>
									</xsl:call-template>
								</xsl:if>
								<xsl:value-of select="' '"/>
							</fo:block>	
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./dccc = ''">
									<xsl:value-of select="'Not Found'" />
								</xsl:when>
								<xsl:when test="./dccc &gt; '0' and ./dcyy &gt; '0'">
									<xsl:call-template name="date4parm">
										<xsl:with-param name="cc" select="./dccc"/>
										<xsl:with-param name="yy" select="./dcyy"/>
										<xsl:with-param name="mm" select="./dcmm"/>
										<xsl:with-param name="dd" select="./dcdd"/>
									</xsl:call-template>	
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="' '"/>
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>	
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" wrap-option="wrap" overflow="hidden" font-size="7px" text-align="left">
							<fo:block>
									<xsl:value-of select="./fname" />
									<xsl:value-of select="' '" />
									<xsl:value-of select="./lname" />
							</fo:block>	
						</fo:table-cell>												
						<fo:table-cell xsl:use-attribute-sets="table-cells" wrap-option="wrap" overflow="hidden" font-size="7px" text-align="left">
								<fo:block>
										<xsl:value-of select="./adln1" />
								</fo:block>
								<fo:block>
										<xsl:value-of select="./adln2" />
								</fo:block>
								<fo:block>
										<xsl:value-of select="./adln3" />
								</fo:block>									
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells" wrap-option="wrap" overflow="hidden" font-size="7px" text-align="left">
								<fo:block>
									<xsl:value-of select="./adcity" />
									<xsl:value-of select="', '" />
									<xsl:value-of select="./adst" />								
								</fo:block>
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="left">
								<fo:block>
									<xsl:value-of select="substring(./adzip, 1, 5)" />
									<xsl:if test="string-length(normalize-space(./adzip)) &gt; 5">
											<xsl:value-of select="'-'" />
											<xsl:value-of select="substring(./adzip, 6, 4)" />
									</xsl:if>								
								</fo:block>
						</fo:table-cell>		
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="center">
							<fo:block>
									<xsl:value-of select="./trdate" />
							</fo:block>	
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
							<fo:block>
								<xsl:if test="./trnamt > ''">
											<xsl:value-of select="format-number(./trnamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
								</xsl:if>
							</fo:block>
						</fo:table-cell>									
						<fo:table-cell xsl:use-attribute-sets="table-cells" font-size="7px" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="./inits = 'POS'">
									<xsl:value-of select="'POS'" />
								</xsl:when>
								<xsl:when test="./inits = 'PSA'">
									<xsl:value-of select="'BILL'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'UNK'" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
				</fo:table-row>
		</xsl:for-each>				
</xsl:template>
</xsl:stylesheet>
