<?xml version="1.0" encoding="utf-8"?>
	<!-- $Id: oneticket.xsl,v 1.6 2011-01-21 19:20:16 michaelr Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
                xmlns:str="java:org.apache.commons.lang.StringUtils"		
                xmlns:util="java:com.psasoft.util.TextUtilities"
				exclude-result-prefixes="java"
				version="2.0">

	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />

	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="concat('Ticket #', $ticket_id)" />

	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set" />
			<xsl:call-template name="make-body" />
		</fo:root>
	</xsl:template>

	<xsl:template name="body_process">
		<xsl:choose>

			<xsl:when test="exists(/all_results/results[@name = 'detail']/row)">
				<xsl:variable name="row" select="/all_results/results[@name = 'detail']/row" />
				<fo:table table-layout="fixed" width="100%" space-before="16px">

					<fo:table-column column-width="7in" />
					<fo:table-header>
						<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="summary-headings">
								<fo:block>
									<xsl:value-of select="'Account: '" />
									<xsl:value-of select="format-number($row/cycle, '000')" />
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number($row/account, '0000000')" />									
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<xsl:if test="$row/tictype = 'A'">
							<fo:table-row margin-left="20px">
								<fo:table-cell xsl:use-attribute-sets="summary-headings">
									<fo:block>
										<xsl:value-of select="'Account Level Ticket '" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>			
						</xsl:if>
						<xsl:if test="$row/tictype = 'S'">
							<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="summary-headings">
									<fo:block>
										<xsl:value-of select="'MDN: '" />
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="$row/cnpa" />
											<xsl:with-param name="nxx" select="$row/cnxx" />
											<xsl:with-param name="line" select="$row/cline" />
										</xsl:call-template>
										<xsl:choose>
										<xsl:when test="$row/dccc = 99">
											<xsl:value-of select="' Suspend NP'" />
										</xsl:when>
										<xsl:when test="$row/dccc &gt; 0">
											<xsl:value-of select="' '" />
											<xsl:call-template name="date4parm">
												<xsl:with-param name="cc" select="$row/dccc" />
												<xsl:with-param name="yy" select="$row/dcyy" />
												<xsl:with-param name="mm" select="$row/dcmm" />
												<xsl:with-param name="dd" select="$row/dcdd" />
											</xsl:call-template>
										</xsl:when>
										</xsl:choose>									
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row margin-left="20px">
								<fo:table-cell xsl:use-attribute-sets="summary-headings">
									<fo:block>
										<xsl:value-of select="'Equipment Description: '" />
										<xsl:value-of select="$row/mfgmdl" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="$row/eqpdsc" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>			
							<xsl:if test="normalize-space($row/esn) &gt; '' and $row/esn &gt; 0">
								<fo:table-row margin-left="20px">
									<fo:table-cell xsl:use-attribute-sets="summary-headings">
										<fo:block>
											<xsl:value-of select="'ESN: '" />
				                            <xsl:value-of select="format-number($row/esn, '00000000000')" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>														
							</xsl:if>
							<xsl:if test="normalize-space($row/imei) &gt; '' and $row/imei &gt; 0">
								<fo:table-row margin-left="20px">
									<fo:table-cell xsl:use-attribute-sets="summary-headings">
										<fo:block>
											<xsl:value-of select="'IMEI: '" />
				                            <xsl:value-of select="format-number($row/imei, '000000000000000')" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>														
							</xsl:if>
							<xsl:if test="normalize-space($row/meid) &gt; ''">
								<fo:table-row margin-left="20px">
									<fo:table-cell xsl:use-attribute-sets="summary-headings">
										<fo:block>
											<xsl:value-of select="'MEID: '" />
											<xsl:value-of select="$row/meid" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>														
							</xsl:if>
							<xsl:if test="normalize-space($row/imnumb) &gt; '' and $row/imnumb &gt; 0">
								<fo:table-row margin-left="20px">
									<fo:table-cell xsl:use-attribute-sets="summary-headings">
										<fo:block>
											<xsl:value-of select="'IMSI: '" />
				                            <xsl:value-of select="format-number($row/imctry, '000')" />
				                            <xsl:value-of select="'-'" />
				                            <xsl:value-of select="format-number($row/imcomp, '00000')" />
				                            <xsl:value-of select="'-'" />
				                            <xsl:value-of select="format-number($row/imnumb, '0000000000')" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>														
							</xsl:if>
						</xsl:if>
						<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="summary-headings">
								<fo:block>
									<xsl:value-of select="'Ticket Code: '" />
									<xsl:value-of select="$row/trbcdds" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="summary-headings">
								<fo:block>
									<xsl:value-of select="'Created By: '" />
									<xsl:value-of select="$row/createname" />
									<xsl:value-of select="' on '" />
									<xsl:value-of select="util:parseAndFormatTimestamp($row/createtime)" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="summary-headings">
								<fo:block space-after="0.25in">
									<xsl:value-of select="'Assigned To: '" />
									<xsl:value-of select="$row/assignedname" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<xsl:if test="$row/starttime != $row/createtime">
							<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="summary-headings">
									<fo:block>
										<xsl:value-of select="'Start on '" />
										<xsl:value-of select="util:parseAndFormatTimestamp($row/starttime)" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</xsl:if>
						<xsl:if test="$row/duetime > ''">
							<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="summary-headings">
									<fo:block space-after="0.25in">
										<xsl:value-of select="'Due: '" />
										<xsl:value-of select="util:parseAndFormatTimestamp($row/duetime)" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</xsl:if>
						<xsl:if test="$row/closeby &gt; 0">
							<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="summary-headings">
									<fo:block space-after="0.25in">
										<xsl:value-of select="'Cleared By: '" />
										<xsl:value-of select="$row/closedname" />
										<xsl:value-of select="' on '" />
										<xsl:value-of select="util:parseAndFormatTimestamp($row/closetime)" />
									</fo:block>				
									<fo:block keep-with-previous="always" space-after="0.5in">
										<xsl:value-of select="'Cleared Reason: '" />
										<xsl:value-of select="$row/clrcdds" />
									</fo:block>	
								</fo:table-cell>				
							</fo:table-row>
						</xsl:if>
					</fo:table-header>
					<fo:table-body>
						<fo:table-row keep-with-previous="always">
							<fo:table-cell text-align="left">
								<xsl:variable name="textrows" select="str:split($row/descr, '~')" />
								<fo:table>
									<fo:table-column column-width="1.5in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="4.5in" />
									<fo:table-header>
										<fo:table-row>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>Note Time</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>Note By</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>Note</fo:block>
											</fo:table-cell>
										</fo:table-row>
									</fo:table-header>
									<fo:table-body>
										<xsl:for-each select="$textrows">
											<xsl:variable name="trow" select="." />
											<fo:table-row>
												<xsl:variable name="textcols" select="str:split($trow, '|')" />
												<xsl:for-each select="$textcols">
													<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
														<fo:block font-size="8pt" space-before="4px">
															<xsl:value-of select="." />
														</fo:block>
													</fo:table-cell>
												</xsl:for-each>
											</fo:table-row>
										</xsl:for-each>
									</fo:table-body>
								</fo:table>
							</fo:table-cell>
						</fo:table-row>		
					</fo:table-body>
				</fo:table>
			</xsl:when>
			<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
					No Information Found
			</fo:block>
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:choose>
			<xsl:when test="exists(/all_results/results[@name = 'schedule']/row)">	
				<fo:block xsl:use-attribute-sets="category-label" space-before="24px">
					Promise to Pay - Scheduled Payments
			    </fo:block>	
				<fo:table table-layout="fixed" width="100%" space-before="12px">
				     <fo:table-column column-width="1.50in" />
					 <fo:table-column column-width="1.00in" />
					 <fo:table-column column-width="1.00in" />
				     <fo:table-header>
						<fo:table-row>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Scheduled Date</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Scheduled Amount</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Payment Status</fo:block>
					    	</fo:table-cell>														
						</fo:table-row>
					 </fo:table-header>
					 <fo:table-body>
						     <xsl:for-each select="/all_results/results[@name = 'schedule']/row">	
						 		<fo:table-row number-columns-spanned="3">
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
										<xsl:call-template name="date1parm-db">
											<xsl:with-param name="date" select="./schedule_date" />
										</xsl:call-template>	
                                    </fo:block>
                                </fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
                                        <xsl:value-of select="./schedule_amt" />
                                    </fo:block>
                                </fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
                                        <xsl:value-of select="./schedule_status" />
                                    </fo:block>
                                </fo:table-cell>
								</fo:table-row>
							</xsl:for-each>
						</fo:table-body>
				</fo:table>			
			</xsl:when>
			<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
					There is not a Payment Schedule attached to this Ticket
			    </fo:block>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name="header">

		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="1.75in" />
		<fo:table-column column-width="1.50in" />
		<fo:table-column column-width="1.50in" />
		<fo:table-column column-width="2.00in" />
		<fo:table-header>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Ticket</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Account</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>MDN</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Disc Date</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Ticket Code</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Created</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Assigned</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Cleared</fo:block>
				</fo:table-cell>				
			</fo:table-row>
		</fo:table-header>
	</xsl:template>

	<xsl:template name="detail">
		<xsl:param name="row" />
		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="format-number($row/recordid, '#########0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<fo:block>
					<xsl:value-of select="format-number($row/cycle, '000')" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="format-number($row/account, '0000000')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<fo:block>
					<xsl:call-template name="phone">
						<xsl:with-param name="npa" select="$row/cnpa" />
						<xsl:with-param name="nxx" select="$row/cnxx" />
						<xsl:with-param name="line" select="$row/cline" />
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<fo:block>
					<xsl:choose>
					<xsl:when test="$row/dccc = 99">
						<xsl:value-of select="'Suspend NP'" />
					</xsl:when>
					<xsl:when test="$row/dccc &gt; 0">
						<xsl:call-template name="date4parm">
							<xsl:with-param name="cc" select="$row/dccc" />
							<xsl:with-param name="yy" select="$row/dcyy" />
							<xsl:with-param name="mm" select="$row/dcmm" />
							<xsl:with-param name="dd" select="$row/dcdd" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="' '" />
					</xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/trbcdds" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/createname" />
				</fo:block>
				<fo:block keep-with-previous="always">
					<xsl:value-of select="$row/createtime" />
				</fo:block>				
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/assignedname" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<xsl:choose>
				<xsl:when test="$row/closeby &gt; 0">
					<fo:block>
						<xsl:value-of select="$row/closedname" />
					</fo:block>				
					<fo:block keep-with-previous="always">
						<xsl:value-of select="$row/closetime" />
					</fo:block>				
					<fo:block keep-with-previous="always">
						<xsl:value-of select="$row/clrcdds" />
					</fo:block>				
				</xsl:when>
				<xsl:otherwise>
					<fo:block>
						<xsl:value-of select="' '" />
					</fo:block>
				</xsl:otherwise>
				</xsl:choose>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row keep-with-previous="always">
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left" number-columns-spanned="8">
				<xsl:variable name="textrows" select="str:split($row/descr, '~')" />
				<fo:table margin-left="10px">
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="7.0in" />
					<fo:table-body>
						<xsl:for-each select="$textrows">
							<xsl:variable name="trow" select="." />
							<fo:table-row>
								<xsl:variable name="textcols" select="str:split($trow, '|')" />
								<xsl:for-each select="$textcols">
									<fo:table-cell text-align="left">
										<fo:block font-size="6pt">
											<xsl:value-of select="." />
										</fo:block>
									</fo:table-cell>
								</xsl:for-each>
							</fo:table-row>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</fo:table-cell>
		</fo:table-row>		
	</xsl:template>


</xsl:stylesheet>






