<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: onhand.xsl,v 1.16 2014-08-25 16:28:28 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:fo="http://www.w3.org/1999/XSL/Format" 
                xmlns:java="http://xml.apache.org/xslt/java" 
                xmlns:exsl="http://exslt.org/functions"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
				xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
				xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				xmlns:saxon="http://saxon.sf.net/"
                exclude-result-prefixes="java" version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="'On Hand Report'" />
    
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>
    <xsl:template name="body_process">
    	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'mastsum']/row">
			<xsl:for-each-group select="/all_results/results[@name = 'mastsum']/row" group-by="company">
				<xsl:variable name="company" select="current-grouping-key()" />
				<xsl:for-each-group select="current-group()" group-by="current-group()/loca">
					<xsl:variable name="location" select="current-grouping-key()" />
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.5in" />
						<fo:table-column column-width="3.0in" />
						<fo:table-column column-width="2.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-header>
							<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="summary-title" number-columns-spanned="5">
									<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left">
										<xsl:value-of select="'Company:'" />
										<xsl:value-of select="$company" />
									</fo:block>
									<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="0px" space-after="6px" text-align="left">
										<xsl:value-of select="'Location:'" />
										<xsl:value-of select="$location" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Item Code</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Unit Code</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Item Description</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Receive Price</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Quantity</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
									<fo:block>Total Cost</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</fo:table-header>
						<fo:table-body>
							<xsl:for-each select="/all_results/results[@name = 'mastsum']/row[company = $company and loca = $location]">
								<xsl:variable name="companyid" select="./companyid" />
								<xsl:variable name="locationid" select="./locationid" />
								<xsl:variable name="rcvprice" select="./rcvprice" />
								<xsl:variable name="serial2typ" select="./serial2typ" />
								<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:value-of select="./externalcd" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:value-of select="./unitcode" />
										</fo:block>
									</fo:table-cell>									
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:value-of select="./unitdesc" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./rcvprice, '##,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./qty, '##,##0')" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./qty * ./rcvprice, '##,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
								<xsl:if test="./serialized = '1'">
									<xsl:variable name="unitid" select="./unitid" />
									<xsl:variable name="seriallbl">
	                                    <xsl:call-template name="getserialname">
	                                        <xsl:with-param name="serial2typ" select="./serial2typ" />
	                                        <xsl:with-param name="s2typlabel" select="./s2typlabel" />
	                                    </xsl:call-template>
									</xsl:variable>
									<xsl:variable name="serialno">
										<xsl:text> &#x2007;&#x2007;</xsl:text>
										<xsl:for-each select="/all_results/results[@name = 'mastdtl']/row[companyid = $companyid and locationid = $locationid and rcvprice = $rcvprice and unitid = $unitid]">
											<xsl:choose>
												<xsl:when test="$report_type = 2">
													<fo:block>
														<xsl:call-template name="formatserial">
															<xsl:with-param name="serial" select="./serialno2" />
															<xsl:with-param name="serial0" select="./serialno" />
															<xsl:with-param name="serial2typ" select="$serial2typ" />
															<xsl:with-param name="unitid" select="./unitid" />
															<xsl:with-param name="actpin" select="./actpin" />
															<xsl:with-param name="npa" select="./npa" />
															<xsl:with-param name="nxx" select="./nxx" />
															<xsl:with-param name="line" select="./line" />
														</xsl:call-template>
													</fo:block>
												</xsl:when>
												<xsl:otherwise>
													<fo:inline space-end="0.2in" space-start.precedence="force" wrap-option="wrap">
														<xsl:call-template name="formatserial">
															<xsl:with-param name="serial" select="./serialno2" />
															<xsl:with-param name="serial0" select="./serialno" />
															<xsl:with-param name="serial2typ" select="$serial2typ" />
															<xsl:with-param name="unitid" select="./unitid" />
															<xsl:with-param name="actpin" select="./actpin" />
															<xsl:with-param name="npa" select="./npa" />
															<xsl:with-param name="nxx" select="./nxx" />
															<xsl:with-param name="line" select="./line" />
														</xsl:call-template>
													</fo:inline>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:for-each>
									</xsl:variable>
									<fo:table-row>
										<fo:table-cell xsl:use-attribute-sets="table-cells">
											<fo:block>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-cells" keep-with-previous="always" text-align="left" number-columns-spanned="4">
											<xsl:choose>
												<xsl:when test="$report_type = 2">
													<fo:block>
														<xsl:value-of select="$seriallbl" />
													</fo:block>
													<xsl:copy-of select="$serialno" />
												</xsl:when>
												<xsl:otherwise>
													<fo:block>
														<fo:inline>
															<xsl:value-of select="$seriallbl" />
														</fo:inline>
														<fo:block space-start.precedence="force">
															<xsl:value-of select="$serialno" />
														</fo:block>
													</fo:block>
												</xsl:otherwise>
											</xsl:choose>
										</fo:table-cell>
									</fo:table-row>
								</xsl:if>
							</xsl:for-each>
						</fo:table-body>
					</fo:table>
					<fo:block break-before="page" />
				</xsl:for-each-group>
			</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
			<fo:block>No Items Found for selection</fo:block>		
		</xsl:otherwise>
		</xsl:choose>
    </xsl:template>
    
</xsl:stylesheet>    	
    