<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: paymentdetail.xsl,v 1.1 2010-03-26 17:28:34 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:util="java:com.psasoft.util.TextUtilities"
				exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>  
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="concat('Payment Detail ', $payment_date_range[1], ' to ', $payment_date_range[2])" />  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'payments']/row)">
		<xsl:for-each-group select="/all_results/results[@name='payments']/row" group-by="./mrktmr">
			<xsl:variable name="market" select="current-group()[position() = 1]/mrktmr" />
			<xsl:variable name="marketname" select="current-group()[position() = 1]/marketdesc" />

			<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always" space-before="10px">
					<xsl:value-of select="'Market:  '"/>
					<xsl:value-of select="$market"/>
					<xsl:value-of select="' - '"/>
					<xsl:value-of select="$marketname"/>
			</fo:block>			
	
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="0.75in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Account</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Account Name</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Batch Id</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Originating Place</fo:block>
								</fo:table-cell>								
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Payment Date</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Payment Ref</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Payment Amount</fo:block>
								</fo:table-cell>
							</fo:table-row>
					</fo:table-header>					
					<fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'payments']/row[mrktmr = $market]">    
								<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:choose>
											<xsl:when test="exists(./cycle) and ./cycle &gt; ''" >
												<xsl:value-of select="format-number(./cycle, '000')"/>
												<xsl:value-of select="'-'"/>
												<xsl:value-of select="format-number(./account, '0000000')"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="./cycle"/>
												<xsl:value-of select="'-'"/>
												<xsl:value-of select="./account"/>
											</xsl:otherwise>
											</xsl:choose>
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:value-of select="normalize-space(./fname)"/>
											<xsl:value-of select="' '"/>
											<xsl:value-of select="normalize-space(./lname)"/>									
										</fo:block>
									</fo:table-cell>	
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
										<fo:block>
											<xsl:value-of select="./btchid" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:value-of select="./orgplc"/>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:call-template name="date4parm">
												<xsl:with-param name="cc" select="./pycc"/>
												<xsl:with-param name="yy" select="./pyyy"/>
												<xsl:with-param name="mm" select="./pymm"/>
												<xsl:with-param name="dd" select="./pydd"/>
											</xsl:call-template>										
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
											<xsl:value-of select="./refno"/>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(./payamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
										</fo:block>
									</fo:table-cell>									
								</fo:table-row>		
						 	</xsl:for-each>					 
						</fo:table-body>
				</fo:table>    
			</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No Payments Found
			</fo:block>
		</xsl:otherwise>
	</xsl:choose>		
</xsl:template>

</xsl:stylesheet>






