<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
							  xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
							  xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				              xmlns:saxon="http://saxon.sf.net/"							  
							  xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
								extension-element-prefixes="saxon"							  
							  exclude-result-prefixes="java" 
							  version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="'POS Adjustments By Date Report'" />

    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>	
    <xsl:template name="body_process">
		 <xsl:choose>
			<xsl:when test="/all_results/results[@name = 'data']/row">
				<xsl:if test="$group_by_item = 'TRUE'">
				<xsl:for-each-group select="/all_results/results[@name='data']/row" group-by="./itemno">
					<xsl:variable name="itemno" select="current-group()[position() = 1]/itemno"/>
					<xsl:variable name="itemdesc" select="current-group()[position() = 1]/itemdesc"/>					
					<xsl:variable name="grouptotal" select="format-number(sum(/all_results/results[@name = 'data']/row[itemno = $itemno]/amt), '$ ##,###,##0.00;$ -#,###,##0.00')"/>
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always" space-before="10px" space-after="5px">
		    				<xsl:value-of select="$itemdesc"/>
                            <xsl:value-of select="' ('"/>	
		    				<xsl:value-of select="$itemno"/>	
				    		<xsl:value-of select="') Total Amount : '"/>
						    <xsl:value-of select="$grouptotal"/>						
		    		</fo:block>	
		
		
					<fo:table table-layout="fixed" width="100%" space-before="5px">
									<fo:table-column column-width="0.50in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.5in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
					     <fo:table-header>
							<fo:table-row>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Batch</fo:block>
						    	</fo:table-cell>							
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Payment Date</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Account</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Service No.</fo:block>
						    	</fo:table-cell>						    	
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Account Name</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Adjustment Amount</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Drawer</fo:block>
						    	</fo:table-cell>																							
							</fo:table-row>
						 </fo:table-header>
						 <fo:table-body>
							     <xsl:for-each select="/all_results/results[@name = 'data']/row[itemno = $itemno]">	
							 		<fo:table-row number-columns-spanned="7">

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
											<xsl:if test="./btchid &gt; 0">
												<fo:block>
													<xsl:value-of select="format-number(./btchid, '#####0')"/>	
												</fo:block>
											</xsl:if>
										</fo:table-cell>

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
												<xsl:call-template name="date1parm-db">
													<xsl:with-param name="date" select="./paydate" />
												</xsl:call-template>	
		                                    </fo:block>
		                                </fo:table-cell>							

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
												<xsl:value-of select="format-number(./cyc, '000')"/>
												<xsl:value-of select="'-'"/>
												<xsl:value-of select="format-number(./acct, '0000000')"/>
											</fo:block>
										</fo:table-cell>	
										
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<xsl:if test="./item_level = 'S'">
												<fo:block>
														<xsl:value-of select="format-number(./area, '000')" />
														<xsl:value-of select="'-'" />
														<xsl:value-of select="format-number(./xchng, '000')" />
														<xsl:value-of select="'-'" />
														<xsl:value-of select="format-number(./line, '0000')" />									
												</fo:block>
											</xsl:if>
										</fo:table-cell>																			

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
											<fo:block>
												<xsl:value-of select="./fname"/>
												<xsl:value-of select="' '"/>
												<xsl:value-of select="./lname"/>									
											</fo:block>
										</fo:table-cell>

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
											<fo:block>
												<xsl:value-of select="format-number(./amt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
											</fo:block>
										</fo:table-cell>	

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./drw" />
		                                    </fo:block>
		                                </fo:table-cell>																										

									</fo:table-row>
							 </xsl:for-each>
						 </fo:table-body>
					</fo:table>					
				</xsl:for-each-group>	
	            </xsl:if>
			    <xsl:if test="$group_by_item != 'TRUE'">
				     <xsl:variable name="total" select="format-number(sum(/all_results/results[@name = 'data']/row/amt), '$ ##,###,##0.00;$ -#,###,##0.00')"/> 
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always" space-before="10px" space-after="5px">	
				    		<xsl:value-of select="'Total Amount : '"/>
						    <xsl:value-of select="$total"/>						
		    		</fo:block>	 
					<fo:table table-layout="fixed" width="100%" space-before="5px">
									<fo:table-column column-width="0.50in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.5in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.5in" />
					     <fo:table-header>
							<fo:table-row>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Batch</fo:block>
						    	</fo:table-cell>							
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Payment Date</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Account</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Service No.</fo:block>
						    	</fo:table-cell>						    	
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Account Name</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Adjustment Amount</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Drawer</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Item#</fo:block>
						    	</fo:table-cell>	
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Item Desc</fo:block>
						    	</fo:table-cell>																						
							</fo:table-row>
						 </fo:table-header>
						 <fo:table-body>
							     <xsl:for-each select="/all_results/results[@name = 'data']/row">	
							 		<fo:table-row number-columns-spanned="9">

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
											<xsl:if test="./btchid &gt; 0">
												<fo:block>
													<xsl:value-of select="format-number(./btchid, '#####0')"/>	
												</fo:block>
											</xsl:if>
										</fo:table-cell>

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
												<xsl:call-template name="date1parm-db">
													<xsl:with-param name="date" select="./paydate" />
												</xsl:call-template>	
		                                    </fo:block>
		                                </fo:table-cell>							

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
												<xsl:value-of select="format-number(./cyc, '000')"/>
												<xsl:value-of select="'-'"/>
												<xsl:value-of select="format-number(./acct, '0000000')"/>
											</fo:block>
										</fo:table-cell>	
										
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<xsl:if test="./item_level = 'S'">
												<fo:block>
														<xsl:value-of select="format-number(./area, '000')" />
														<xsl:value-of select="'-'" />
														<xsl:value-of select="format-number(./xchng, '000')" />
														<xsl:value-of select="'-'" />
														<xsl:value-of select="format-number(./line, '0000')" />									
												</fo:block>
											</xsl:if>
										</fo:table-cell>										

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
											<fo:block>
												<xsl:value-of select="./fname"/>
												<xsl:value-of select="' '"/>
												<xsl:value-of select="./lname"/>									
											</fo:block>
										</fo:table-cell>

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
											<fo:block>
												<xsl:value-of select="format-number(./amt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
											</fo:block>
										</fo:table-cell>	

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./drw" />
		                                    </fo:block>
		                                </fo:table-cell>	
		
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./itemno" />
		                                    </fo:block>
		                                </fo:table-cell>
		
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./itemdesc" />
		                                    </fo:block>
		                                </fo:table-cell>																													

									</fo:table-row>
							 </xsl:for-each>
						 </fo:table-body>
					</fo:table>		    
			    </xsl:if>
			</xsl:when>		
   			<xsl:when test="count(/all_results/results[@name = 'data']/row) &lt; 1">
      			<fo:block xsl:use-attribute-sets="category-label">No POS Adjustments found for this Date Range.</fo:block>
   			</xsl:when>			
 		</xsl:choose>
    </xsl:template>
</xsl:stylesheet>
