<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="java"
	version="2.0">

	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title">
		<xsl:choose>
			<xsl:when test="$report_type = 1">
				<xsl:value-of select="concat('CC Transaction Summary ', $sold_date[1], ' to ', $sold_date[2])" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat('CC Transaction Detail ', $sold_date[1], ' to ', $sold_date[2])" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="marketcount" select="/all_results/results[@name='market']/row/marketcount" />	

	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>

	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="$report_type = 1 and /all_results/results[@name = 'merchsum']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'merchsum']/row" group-by="./merchid">
					<xsl:variable name="merchid" select="./merchid" />
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:value-of select="'Merchant Id: '" />
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
					</fo:block>
					
					<xsl:for-each-group select="/all_results/results[@name = 'merchsum']/row[merchid = $merchid]" group-by="./transdate">
						<xsl:variable name="date" select="./transdate" />
						<fo:table table-layout="fixed" width="100%" space-before="16px">

							<xsl:call-template name="header">
								<xsl:with-param name="date" select="$date" />
							</xsl:call-template>

							<fo:table-body>
								<xsl:call-template name="merchsumrow">
									<xsl:with-param name="date" select="$date" />
									<xsl:with-param name="merchid" select="$merchid" />
								</xsl:call-template>
								<fo:table-row keep-with-previous="always">
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="3">
										<fo:block keep-with-previous="always">
											<xsl:value-of select="'Total for '" />
											<xsl:value-of select="$date" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'merchsum']/row[merchid = $merchid and transdate = $date]/cnt)" />
										<fo:block keep-with-previous="always">
											<xsl:value-of select="format-number($cnt, '###,##0')" />
										</fo:block>
									</fo:table-cell>									
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="total" select="sum(/all_results/results[@name = 'merchsum']/row[merchid = $merchid and transdate = $date]/ccamt)" />
										<xsl:choose>
											<xsl:when test="$total &lt; 0">
												<fo:block font-weight="bold" color="#FF0000" keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</xsl:for-each-group>

					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:value-of select="'Total for Merchant Id '" />
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
						<xsl:value-of select="' - '" />
						<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'merchsum']/row[merchid = $merchid]/cnt)" />
						<xsl:value-of select="format-number($cnt, '###,##0')" />
						<xsl:value-of select="' Transactions '" />
						<xsl:variable name="total" select="sum(/all_results/results[@name = 'merchsum']/row[merchid = $merchid]/ccamt)" />
						<xsl:choose>
						<xsl:when test="$total &lt; 0">
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</xsl:for-each-group>
				<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
					<xsl:value-of select="'Total for date range '" />
					<xsl:value-of select="' - '" />
					<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'merchsum']/row/cnt)" />
					<xsl:value-of select="format-number($cnt, '###,##0')" />
					<xsl:value-of select="' Transactions '" />
					<xsl:variable name="total" select="sum(/all_results/results[@name = 'merchsum']/row/ccamt)" />
					<xsl:choose>
					<xsl:when test="$total &lt; 0">
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:otherwise>
					</xsl:choose>
				</fo:block>				

			</xsl:when>
			<xsl:when test="$report_type = 2 and /all_results/results[@name = 'merchcardsum']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'merchcardsum']/row" group-by="./merchid">
					<xsl:variable name="merchid" select="./merchid" />
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:value-of select="'Merchant Id: '" />
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
					</fo:block>
					
					<xsl:for-each-group select="/all_results/results[@name = 'merchcardsum']/row[merchid = $merchid]" group-by="./cctype">
						<xsl:variable name="cardtype" select="./cctype" />
						<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
							<xsl:value-of select="'Card Type: '" />
							<xsl:value-of select="$cardtype" />
						</fo:block>

						<xsl:for-each-group select="/all_results/results[@name = 'merchcardsum']/row[merchid = $merchid and cctype = $cardtype]" group-by="./transdate">
							<xsl:variable name="date" select="./transdate" />
							<fo:table table-layout="fixed" width="100%" space-before="16px">
	
								<xsl:call-template name="header">
									<xsl:with-param name="date" select="$date" />
								</xsl:call-template>
	
								<fo:table-body>
									<xsl:call-template name="merchcardsumrow">
										<xsl:with-param name="date" select="$date" />
										<xsl:with-param name="merchid" select="$merchid" />
										<xsl:with-param name="cardtype" select="$cardtype" />
									</xsl:call-template>
									<fo:table-row keep-with-previous="always">
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="3">
											<fo:block keep-with-previous="always">
												<xsl:value-of select="'Total for '" />
												<xsl:value-of select="$date" />
											</fo:block>
										</fo:table-cell>				
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
											<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'merchcardsum']/row[merchid = $merchid and cctype = $cardtype and transdate = $date]/cnt)" />
											<fo:block keep-with-previous="always">
												<xsl:value-of select="format-number($cnt, '###,##0')" />
											</fo:block>
										</fo:table-cell>																
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
											<xsl:variable name="total" select="sum(/all_results/results[@name = 'merchcardsum']/row[merchid = $merchid and cctype = $cardtype and transdate = $date]/ccamt)" />
											<xsl:choose>
												<xsl:when test="$total &lt; 0">
													<fo:block font-weight="bold" color="#FF0000" keep-with-previous="always">
														<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</xsl:when>
												<xsl:otherwise>
													<fo:block keep-with-previous="always">
														<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
													</fo:block>
												</xsl:otherwise>
											</xsl:choose>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</xsl:for-each-group>
						<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
							<xsl:value-of select="'Total for Card Type '" />
							<xsl:value-of select="$cardtype" />
							<xsl:value-of select="' - '" />
							<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'merchcardsum']/row[cctype = $cardtype and merchid = $merchid]/cnt)" />
							<xsl:value-of select="format-number($cnt, '###,##0')" />
							<xsl:value-of select="' Transactions '" />
							<xsl:variable name="total" select="sum(/all_results/results[@name = 'merchcardsum']/row[cctype = $cardtype and merchid = $merchid]/ccamt)" />
							<xsl:choose>
							<xsl:when test="$total &lt; 0">
								<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</xsl:otherwise>
							</xsl:choose>
						</fo:block>	
												
					</xsl:for-each-group>
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:value-of select="'Total for Merchant Id '" />
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
						<xsl:value-of select="' - '" />
						<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'merchcardsum']/row[merchid = $merchid]/cnt)" />
						<xsl:value-of select="format-number($cnt, '###,##0')" />
						<xsl:value-of select="' Transactions '" />
						<xsl:variable name="total" select="sum(/all_results/results[@name = 'merchcardsum']/row[merchid = $merchid]/ccamt)" />
						<xsl:choose>
						<xsl:when test="$total &lt; 0">
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>					
				</xsl:for-each-group>
				<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
					<xsl:value-of select="'Total for date range '" />
					<xsl:value-of select="' - '" />
					<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'merchcardsum']/row/cnt)" />
					<xsl:value-of select="format-number($cnt, '###,##0')" />
					<xsl:value-of select="' Transactions '" />
					<xsl:variable name="total" select="sum(/all_results/results[@name = 'merchcardsum']/row/ccamt)" />
					<xsl:choose>
					<xsl:when test="$total &lt; 0">
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:otherwise>
					</xsl:choose>
				</fo:block>				

			</xsl:when>			
			<xsl:when test="$report_type = 3 and /all_results/results[@name = 'drawersum']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'drawersum']/row" group-by="./drawername">
					<xsl:variable name="drawername" select="./drawername" />
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px" keep-with-next="always">
						<xsl:choose>
						<xsl:when test="normalize-space($drawername) > ''" >
							<xsl:value-of select="'Drawer: '" />
							<xsl:value-of select="$drawername" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'Web Payments '" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
					
					<xsl:for-each-group select="/all_results/results[@name = 'drawersum']/row[drawername = $drawername]" group-by="./transdate">
						<xsl:variable name="date" select="./transdate" />
						<fo:table table-layout="fixed" width="100%" space-before="16px">
	
							<xsl:call-template name="header">
								<xsl:with-param name="date" select="$date" />
							</xsl:call-template>
	
							<fo:table-body>
								<xsl:call-template name="drawersumrow">
									<xsl:with-param name="date" select="$date" />
									<xsl:with-param name="drawername" select="$drawername" />
								</xsl:call-template>
								<fo:table-row keep-with-previous="always">
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="5">
										<fo:block keep-with-previous="always">
											<xsl:value-of select="'Total for '" />
											<xsl:value-of select="$date" />
										</fo:block>
									</fo:table-cell>				
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'drawersum']/row[drawername = $drawername and transdate = $date]/cnt)" />
										<fo:block keep-with-previous="always">
											<xsl:value-of select="format-number($cnt, '###,##0')" />
										</fo:block>
									</fo:table-cell>																
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="total" select="sum(/all_results/results[@name = 'drawersum']/row[drawername = $drawername and transdate = $date and exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
										<xsl:choose>
								 			<xsl:when test="$total &lt; 0">
												<fo:block font-weight="bold" color="#FF0000" keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
												
					</xsl:for-each-group>
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:choose>
						<xsl:when test="normalize-space($drawername) > ''" >
							<xsl:value-of select="'Total for Drawer: '" />
							<xsl:value-of select="$drawername" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'Total for Web Payments '" />
						</xsl:otherwise>
						</xsl:choose>
						<xsl:value-of select="' - '" />
						<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'drawersum']/row[drawername = $drawername]/cnt)" />
						<xsl:value-of select="format-number($cnt, '###,##0')" />
						<xsl:value-of select="' Transactions '" />
						<xsl:variable name="total" select="sum(/all_results/results[@name = 'drawersum']/row[drawername = $drawername and exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
						<xsl:choose>
						<xsl:when test="$total &lt; 0">
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>					
				</xsl:for-each-group>
				<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
					<xsl:value-of select="'Total for date range '" />
					<xsl:value-of select="' - '" />
					<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'drawersum']/row/cnt)" />
					<xsl:value-of select="format-number($cnt, '###,##0')" />
					<xsl:value-of select="' Transactions '" />
					<xsl:variable name="total" select="sum(/all_results/results[@name = 'drawersum']/row[exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
					<xsl:choose>
					<xsl:when test="$total &lt; 0">
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:otherwise>
					</xsl:choose>
				</fo:block>				

			</xsl:when>
			<xsl:when test="$report_type = 5 and /all_results/results[@name = 'marketsum']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'marketsum']/row" group-by="./market">
					<xsl:variable name="market" select="current-group()[position() = 1]/market" />
					<xsl:variable name="marketname" select="current-group()[position() = 1]/marketname" />
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px" keep-with-next="always">
						<xsl:value-of select="'Market: '" />
						<xsl:value-of select="$market" />
						<xsl:value-of select="' - '" />
						<xsl:value-of select="$marketname" />
					</fo:block>
					
					<xsl:for-each-group select="/all_results/results[@name = 'marketsum']/row[market = $market]" group-by="./transdate">
						<xsl:variable name="date" select="./transdate" />
						<fo:table table-layout="fixed" width="100%" space-before="16px">
	
							<xsl:call-template name="header">
								<xsl:with-param name="date" select="$date" />
							</xsl:call-template>
	
							<fo:table-body>
								<xsl:call-template name="marketsumrow">
									<xsl:with-param name="date" select="$date" />
									<xsl:with-param name="market" select="$market" />
								</xsl:call-template>
								<fo:table-row keep-with-previous="always">
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="5">
										<fo:block keep-with-previous="always">
											<xsl:value-of select="'Total for '" />
											<xsl:value-of select="$date" />
										</fo:block>
									</fo:table-cell>				
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'marketsum']/row[market = $market and transdate = $date]/cnt)" />
										<fo:block keep-with-previous="always">
											<xsl:value-of select="format-number($cnt, '###,##0')" />
										</fo:block>
									</fo:table-cell>																
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="total" select="sum(/all_results/results[@name = 'marketsum']/row[market = $market and transdate = $date and exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
										<xsl:choose>
								 			<xsl:when test="$total &lt; 0">
												<fo:block font-weight="bold" color="#FF0000" keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
												
					</xsl:for-each-group>
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:value-of select="'Total for Market: '" />
						<xsl:value-of select="$market" />
						<xsl:value-of select="' - '" />
						<xsl:value-of select="$marketname" />
						<xsl:value-of select="' - '" />
						<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'marketsum']/row[market = $market]/cnt)" />
						<xsl:value-of select="format-number($cnt, '###,##0')" />
						<xsl:value-of select="' Transactions '" />
						<xsl:variable name="total" select="sum(/all_results/results[@name = 'marketsum']/row[dmarket = $market and exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
						<xsl:choose>
						<xsl:when test="$total &lt; 0">
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>					
				</xsl:for-each-group>
				<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
					<xsl:value-of select="'Total for date range '" />
					<xsl:value-of select="' - '" />
					<xsl:variable name="cnt" select="sum(/all_results/results[@name = 'marketsum']/row/cnt)" />
					<xsl:value-of select="format-number($cnt, '###,##0')" />
					<xsl:value-of select="' Transactions '" />
					<xsl:variable name="total" select="sum(/all_results/results[@name = 'marketsum']/row[exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
					<xsl:choose>
					<xsl:when test="$total &lt; 0">
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:otherwise>
					</xsl:choose>
				</fo:block>				

			</xsl:when>				
			<xsl:when test="$report_type = 4 and /all_results/results[@name = 'detail']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'detail']/row" group-by="./merchid">
					<xsl:variable name="merchid" select="./merchid" />
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:value-of select="'Merchant Id: '" />
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
					</fo:block>

					<xsl:for-each-group select="/all_results/results[@name = 'detail']/row[merchid = $merchid]" group-by="./transdate">
						<xsl:variable name="date" select="./transdate" />

						<fo:table table-layout="fixed" width="100%" space-before="16px">
							<xsl:call-template name="header">
								<xsl:with-param name="date" select="$date" />
							</xsl:call-template>

							<fo:table-body>

								<xsl:call-template name="detailrow">
									<xsl:with-param name="date" select="$date" />
									<xsl:with-param name="merchid" select="$merchid" />
								</xsl:call-template>
								<fo:table-row keep-with-previous="always">
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="{if ($marketcount > 1) then 11 else 10}">
										<fo:block keep-with-previous="always">
											<xsl:value-of select="'Total for '" />
											<xsl:value-of select="$date" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="cnt" select="count(/all_results/results[@name = 'detail']/row[transdate = $date and merchid = $merchid])" />
										<fo:block keep-with-previous="always">
											<xsl:value-of select="'Count '" />
											<xsl:value-of select="format-number($cnt, '###,##0')" />
										</fo:block>
									</fo:table-cell>									
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<xsl:variable name="total" select="sum(/all_results/results[@name = 'detail']/row[transdate = $date and merchid = $merchid and (valid = '1' or valid = 'A') and exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
										<xsl:choose>
											<xsl:when test="$total &lt; 0">
												<fo:block font-weight="bold" color="#FF0000" keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:when>
											<xsl:otherwise>
												<fo:block keep-with-previous="always">
													<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
												</fo:block>
											</xsl:otherwise>
										</xsl:choose>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</xsl:for-each-group>
					
					<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
						<xsl:value-of select="'Total for Merchant Id '" />
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
						<xsl:value-of select="' - '" />
						<xsl:variable name="cnt" select="count(/all_results/results[@name = 'detail']/row[merchid = $merchid])" />
						<xsl:value-of select="format-number($cnt, '###,##0')" />
						<xsl:value-of select="' Transactions '" />
						<xsl:variable name="total" select="sum(/all_results/results[@name = 'detail']/row[merchid = $merchid and exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
						<xsl:choose>
						<xsl:when test="$total &lt; 0">
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>	
				</xsl:for-each-group>
				<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px" font-size="12px">
					<xsl:value-of select="'Total for date range '" />
					<xsl:value-of select="' - '" />
					<xsl:variable name="cnt" select="count(/all_results/results[@name = 'detail']/row)" />
					<xsl:value-of select="format-number($cnt, '###,##0')" />
					<xsl:value-of select="' Transactions '" />
					<xsl:variable name="total" select="sum(/all_results/results[@name = 'detail']/row[exists(ccamt) and normalize-space(ccamt) > '']/ccamt)" />
					<xsl:choose>
					<xsl:when test="$total &lt; 0">
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="format-number($total, '$ ##,###,##0.00;$ -#,###,##0.00')" />
					</xsl:otherwise>
					</xsl:choose>
				</fo:block>				

			</xsl:when>
			<xsl:otherwise>
				<fo:block>No Transactions Found For Date Range</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="header">
		<xsl:param name="date" />

		<xsl:choose>
			<xsl:when test="$report_type = 1">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="5" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
								<xsl:value-of select="'Date: '" />
								<xsl:value-of select="$date" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Transaction Method
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Transaction Type
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Source
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Count
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Total
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
			</xsl:when>
			<xsl:when test="$report_type = 2">
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="5" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
								<xsl:value-of select="'Date: '" />
								<xsl:value-of select="$date" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Transaction Method
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Transaction Type
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Source
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Count
				     		</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Total
				     		</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
			</xsl:when>
			<xsl:when test="$report_type = 3 or $report_type = 5">
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="3.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="7" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
								<xsl:value-of select="'Date: '" />
								<xsl:value-of select="$date" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Merchant
										</fo:block>
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Transaction Method
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Card Type
										</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Transaction Type
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Source
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Count
							</fo:block>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Total
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
			</xsl:when>			
			<xsl:otherwise>
				<xsl:if test="$marketcount > 1">
					<fo:table-column column-width="0.4in" />
				</xsl:if>
				<fo:table-column column-width="0.4in" />
				<fo:table-column column-width="0.4in" />
				<fo:table-column column-width="0.4in" />
				<fo:table-column column-width="0.4in" />
				<fo:table-column column-width="1.1in" />
				<fo:table-column column-width="0.7in" />
				<fo:table-column column-width="1.1in" />
				<fo:table-column column-width="1.3in" />
				<fo:table-column column-width="0.7in" />
				<fo:table-column column-width="0.4in" />
				<fo:table-column column-width="1.6in" />
				<fo:table-column column-width="0.8in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="12" text-align="left">
							<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
								<xsl:value-of select="'Date: '" />
								<xsl:value-of select="$date" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row keep-with-next="always">
						<xsl:if test="$marketcount > 1">
							<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
									Mkt
											</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Trans Time
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Trans Mthd
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Trans Type
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Card Type
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Drawer
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Account
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Trans #
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								CC Name
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Src
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								By
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Ref #
										</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>
								Chrg Amt
										</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="merchsumrow">
		<xsl:param name="date" />
		<xsl:param name="merchid" />

		<xsl:for-each select="/all_results/results[@name = 'merchsum']/row[merchid = $merchid and transdate = $date]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./authtype" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:choose>
						<xsl:when test="normalize-space(./transtype) = 'REFUND'">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<xsl:choose>
						<xsl:when test="normalize-space(./transdesc) = 'Web Payment(interactive)'">
							<fo:block>
								<xsl:value-of select="'Web Payment(interactive)'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Auto ACH Payment'">
							<fo:block>
								<xsl:value-of select="'Auto ACH Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Automatic - Credit Card Payment'">
							<fo:block>
								<xsl:value-of select="'Automatic - Credit Card Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="'Point-of-Sale Transaction'" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:value-of select="format-number(./cnt, '###,##0')" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<xsl:choose>
						<xsl:when test="exists(ccamt) and normalize-space(ccamt) > '' and ./ccamt &lt; 0">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:when test="exists(ccamt) and normalize-space(ccamt) > ''">
							<fo:block>
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="' '"/>
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="merchcardsumrow">
		<xsl:param name="date" />
		<xsl:param name="merchid" />
		<xsl:param name="cardtype" />

		<xsl:for-each select="/all_results/results[@name = 'merchcardsum']/row[merchid = $merchid and cctype = $cardtype and transdate = $date]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./authtype" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:choose>
						<xsl:when test="normalize-space(./transtype) = 'REFUND'">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<xsl:choose>
						<xsl:when test="normalize-space(./transdesc) = 'Web Payment(interactive)'">
							<fo:block>
								<xsl:value-of select="'Web Payment(interactive)'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Auto ACH Payment'">
							<fo:block>
								<xsl:value-of select="'Auto ACH Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Automatic - Credit Card Payment'">
							<fo:block>
								<xsl:value-of select="'Automatic - Credit Card Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="'Point-of-Sale Transaction'" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:value-of select="format-number(./cnt, '###,##0')" />
					</fo:block>
				</fo:table-cell>								
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<xsl:choose>
						<xsl:when test="exists(ccamt) and normalize-space(ccamt) > '' and ./ccamt &lt; 0">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:when test="exists(ccamt) and normalize-space(ccamt) > ''">
							<fo:block>
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="' '"/>
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="drawersumrow">
		<xsl:param name="date" />
		<xsl:param name="drawername" />

		<xsl:for-each select="/all_results/results[@name = 'drawersum']/row[drawername = $drawername and transdate = $date]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:variable name="merchid" select="./merchid" />
					<fo:block>
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./authtype" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:choose>
						<xsl:when test="normalize-space(./transtype) = 'REFUND'">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./cctype" />
					</fo:block>
				</fo:table-cell>					
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<xsl:choose>
						<xsl:when test="normalize-space(./transdesc) = 'Web Payment(interactive)'">
							<fo:block>
								<xsl:value-of select="'Web Payment(interactive)'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Auto ACH Payment'">
							<fo:block>
								<xsl:value-of select="'Auto ACH Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Automatic - Credit Card Payment'">
							<fo:block>
								<xsl:value-of select="'Automatic - Credit Card Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="'Point-of-Sale Transaction'" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:value-of select="format-number(./cnt, '###,##0')" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<xsl:choose>
						<xsl:when test="exists(./ccamt) and normalize-space(./ccamt) > '' and ./ccamt &lt; 0">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:when test="exists(./ccamt) and normalize-space(./ccamt) > ''">
							<fo:block>
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="'               '" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="marketsumrow">
		<xsl:param name="date" />
		<xsl:param name="market" />

		<xsl:for-each select="/all_results/results[@name = 'marketsum']/row[market = $market and transdate = $date]">
			<fo:table-row>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:variable name="merchid" select="./merchid" />
					<fo:block>
						<xsl:value-of select="/all_results/results[@name = 'merch']/row[login = $merchid]/desc" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./authtype" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:choose>
						<xsl:when test="normalize-space(./transtype) = 'REFUND'">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./cctype" />
					</fo:block>
				</fo:table-cell>					
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<xsl:choose>
						<xsl:when test="normalize-space(./transdesc) = 'Web Payment(interactive)'">
							<fo:block>
								<xsl:value-of select="'Web Payment(interactive)'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Auto ACH Payment'">
							<fo:block>
								<xsl:value-of select="'Auto ACH Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Automatic - Credit Card Payment'">
							<fo:block>
								<xsl:value-of select="'Automatic - Credit Card Payment'" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="'Point-of-Sale Transaction'" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:value-of select="format-number(./cnt, '###,##0')" />
					</fo:block>
				</fo:table-cell>				
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<xsl:choose>
						<xsl:when test="exists(./ccamt) and normalize-space(./ccamt) > '' and ./ccamt &lt; 0">
							<fo:block font-weight="bold" color="#FF0000">
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:when test="exists(./ccamt) and normalize-space(./ccamt) > ''">
							<fo:block>
								<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:value-of select="'               '" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="detailrow">
		<xsl:param name="date" />
		<xsl:param name="merchid" />

		<xsl:for-each select="/all_results/results[@name = 'detail']/row[merchid = $merchid and transdate = $date]">
			<fo:table-row>
				<xsl:if test="$marketcount > 1">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
						<fo:block font-size="6.5pt">
							<xsl:value-of select="./market" />
						</fo:block>
					</fo:table-cell>
				</xsl:if>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block font-size="6.5pt">
						<xsl:value-of select="./transtime" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block font-size="6.5pt">
						<xsl:value-of select="./authtype" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:choose>
						<xsl:when test="normalize-space(./transtype) = 'REFUND'">
							<fo:block font-size="6.5pt" font-weight="bold" color="#FF0000">
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block font-size="6.5pt">
								<xsl:value-of select="./transtype" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block font-size="6.5pt">
						<xsl:value-of select="./cctype" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block font-size="6.5pt">
						<xsl:choose>
						<xsl:when test="normalize-space(./drwnam) > ''" >
							<xsl:value-of select="./drwnam" />
						</xsl:when>
						<xsl:when test="./chrgby = 'WWW'">
							<xsl:value-of select="'Web Payments '" />
						</xsl:when>
						<xsl:when test="//transdesc = 'Prepay Autopay' or ./transdesc = 'Monthly Autopay' " >
							<xsl:value-of select="./transdesc" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'Invalid/Incomplete '" />
						</xsl:otherwise>
						</xsl:choose>						
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block font-size="6.5pt">
						<xsl:choose>
							<xsl:when test="./cycle != 0 and ./acct != 0">
								<xsl:value-of select="format-number(./cycle, '000')" />
								<xsl:value-of select="'-'" />
								<xsl:value-of select="format-number(./acct, '0000000')" />
							</xsl:when>
							<xsl:otherwise>
								<fo:block font-size="6.5pt">
									<xsl:value-of select="'Walk-in'" />
								</fo:block>
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block font-size="6.5pt">
						<xsl:choose>
							<xsl:when test="./invcno != '' and ./invcno != 0">
								<xsl:value-of select="./invcno" />
							</xsl:when>
							<xsl:otherwise>
								<fo:block>
									<xsl:value-of select="' '" />
								</fo:block>
							</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block font-size="6.5pt">
						<xsl:value-of select="./cclname" />
						<xsl:value-of select="', '" />
						<xsl:value-of select="./ccfname" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:choose>
						<xsl:when test="normalize-space(./transdesc) = 'Web Payment(interactive)'">
							<fo:block font-size="6.5pt">
								<xsl:value-of select="'Web Pay'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Auto ACH Payment'">
							<fo:block font-size="6.5pt">
								<xsl:value-of select="'Auto ACH Pay'" />
							</fo:block>
						</xsl:when>
						<xsl:when test="normalize-space(./transdesc) = 'Automatic - Credit Card Payment'">
							<fo:block font-size="6.5pt">
								<xsl:value-of select="'Auto CC Pay'" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block font-size="6.5pt">
								<xsl:value-of select="'POS Tran'" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block font-size="6.5pt">
						<xsl:value-of select="./chrgby" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<xsl:choose>
						<xsl:when test="valid = '1' or valid = 'A'">
							<fo:block font-size="6.5pt">
								<xsl:value-of select="./rsptrace" />
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block font-size="6.5pt" font-weight="bold" color="#FF0000" font-style="italic">
								<xsl:value-of select="./rsptext" />
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<xsl:choose>
						<xsl:when test="valid = '1' or valid = 'A'">
							<xsl:choose>
								<xsl:when test="exists(ccamt) and normalize-space(ccamt) > '' and ./ccamt &lt; 0">
									<fo:block font-size="6.5pt" font-weight="bold" color="#FF0000">
										<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
									</fo:block>
								</xsl:when>
								<xsl:when test="exists(ccamt) and normalize-space(ccamt) > ''">
									<fo:block font-size="6.5pt">
										<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
									</fo:block>
								</xsl:when>
								<xsl:otherwise>
									<fo:block>
										<xsl:value-of select="' '"/>
									</fo:block>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:choose>
								<xsl:when test="normalize-space(./ccamt) = ''">
									<fo:block font-size="6.5pt" font-weight="bold" color="336666" font-style="italic">
										<xsl:value-of select="'&lt;'" />
										<xsl:value-of select="./amtraw" />
										<xsl:value-of select="'&gt;'" />
									</fo:block>
								</xsl:when>
								<xsl:when test="./ccamt &lt; 0">
									<fo:block font-size="6.5pt" font-weight="bold" color="#FF0000" font-style="italic">
										<xsl:value-of select="'&lt;'" />
										<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
										<xsl:value-of select="'&gt;'" />
									</fo:block>
								</xsl:when>
								<xsl:otherwise>
									<fo:block font-size="6.5pt" font-style="italic">
										<xsl:value-of select="'&lt;'" />
										<xsl:value-of select="format-number(./ccamt, '$ ##,###,##0.00;$ -#,###,##0.00')" />
										<xsl:value-of select="'&gt;'" />
									</fo:block>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
