<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								xmlns:convert="java:com.psasoft.util.ConversionUtilities"								
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl"/> 
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Items Sold GL Detail ', $sold_date[1], ' to ', $sold_date[2])" />
	
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	
	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="exists(/all_results/results[@name = 'detail']/row)">
				<xsl:for-each-group select="/all_results/results[@name = 'detail']/row" group-by="marketid">
					<xsl:variable name="market" select="current-group()[position() = 1]/marketid" />
					<xsl:variable name="marketname" select="current-group()[position() = 1]/market" />

					<xsl:for-each-group select="/all_results/results[@name = 'detail']/row[marketid = $market]" group-by="location">
						<xsl:variable name="location" select="current-group()[position() = 1]/location" />
						
						<fo:table table-layout="fixed" width="100%" space-before="16px">
							<xsl:call-template name="detailheader">
								<xsl:with-param name="market" select="$market" />
								<xsl:with-param name="marketname" select="$marketname" />
								<xsl:with-param name="location" select="$location" />
							</xsl:call-template>
							<fo:table-body>
								<xsl:call-template name="detailrow">
									<xsl:with-param name="market" select="$market" />
									<xsl:with-param name="location" select="$location" />
								</xsl:call-template>
							</fo:table-body>
						</fo:table>
					</xsl:for-each-group>
				</xsl:for-each-group>
			</xsl:when>
			<xsl:otherwise>
				<fo:block>No Items Found for selection(s)</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="detailheader">
		<xsl:param name="market" />
		<xsl:param name="marketname" />
		<xsl:param name="location" />

		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="1.50in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="1.50in" />
		<fo:table-column column-width="1.50in" />
		<fo:table-column column-width="0.50in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-header>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="10" text-align="left">
					<xsl:choose>
					<xsl:when test="normalize-space($market) != ''">
						<fo:block xsl:use-attribute-sets="summary-headings" font-style="normal">
							<xsl:value-of select="$market" />
							<xsl:value-of select="' - '" />
							<xsl:value-of select="$marketname" />
						</fo:block>
					</xsl:when>
					<xsl:otherwise>
						<fo:block xsl:use-attribute-sets="summary-headings" font-style="italic">
							<xsl:value-of select="'No Market Defined'" />
						</fo:block>
					</xsl:otherwise>
					</xsl:choose>
					<fo:block xsl:use-attribute-sets="summary-headings" font-style="normal">
						<xsl:value-of select="'          '" />
						<xsl:value-of select="$location" />
					</fo:block>					
				</fo:table-cell>
			</fo:table-row>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings"  text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Account
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Account Name
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Service Number
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Disc Date
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Transaction
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Item
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						GL Code
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Item Amount
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Tax Amount
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="center">
					<fo:block xsl:use-attribute-sets="summary-headings">
						Total Amount
					</fo:block>
				</fo:table-cell>												
			</fo:table-row>
		</fo:table-header>		
	</xsl:template>
	
	<xsl:template name="detailrow">
		<xsl:param name="market" />
		<xsl:param name="location" />
		<xsl:for-each select="/all_results/results[@name = 'detail']/row[marketid = $market and location = $location]">
			<fo:table-row>
				<xsl:choose>
				<xsl:when test="./cycle != 0 and ./account != 0">
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
						<fo:block>
							<xsl:value-of select="format-number(./cycle, '000')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number(./account, '0000000')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
						<fo:block>
							<xsl:value-of select="./fname" />
							<xsl:value-of select="' '" />
							<xsl:value-of select="./lname" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
						<fo:block>
							<xsl:if test="./npa &gt; 0 and ./nxx &gt; 0">
								<xsl:call-template name="phone">
									<xsl:with-param name="npa" select="./npa" />
									<xsl:with-param name="nxx" select="./nxx" />
									<xsl:with-param name="line" select="./line" />
								</xsl:call-template>
							</xsl:if>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
						<fo:block>
							<xsl:if test="./dcmm &gt; 0 and ./dcmm != 99">
								<xsl:call-template name="date4parm">
									<xsl:with-param name="cc" select="./dccc" />
									<xsl:with-param name="yy" select="./dcyy" />
									<xsl:with-param name="mm" select="./dcmm" />
									<xsl:with-param name="dd" select="./dcdd" />
								</xsl:call-template>
							</xsl:if>
							<xsl:value-of select="' '" />
						</fo:block>
					</fo:table-cell>
				</xsl:when>
				<xsl:otherwise>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center" number-columns-spanned="4">
						<fo:block>
							<xsl:value-of select="'Walkin'" />
						</fo:block>
					</fo:table-cell>				
				</xsl:otherwise>
				</xsl:choose>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
					<fo:block>
						<xsl:value-of select="./invc" />
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:choose>
						<xsl:when test="./item = 'PAY  '">
							<xsl:value-of select="'Payment'" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="./item" />
							<xsl:value-of select="' - '" />
							<xsl:value-of select="./itmdsc" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
					<fo:block>
						<xsl:value-of select="./glacct" />
						<xsl:if test="./subacct &gt; '0'">
								<xsl:value-of select="'-'" />
								<xsl:value-of select="./subacct" />
						</xsl:if>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:choose>
						<xsl:when test="./totitemamt != 0">
							<xsl:value-of select="format-number(./totitemamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/> 												
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:choose>
						<xsl:when test="./totalitemtax != 0">
							<xsl:value-of select="format-number(./totalitemtax, '$ ##,###,##0.00;$ -#,###,##0.00')"/> 												
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
					<fo:block>
						<xsl:choose>
						<xsl:when test="./totalitem != 0">
							<xsl:value-of select="format-number(./totalitem, '$ ##,###,##0.00;$ -#,###,##0.00')"/> 												
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>				
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
