<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
							  xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
							  xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				              xmlns:saxon="http://saxon.sf.net/"							  
							  xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
								extension-element-prefixes="saxon"							  
							  exclude-result-prefixes="java" 
							  version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="concat('POS Payments ', $date_range[1], ' to ', $date_range[2])" />
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>	
    <xsl:template name="body_process">
		 <xsl:choose>
			<xsl:when test="/all_results/results[@name = 'data']/row">
				<fo:block xsl:use-attribute-sets="category-label">
					Total = <xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row/amt), '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
				</fo:block>
						
			 	 <xsl:choose>
			 	 <xsl:when test="$report_type = 2">
					 <xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="drwnam">
					 	<xsl:variable name="drwnam" select="current-grouping-key()"/>
						<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left">
							<xsl:value-of select="'Drawer '" />
							<xsl:value-of select="$drwnam" />
						</fo:block>
						<fo:table table-layout="fixed" width="100%" space-before="5px">
							<xsl:call-template name="header" />
							<fo:table-body>
								<xsl:for-each select="/all_results/results[@name = 'data']/row[drwnam = $drwnam]">
									<xsl:call-template name="detailrow">
										<xsl:with-param name="row" select="." />
									</xsl:call-template>
								</xsl:for-each>
								<fo:table-row keep-with-next="always">
									<fo:table-cell xsl:use-attribute-sets="summary-title" number-columns-spanned="4">
										<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left">
											<xsl:value-of select="'Drawer '" />
											<xsl:value-of select="$drwnam" />
											<xsl:value-of select="' Totals '" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[drwnam = $drwnam]/amt), '$ ##,###,##0.00;$ -#,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell number-columns-spanned="3">
										<fo:block>
											<xsl:value-of select="' '" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
						<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="10px" text-align="left">
							<xsl:value-of select="'  '" />
						</fo:block>

					 </xsl:for-each-group>
				 </xsl:when>
			 	 <xsl:when test="$report_type = 3">
					 <xsl:for-each-group select="/all_results/results[@name = 'data']/row" group-by="subloc1">
					 	<xsl:variable name="subloc1" select="current-grouping-key()"/>
						<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left">
							<xsl:value-of select="'Location '" />
							<xsl:value-of select="$subloc1" />
						</fo:block>
						<fo:table table-layout="fixed" width="100%" space-before="5px">
							<xsl:call-template name="header" />
							<fo:table-body>
								<xsl:for-each select="/all_results/results[@name = 'data']/row[subloc1 = $subloc1]">
									<xsl:call-template name="detailrow">
										<xsl:with-param name="row" select="." />
									</xsl:call-template>
								</xsl:for-each>
								<fo:table-row keep-with-next="always">
									<fo:table-cell xsl:use-attribute-sets="summary-title" number-columns-spanned="4">
										<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="3px" text-align="left">
											<xsl:value-of select="'Location '" />
											<xsl:value-of select="$subloc1" />
											<xsl:value-of select="' Totals '" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
										<fo:block>
											<xsl:value-of select="format-number(sum(/all_results/results[@name = 'data']/row[subloc1 = $subloc1]/amt), '$ ##,###,##0.00;$ -#,###,##0.00')" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell number-columns-spanned="3">
										<fo:block>
											<xsl:value-of select="' '" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
						<fo:block xsl:use-attribute-sets="summary-title" keep-with-next="always" space-before="3px" space-after="10px" text-align="left">
							<xsl:value-of select="'  '" />
						</fo:block>

					 </xsl:for-each-group>
				 </xsl:when>				 
			 	 <xsl:otherwise>
					<fo:table table-layout="fixed" width="100%" space-before="5px">
						<xsl:call-template name="header" />
						 <fo:table-body>
							 <xsl:for-each select="/all_results/results[@name = 'data']/row">	
								<xsl:call-template name="detailrow">
									<xsl:with-param name="row" select="." />
								</xsl:call-template>
							 </xsl:for-each>
						 </fo:table-body>
					</fo:table>
					 
				 </xsl:otherwise>
				 </xsl:choose>						 
			</xsl:when>
       		<xsl:when test="count(/all_results/results[@name = 'data']/row) &lt; 1">
          		<fo:block xsl:use-attribute-sets="category-label">No payments for this Date Range.</fo:block>
       		</xsl:when>				
	 	</xsl:choose>
    </xsl:template>
    
    <xsl:template name="header">
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.5in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="1.5in" />
	     <fo:table-header>
			<fo:table-row>
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Batch</fo:block>
		    	</fo:table-cell>							
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Payment Date</fo:block>
		    	</fo:table-cell>
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Account</fo:block>
		    	</fo:table-cell>
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Account Name</fo:block>
		    	</fo:table-cell>
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Payment Amount</fo:block>
		    	</fo:table-cell>
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Drawer</fo:block>
		    	</fo:table-cell>
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Payment Ref</fo:block>
		    	</fo:table-cell>																								
		    	<fo:table-cell xsl:use-attribute-sets="table-headings">
		        	<fo:block>Invoice #</fo:block>
		    	</fo:table-cell>																								
			</fo:table-row>
		 </fo:table-header>    
    </xsl:template>
    
 	<xsl:template name="detailrow">
	<xsl:param name="row" />
		 	
 		<fo:table-row number-columns-spanned="7">

			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="$row/btchid"/>	
				</fo:block>
			</fo:table-cell>
	
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:call-template name="date1parm-db">
						<xsl:with-param name="date" select="$row/paydate" />
					</xsl:call-template>	
	                              </fo:block>
	                          </fo:table-cell>							
	
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="format-number($row/cyc, '000')"/>
					<xsl:value-of select="'-'"/>
					<xsl:value-of select="format-number($row/acct, '0000000')"/>
				</fo:block>
			</fo:table-cell>	
			
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/fname"/>
					<xsl:value-of select="' '"/>
					<xsl:value-of select="$row/lname"/>									
				</fo:block>
			</fo:table-cell>
			
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($row/amt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>	
				</fo:block>
			</fo:table-cell>	
			
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
				<fo:block>
                    <xsl:value-of select="$row/drw" />
                </fo:block>
            </fo:table-cell>
	
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="$row/ref"/>							
				</fo:block>
			</fo:table-cell>																											
	
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="$row/trcp"/>							
				</fo:block>
			</fo:table-cell>																											
	
		</fo:table-row>
 	</xsl:template>    
</xsl:stylesheet>
