<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Sales By Agent and Category ', $sold_date[1], ' to ', $sold_date[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:for-each-group select="/all_results/results[@name = 'sum']/row" group-by="./name">
				<xsl:variable name="name" select="current-group()[position() = 1]/name"/>
				<fo:table table-layout="fixed" width="100%" space-before="16px">
						<xsl:call-template name="header">
								<xsl:with-param name="name" select="$name"/>
								<xsl:with-param name="uname" select="/all_results/results[@name = 'sum']/row[position() = 1 and name = $name]/uname"/>
						</xsl:call-template>
						<fo:table-body>
							<xsl:call-template name="detailrow">
									<xsl:with-param name="name" select="$name"/>
							</xsl:call-template>									
					</fo:table-body>
			  </fo:table>

		</xsl:for-each-group>

</xsl:template>
    
<xsl:template name="header">
		<xsl:param name="name" />    
		<xsl:param name="uname" />    
		
		<fo:table-column column-width="1.5in" />
		<fo:table-column column-width="1.5in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-column column-width="1.0in" />
		<fo:table-header>
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings" number-columns-spanned="6" text-align="left">
								<fo:block xsl:use-attribute-sets="summary-headings" space-before="10px">
										<xsl:value-of select="'User: '"/>
										<xsl:value-of select="$uname"/>
										<xsl:value-of select="' - '"/>
										<xsl:value-of select="$name"/>
								</fo:block>	
						</fo:table-cell>
				</fo:table-row>		
				<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
								Item Category
								</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
								Sale Type
								</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
								Total Amount
								</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
								Total Collected Amount
								</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
								Total Bill To Amount
								</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
								<fo:block>
								Total Sold Count
								</fo:block>
						</fo:table-cell>
				</fo:table-row>
		</fo:table-header>
</xsl:template>

<xsl:template name="detailrow">
		<xsl:param name="name" />    
  	
		<xsl:for-each select="/all_results/results[@name = 'sum']/row[name = $name]">
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
										<xsl:value-of select="./category" />
								</fo:block>
					  </fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<xsl:choose>
								<xsl:when test="normalize-space(./ptrtyp) = 'PURCHASE'" >
									<fo:block>
										<xsl:value-of select="'Purchase'" />
									</fo:block>
								</xsl:when>
								<xsl:when test="normalize-space(./ptrtyp) = 'RETURN'" >
									<fo:block font-weight="bold" color="#FF0000">
										<xsl:value-of select="'Return'" />
									</fo:block>
								</xsl:when>
								<xsl:when test="normalize-space(./ptrtyp) = 'MISC'" >
									<fo:block>
										<xsl:value-of select="'Micellaneous'" />
									</fo:block>
								</xsl:when>					
								<xsl:when test="normalize-space(./ptrtyp) = 'ACCOUNT'" >
									<fo:block>
										<xsl:value-of select="'Account Install'" />
									</fo:block>
								</xsl:when>	
								<xsl:when test="normalize-space(./ptrtyp) = 'SERVICE'" >
									<fo:block>
										<xsl:value-of select="'Service Install'" />
									</fo:block>
								</xsl:when>									
								<xsl:otherwise>
									<fo:block>
										<xsl:value-of select="./ptrtyp" />
									</fo:block>
								</xsl:otherwise>
								</xsl:choose>
						</fo:table-cell>						
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<xsl:choose>
								<xsl:when test="./total &lt; 0">
										<fo:block font-weight="bold" color="#FF0000">
												<xsl:value-of select="format-number(./total, '##,###,##0.00')" />
										</fo:block>
								</xsl:when>									
								<xsl:otherwise>
										<fo:block>
												<xsl:value-of select="format-number(./total, '##,###,##0.00')" />
										</fo:block>
								</xsl:otherwise>
								</xsl:choose>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<xsl:choose>
								<xsl:when test="./pitamt &lt; 0">
										<fo:block font-weight="bold" color="#FF0000">
												<xsl:value-of select="format-number(./pitamt, '##,###,##0.00')" />
										</fo:block>
								</xsl:when>									
								<xsl:otherwise>
										<fo:block>
												<xsl:value-of select="format-number(./pitamt, '##,###,##0.00')" />
										</fo:block>
								</xsl:otherwise>
								</xsl:choose>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<xsl:choose>
								<xsl:when test="./pitamtbillto &lt; 0">
										<fo:block font-weight="bold" color="#FF0000">
												<xsl:value-of select="format-number(./pitamtbillto, '##,###,##0.00')" />
										</fo:block>
								</xsl:when>									
								<xsl:otherwise>
										<fo:block>
												<xsl:value-of select="format-number(./pitamtbillto, '##,###,##0.00')" />
										</fo:block>
								</xsl:otherwise>
								</xsl:choose>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
									<xsl:value-of select="format-number(./salecnt, '###,##0')" />
							</fo:block>
						</fo:table-cell>

																	
			  </fo:table-row>
		</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
