<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Sales Tax by Drawer Loca ', $sold_date[1], ' to ', $sold_date[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:call-template name="main">
				<xsl:with-param name="posfrom" select="0" />    
				<xsl:with-param name="posto" select="8" /> 										
		</xsl:call-template>
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 7]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="7" />    
						<xsl:with-param name="posto" select="15" /> 										
				</xsl:call-template>		
		</xsl:if>
		<xsl:if test="/all_results/results[@name = 'loca']/row[position() &gt; 14]">
				<fo:block break-before="page" />
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="14" />    
						<xsl:with-param name="posto" select="22" /> 										
				</xsl:call-template>		
		</xsl:if>		
</xsl:template>

<xsl:template name="main">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 
		
		<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.5in" />
				<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
						<fo:table-column column-width="1.2in" />
				</xsl:for-each>
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Tax Entity
										</fo:block>
								</fo:table-cell>									
								<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
													<xsl:value-of select="./location" />
													<xsl:value-of select="' '" />
													<xsl:value-of select="./city" />
													<xsl:value-of select="' '" />
													<xsl:value-of select="./state" />													
												</fo:block>
										</fo:table-cell>		
								</xsl:for-each>
						</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="'Total Invoice Amount'" />
							</fo:block>
						</fo:table-cell>	
						<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
								<xsl:variable name="loca" select="./location" />
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
										<fo:block>
												<xsl:variable name="totamt" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca]/totamt)"/>
												<xsl:choose>
												<xsl:when test="$totamt != 0">
														<xsl:value-of select="format-number($totamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:when>
												<xsl:otherwise>
														<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:otherwise>
												</xsl:choose>
										</fo:block>
								</fo:table-cell>		
						</xsl:for-each>																	
					</fo:table-row>		
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="'Total Installment Amount'" />
							</fo:block>
						</fo:table-cell>	
						<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
								<xsl:variable name="loca" select="./location" />
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
										<fo:block>
												<xsl:variable name="totamt" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca]/instamt)"/>
												<xsl:choose>
												<xsl:when test="$totamt != 0">
														<xsl:value-of select="format-number($totamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:when>
												<xsl:otherwise>
														<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:otherwise>
												</xsl:choose>
										</fo:block>
								</fo:table-cell>		
						</xsl:for-each>																	
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="'Total Taxable Amount'" />
							</fo:block>
						</fo:table-cell>	
						<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
								<xsl:variable name="loca" select="./location" />
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
										<fo:block>
												<xsl:variable name="totamt" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca]/taxable)"/>
												<xsl:choose>
												<xsl:when test="$totamt != 0">
														<xsl:value-of select="format-number($totamt, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:when>
												<xsl:otherwise>
														<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:otherwise>
												</xsl:choose>
										</fo:block>
								</fo:table-cell>		
						</xsl:for-each>																	
					</fo:table-row>														
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
										<xsl:value-of select="'Federal Tax'" />
								</fo:block>
							</fo:table-cell>	
							<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
									<xsl:variable name="loca" select="./location" />
									<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
											<fo:block>
													<xsl:variable name="fedtx" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca]/fedtx)"/>
													<xsl:choose>
													<xsl:when test="$fedtx != 0">
															<xsl:value-of select="format-number($fedtx, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:when>
													<xsl:otherwise>
															<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:otherwise>
													</xsl:choose>
											</fo:block>
									</fo:table-cell>		
							</xsl:for-each>																	
					</fo:table-row>		

					<xsl:for-each-group select="/all_results/results[@name = 'summuni']/row" group-by="./stname">
							<xsl:variable name="state" select="./stname"/>
							<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
												<xsl:value-of select="' ... '" />
												<xsl:value-of select="$state" />
										</fo:block>
									</fo:table-cell>	
									<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
											<xsl:variable name="loca" select="./location" />
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
													<fo:block>
															<xsl:variable name="statetx" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca and stname = $state]/statetx)"/>
															<xsl:choose>
															<xsl:when test="$statetx != 0">
																	<xsl:value-of select="format-number($statetx, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
															</xsl:when>
															<xsl:otherwise>
																	<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
															</xsl:otherwise>
															</xsl:choose>
													</fo:block>
											</fo:table-cell>		
									</xsl:for-each>																	
							</fo:table-row>	
					</xsl:for-each-group>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
										<xsl:value-of select="'Total State Tax '" />
								</fo:block>
							</fo:table-cell>	
							<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
									<xsl:variable name="loca" select="./location" />
									<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
											<fo:block>
													<xsl:variable name="totstatetx" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca]/statetx)"/>
													<xsl:choose>
													<xsl:when test="$totstatetx != 0">
															<xsl:value-of select="format-number($totstatetx, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:when>
													<xsl:otherwise>
															<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:otherwise>
													</xsl:choose>
											</fo:block>
									</fo:table-cell>		
							</xsl:for-each>																	
					</fo:table-row>						

					<xsl:for-each-group select="/all_results/results[@name = 'summuni']/row" group-by="./cnname">
							<xsl:variable name="cnname" select="./cnname"/>
							<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
												<xsl:value-of select="' ... '" />
												<xsl:value-of select="$cnname" />
										</fo:block>
									</fo:table-cell>	
									<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
											<xsl:variable name="loca" select="./location" />
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
													<fo:block>
															<xsl:variable name="countytx" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca and cnname = $cnname]/countytx)"/>
															<xsl:choose>
															<xsl:when test="$countytx != 0">
																	<xsl:value-of select="format-number($countytx, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
															</xsl:when>
															<xsl:otherwise>
																	<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
															</xsl:otherwise>
															</xsl:choose>
													</fo:block>
											</fo:table-cell>		
									</xsl:for-each>																	
							</fo:table-row>	
					</xsl:for-each-group>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
										<xsl:value-of select="'Total County Tax '" />
								</fo:block>
							</fo:table-cell>	
							<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
									<xsl:variable name="loca" select="./location" />
									<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
											<fo:block>
													<xsl:variable name="totcountytx" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca]/countytx)"/>
													<xsl:choose>
													<xsl:when test="$totcountytx != 0">
															<xsl:value-of select="format-number($totcountytx, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:when>
													<xsl:otherwise>
															<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:otherwise>
													</xsl:choose>
											</fo:block>
									</fo:table-cell>		
							</xsl:for-each>																	
					</fo:table-row>
						
					<xsl:for-each-group select="/all_results/results[@name = 'summuni']/row" group-by="./ctname">
							<xsl:variable name="ctname" select="./ctname"/>
							<fo:table-row>
									<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										<fo:block>
												<xsl:value-of select="' ... '" />
												<xsl:value-of select="$ctname" />
										</fo:block>
									</fo:table-cell>	
									<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
											<xsl:variable name="loca" select="./location" />
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
													<fo:block>
															<xsl:variable name="citytx" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca and ctname = $ctname]/citytx)"/>
															<xsl:choose>
															<xsl:when test="$citytx != 0">
																	<xsl:value-of select="format-number($citytx, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
															</xsl:when>
															<xsl:otherwise>
																	<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
															</xsl:otherwise>
															</xsl:choose>
													</fo:block>
											</fo:table-cell>		
									</xsl:for-each>																	
							</fo:table-row>	
					</xsl:for-each-group>
					<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								<fo:block>
										<xsl:value-of select="'Total City Tax '" />
								</fo:block>
							</fo:table-cell>	
							<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
									<xsl:variable name="loca" select="./location" />
									<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
											<fo:block>
													<xsl:variable name="totcitytx" select="sum(/all_results/results[@name = 'summuni']/row[./location = $loca]/citytx)"/>
													<xsl:choose>
													<xsl:when test="$totcitytx != 0">
															<xsl:value-of select="format-number($totcitytx, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:when>
													<xsl:otherwise>
															<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
													</xsl:otherwise>
													</xsl:choose>
											</fo:block>
									</fo:table-cell>		
							</xsl:for-each>																	
					</fo:table-row>
					
					<xsl:for-each select="/all_results/results[@name = 'taxcodes']/row">
							<xsl:variable name="taxcode" select="./mtaxcd" />
							<xsl:if test="/all_results/results[@name = 'summisc']/row[pmstc1 = $taxcode]">
									<xsl:call-template name="detailmisc">
											<xsl:with-param name="posfrom" select="$posfrom" />    
											<xsl:with-param name="posto" select="$posto" /> 										
											<xsl:with-param name="taxcode" select="$taxcode" />
											<xsl:with-param name="taxname" select="./mtaxds" />
									</xsl:call-template>	
							</xsl:if>
					</xsl:for-each>

			</fo:table-body>
</fo:table>
</xsl:template>

<xsl:template name="detailmisc">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 
		<xsl:param name="taxcode" />    
		<xsl:param name="taxname" />    

				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="$taxcode" />
									<xsl:value-of select="' - '" />
									<xsl:value-of select="$taxname" />
							</fo:block>
						</fo:table-cell>	
						<xsl:for-each select="/all_results/results[@name = 'loca']/row[position() &gt; $posfrom and position() &lt; $posto]">
								<xsl:variable name="loca" select="./location" />
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="right">
										<fo:block>
												<xsl:choose>
												<xsl:when test="/all_results/results[@name = 'summisc']/row[./location = $loca and ./pmstc1 = $taxcode]/pmstx1 != 0">
														<xsl:value-of select="format-number(/all_results/results[@name = 'summisc']/row[./location = $loca and ./pmstc1 = $taxcode]/pmstx1, '$ ##,###,##0.00;$ -#,###,##0.00')"/> 												
												</xsl:when>
												<xsl:otherwise>
														<xsl:value-of select="format-number(0, '$ ##,###,##0.00;$ -#,###,##0.00')"/>
												</xsl:otherwise>
												</xsl:choose>												
										</fo:block>
								</fo:table-cell>		
						</xsl:for-each>																	
			</fo:table-row>
</xsl:template>
</xsl:stylesheet>
