<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: prepay_accountsumm.xsl,v 1.3 2018-09-04 18:03:03 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" xmlns:saxon="http://saxon.sf.net/"
	xmlns:util="java:com.psasoft.reports.util.ReportUtilities" exclude-result-prefixes="java" extension-element-prefixes="saxon" version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Account Summary'" />
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:call-template name="account">
			<xsl:with-param name="row" select="/all_results/results[@name = 'acct']/row" />
		</xsl:call-template>
		<xsl:variable name="xml" select="util:getParamountPrepayCustomerAndPlans($areacode, $exchange, $line, $imsi)" />
		<xsl:if test="not(exists($xml))">
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Prepay Customer Found</fo:block>
		</xsl:if>
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="3.0in" />
			<fo:table-column column-width="2.0in" />
			<fo:table-column column-width="3.0in" />
			<fo:table-column column-width="2.0in" />
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Status'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="$xml/paramount_prepay/service_inquiry_response/cust_status" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Customer Id'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="format-number($xml/paramount_prepay/service_inquiry_response/customer_id, '#########0')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Service Number'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="/all_results/results[@name = 'detail']/row/cnpa" />
								<xsl:with-param name="nxx" select="/all_results/results[@name = 'detail']/row/cnxx" />
								<xsl:with-param name="line" select="/all_results/results[@name = 'detail']/row/cline" />
							</xsl:call-template>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:if test="./dcyy &gt; 0">
								<xsl:value-of select="'Disconnect Date'" />
							</xsl:if>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<xsl:if test="./dcmm &gt; 0">
							<fo:block>
								<xsl:call-template name="date4parm">
									<xsl:with-param name="cc" select="/all_results/results[@name = 'detail']/row/dccc" />
									<xsl:with-param name="yy" select="/all_results/results[@name = 'detail']/row/dcyy" />
									<xsl:with-param name="mm" select="/all_results/results[@name = 'detail']/row/dcmm" />
									<xsl:with-param name="dd" select="/all_results/results[@name = 'detail']/row/dcdd" />
								</xsl:call-template>
							</fo:block>
						</xsl:if>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:choose>
								<xsl:when test="./esn != 0">
									<xsl:value-of select="'ESN'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'IMEI'" />
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:choose>
								<xsl:when test="./esn != 0">
									<xsl:value-of select="format-number(/all_results/results[@name = 'detail']/row/esn, '00000000000')" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(/all_results/results[@name = 'detail']/row/imei, '000000000000000')" />
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:choose>
								<xsl:when test="./esn != 0">
									<xsl:value-of select="'MIN'" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'IMSI'" />
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:choose>
								<xsl:when test="/all_results/results[@name = 'detail']/row/xnpa != 0">
									<xsl:call-template name="phone">
										<xsl:with-param name="npa" select="/all_results/results[@name = 'detail']/row/xnpa"/>
										<xsl:with-param name="nxx" select="/all_results/results[@name = 'detail']/row/xnxx"/>
										<xsl:with-param name="line" select="/all_results/results[@name = 'detail']/row/xline"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(/all_results/results[@name = 'detail']/row/imctry, '000')" />
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number(/all_results/results[@name = 'detail']/row/imcomp, '00')" />
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number(/all_results/results[@name = 'detail']/row/imnumb, '0000000000')" />	
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
				</fo:table-row> 							
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Prepay Name'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="$xml/paramount_prepay/service_inquiry_response/customer_desc" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Contact Phone'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:call-template name="phone">
								<xsl:with-param name="npa" select="/all_results/results[@name = 'acct']/row/ctnpa" />
								<xsl:with-param name="nxx" select="/all_results/results[@name = 'acct']/row/ctnxx" />
								<xsl:with-param name="line" select="/all_results/results[@name = 'acct']/row/ctline" />
							</xsl:call-template>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Active Date'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="$xml/paramount_prepay/service_inquiry_response/active_date" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Expire Date'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="$xml/paramount_prepay/service_inquiry_response/expire_date" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Repeating Prepay'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="$xml/paramount_prepay/service_inquiry_response/repeating" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Repeating Period'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="format-number($xml/paramount_prepay/service_inquiry_response/repeating_period, '##0')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Current Balance'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="format-number($xml/paramount_prepay/balance_inquiry_response/current_balance, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Repeating Held Amount'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="format-number($xml/paramount_prepay/balance_inquiry_response/held_amount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>				
				<fo:table-row>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Required To Renew Amount'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="format-number($xml/paramount_prepay/balance_inquiry_response/renew_req_amount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right" padding-right="10px">
						<fo:block xsl:use-attribute-sets="summary-headings">
							<xsl:value-of select="'Expired Amount'" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<xsl:value-of select="format-number($xml/paramount_prepay/balance_inquiry_response/expired_amount, '$ ##,###,##0.00;$ -#,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>				
			</fo:table-body>
		</fo:table>
		<xsl:if test="exists($xml/paramount_prepay/list_customer_plans_response/plan_record)" >
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> Prepay Features
			</fo:block>
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.25in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-column column-width="1.00in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Status</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Amount Used</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Amount Remaining</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Effective Date</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>End Date</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="$xml/paramount_prepay/list_customer_plans_response/plan_record">
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./plan" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./plan_status" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./used_value, '$ ##,###,##0.00;$ -#,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(./remaining, '$ ##,###,##0.00;$ -#,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./effective_date" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./end_date" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>