<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:import href="subtemplates.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="concat('Print Flag Change Report ', $change_date_range[1], ' to ', $change_date_range[2])" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'data']/row">
			<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-header>
					<fo:table-row keep-with-next="always">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Date Time</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> By</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Account</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Account Name</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Flag</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Flag Before</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block> Flag After</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				<fo:table-body>
					<xsl:for-each select="/all_results/results[@name = 'data']/row">
						<xsl:call-template name="detailrow">
							<xsl:with-param name="row" select="." />
						</xsl:call-template>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
			
		</xsl:when>
		<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
					No Information Found
				</fo:block>		
		</xsl:otherwise>
		</xsl:choose>
</xsl:template>

<xsl:template name="detailrow">
	<xsl:param name="row" />
	<fo:table-row>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/auditdate" />
				<xsl:value-of select="' '" />
				<xsl:value-of select="$row/audittime" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:choose>
				<xsl:when test="$row/updatedby = 0">
					<xsl:value-of select="'Web User'" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$row/name" />
					<xsl:value-of select="' ('" />
					<xsl:value-of select="$row/uname" />
					<xsl:value-of select="')'" />
				</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:if test="$row/cycle != 0 and $row/acct != 0">
					<xsl:value-of select="format-number($row/cycle, '000')" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="format-number($row/acct, '0000000')" />
				</xsl:if>
				<xsl:value-of select="' '" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="$row/fname" />
				<xsl:value-of select="' '" />
				<xsl:value-of select="$row/lname" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:choose>
				<xsl:when test="$row/auditfield = 'PRTEBL'">
					<xsl:value-of select="'Print E-Bill'" />
				</xsl:when>
				<xsl:when test="$row/auditfield = 'PRTPBL'">
					<xsl:value-of select="'Print Paper Bill'" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$row/auditfield" />
				</xsl:otherwise>
				</xsl:choose>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="./flagbefore" />
			</fo:block>
		</fo:table-cell>
		<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
			<fo:block>
				<xsl:value-of select="./flagafter" />
			</fo:block>
		</fo:table-cell>
	</fo:table-row>
</xsl:template>

</xsl:stylesheet>
