<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
			    xmlns:fo="http://www.w3.org/1999/XSL/Format" 
			    xmlns:java="http://xml.apache.org/xslt/java" 
                xmlns:util="java:com.psasoft.util.TextUtilities"
			    exclude-result-prefixes="java"
				version="2.0">
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="concat('Provision Results ', $date_range[1], ' to ', $date_range[2])" />
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>
	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="/all_results/results[@name = 'data']/row">
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<fo:table-column column-width="0.8in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="2.0in" />
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="2.0in" />
					<fo:table-header>
						<fo:table-row keep-with-next="always">
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>MDN</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Submitted</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Started</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Completed</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Action</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Parm</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Equipment</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Status</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Response</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-headings-smaller">
								<fo:block>Comment</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-header>
					<fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'data']/row">
							<xsl:variable name="color">
								<xsl:choose>
									<xsl:when test="./prvsts = 'NEW'">
										<xsl:value-of select="'#FFFFCC'" />
									</xsl:when>
									<xsl:when test="./respcd = 'ERROR'">
										<xsl:value-of select="'#FFCC00'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="'white'" />
									</xsl:otherwise>
								</xsl:choose>
							</xsl:variable>
							<fo:table-row background-color="{$color}">
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:call-template name="phone">
											<xsl:with-param name="npa" select="./areacode"/>
											<xsl:with-param name="nxx" select="./exchange"/>
											<xsl:with-param name="line" select="./line"/>
										</xsl:call-template>
									</fo:block>
								</fo:table-cell>							
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./newdate" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="./newtime" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./inpgdate" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="./inpgtime" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./cmpdate" />
										<xsl:value-of select="' '" />
										<xsl:value-of select="./cmptime" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./action" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./genparm" />
									</fo:block>
								</fo:table-cell>								
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./eqpdesc" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./prvsts" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
									<fo:block>
										<xsl:value-of select="./respcd" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
									<fo:block>
										<xsl:value-of select="util:removeBinary(./resptxt)" />
									</fo:block>
								</fo:table-cell>																
							</fo:table-row>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</xsl:when>
			<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
					No Information Found
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
