<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
							  xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
							  xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				              xmlns:saxon="http://saxon.sf.net/"							  
							  xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
								extension-element-prefixes="saxon"							  
							  exclude-result-prefixes="java" 
							  version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="'Rate Plan/Print Options Report'" />

    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>	
    <xsl:template name="body_process">
		 <xsl:choose>
			<xsl:when test="/all_results/results[@name = 'rate_plan']/row">
				<xsl:for-each-group select="/all_results/results[@name='rate_plan']/row" group-by="./plan_desc">
				    <xsl:variable name="desc" select="current-group()[position() = 1]/plan_desc"/>
				    <xsl:variable name="plan" select="current-group()[position() = 1]/plan"/>
				    
		    		<fo:block xsl:use-attribute-sets="summary-headings" keep-with-next="always" space-before="10px" space-after="5px">
		    				<xsl:value-of select="$desc"/>
                            <xsl:value-of select="' ('"/>	
		    				<xsl:value-of select="$plan"/>	
				    		<xsl:value-of select="')'"/>					
		    		</fo:block>	
		
					<fo:table table-layout="fixed" width="100%" space-before="5px">
					                <fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="1.0in" />
									<fo:table-column column-width="2.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
									<fo:table-column column-width="0.5in" />
					     <fo:table-header>
							<fo:table-row>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Rate Plan</fo:block>
						    	</fo:table-cell>										
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Service No.</fo:block>
						    	</fo:table-cell>							
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Disconnected</fo:block>
						    	</fo:table-cell>		
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Account</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Account Name</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Detail</fo:block>  
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Paper</fo:block>
						    	</fo:table-cell>
						    	<fo:table-cell xsl:use-attribute-sets="table-headings">
						        	<fo:block>Elec.</fo:block>
						    	</fo:table-cell>																							
							</fo:table-row>
						 </fo:table-header>
						 <fo:table-body>
							     <xsl:for-each select="/all_results/results[@name = 'rate_plan']/row[plan = $plan]">	
							 		<fo:table-row number-columns-spanned="8">
							 			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./plan_desc" />
		                                    </fo:block>
		                                </fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
													<xsl:value-of select="format-number(./area, '000')" />
													<xsl:value-of select="'-'" />
													<xsl:value-of select="format-number(./exchange, '000')" />
													<xsl:value-of select="'-'" />
													<xsl:value-of select="format-number(./line, '0000')" />									
											</fo:block>
										</fo:table-cell>	
										
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
										    <xsl:if test="./mm &gt; 0">
												<fo:block>
													<xsl:call-template name="date1parm-db">
														<xsl:with-param name="date" select="./disconnect" />
													</xsl:call-template>	
			                                    </fo:block>
		                                    </xsl:if>
		                                </fo:table-cell>																
										
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
												<xsl:value-of select="format-number(./cycle, '000')"/>
												<xsl:value-of select="'-'"/>
												<xsl:value-of select="format-number(./account, '0000000')"/>
											</fo:block>
										</fo:table-cell>	
										

										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
											<fo:block>
												<xsl:value-of select="./firstname"/>
												<xsl:value-of select="' '"/>
												<xsl:value-of select="./lastname"/>									
											</fo:block>
										</fo:table-cell>	
										
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./detail_options" />
		                                    </fo:block>
		                                </fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./paper_options" />
		                                    </fo:block>
		                                </fo:table-cell>
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
											<fo:block>
		                                        <xsl:value-of select="./elec_options" />
		                                    </fo:block>
		                                </fo:table-cell>		                                		                                																									
									</fo:table-row>
							 </xsl:for-each>
						 </fo:table-body>
					</fo:table>					
				</xsl:for-each-group>	
			</xsl:when>		
   			<xsl:when test="count(/all_results/results[@name = 'rate_plan']/row) &lt; 1">
      			<fo:block xsl:use-attribute-sets="category-label">No Rate Plans found for this selection.</fo:block>
   			</xsl:when>			
 		</xsl:choose>
    </xsl:template>
</xsl:stylesheet>
