<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
							  xmlns:fo="http://www.w3.org/1999/XSL/Format" 
							  xmlns:java="http://xml.apache.org/xslt/java" 
							  xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
							  xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
				              xmlns:saxon="http://saxon.sf.net/"							  
							  xmlns:fn="http://www.w3.org/2005/02/xpath-functions" 
							  extension-element-prefixes="saxon"							  
							  exclude-result-prefixes="java" 
							  version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="concat('Receive By Date ', $po_receive_date[1], ' to ', $po_receive_date[2])" />
    
    
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set-landscape" />
            <xsl:call-template name="make-body-landscape" />
        </fo:root>
    </xsl:template>	
    <xsl:template name="body_process">
		 <xsl:choose>
			<xsl:when test="/all_results/results[@name = 'po']/row">
				<fo:table table-layout="fixed" width="100%" space-before="16px">
				     <fo:table-column column-width="0.50in" />
				     <fo:table-column column-width="1.00in" />
				     <fo:table-column column-width="1.00in" />
					 <fo:table-column column-width="1.50in" />
					 <fo:table-column column-width="1.50in" />
				     <fo:table-column column-width="0.40in" />
			         <fo:table-column column-width="0.60in" />
			         <fo:table-column column-width="1.00in" />
				     <fo:table-header>
						<fo:table-row>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>PO No.</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>PO Date</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Received</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Vendor / Old Location</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Rcvd Location / New Location</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Rec Qty</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Item</fo:block>
					    	</fo:table-cell>
					    	<fo:table-cell xsl:use-attribute-sets="table-headings">
					        	<fo:block>Item Desc</fo:block>
					    	</fo:table-cell>										
						</fo:table-row>
					 </fo:table-header>											
				     <fo:table-body>
					     <xsl:for-each select="/all_results/results[@name = 'po']/row">
	                        <xsl:variable name="pono" select="./pono" />
	                        <xsl:variable name="status" select="./status" />
	                        <xsl:variable name="unitid" select="./unitid" />
	                        <xsl:variable name="rcvdate" select="./rcvdate" />
	                        <xsl:variable name="rcvprice" select="./rcvcost" />
	                        <xsl:variable name="rcvbyname" select="./rcvbyname" />							
							<xsl:variable name="serial2typ" select="./serial2typ" />
						    <fo:table-row number-columns-spanned="8">
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
                                        <xsl:value-of select="./pono" />
                                    </fo:block>
                                </fo:table-cell>
							    <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
	                                    <xsl:value-of select="./podate" />
	                                </fo:block>
	                            </fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
								    <fo:block>
		                                <xsl:value-of select="./rcvdate" />
		                            </fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
                                    <xsl:choose>
                                        <xsl:when test="./olocation != ''">
                                            <fo:block>
                                                <xsl:value-of select="concat(./ocompdesc,': ',./olocation)" />
                                            </fo:block>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <fo:block>
	                                            <xsl:value-of select="./vendor" />
                                            </fo:block>
                                        </xsl:otherwise>
                                    </xsl:choose>									
                                </fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
                                    <xsl:choose>
                                        <xsl:when test="./nlocation != ''">
                                            <fo:block>
                                                <xsl:value-of select="concat(./ncompdesc,': ',./nlocation)" />
                                            </fo:block>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <fo:block>
	                                            <xsl:value-of select="concat(./companydesc,': ',./rcvloca)" />
                                            </fo:block>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
                                        <xsl:value-of select="./rcvqty" />
                                    </fo:block>
                                </fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
                                    <xsl:choose>
                                        <xsl:when test="./externalcd != ''">
                                            <fo:block>
                                                <xsl:value-of select="./externalcd" />
                                            </fo:block>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <fo:block>
                                                <xsl:value-of select="./unitcode" />
                                            </fo:block>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </fo:table-cell>	
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
									<fo:block>
                                        <xsl:value-of select="./desc" />
                                    </fo:block>
                                </fo:table-cell>													
							</fo:table-row>
							<xsl:if test="./serialized = '1' and ./rcvqty &gt; 0">
							    <xsl:variable name="unitid" select="./unitid" />
							    <xsl:variable name="seriallbl">
                                    <xsl:call-template name="getserialname">
                                        <xsl:with-param name="serial2typ" select="./serial2typ" />
                                        <xsl:with-param name="s2typlabel" select="./s2typlabel" />
                                    </xsl:call-template>
							    </xsl:variable>
							    <xsl:variable name="serialno">
							        <xsl:text> &#x2007;&#x2007;</xsl:text>
							        <xsl:for-each select="/all_results/results[@name = 'mastdtl']/row[pono = $pono and rcvbyname = $rcvbyname and unitid = $unitid and ((($status = 6 or $status = 7) and statuschdt = $rcvdate) or (($status != 6 and $status != 7) and rcvdate = $rcvdate)) and (rcvprice = $rcvprice or ($status = 6 or $status = 7))]">
										<xsl:call-template name="formatserial">
											<xsl:with-param name="serial" select="./serialno2" />
											<xsl:with-param name="serial0" select="./serialno" />
											<xsl:with-param name="serial2typ" select="$serial2typ" />
											<xsl:with-param name="unitid" select="$unitid" />
											<xsl:with-param name="actpin" select="./actpin" />
											<xsl:with-param name="npa" select="./npa" />
											<xsl:with-param name="nxx" select="./nxx" />
											<xsl:with-param name="line" select="./line" />
										</xsl:call-template>
							        </xsl:for-each>
							    </xsl:variable>
							    <fo:table-row number-columns-spanned="8" keep-with-previous="always">
							        <fo:table-cell xsl:use-attribute-sets="table-cells">
							            <fo:block>
							                <xsl:value-of select="' '" />
							            </fo:block>
							        </fo:table-cell>
							        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="7">
							            <fo:block>
							                <fo:inline>
							                    <xsl:value-of select="$seriallbl" />
							                </fo:inline>
							                <fo:block space-start="auto" space-start.precedence="force" wrap-option="wrap">
							                    <xsl:value-of select="$serialno" />
							                </fo:block>
							            </fo:block>
							        </fo:table-cell>
							    </fo:table-row>
							</xsl:if>
						 </xsl:for-each>
					 </fo:table-body>
				</fo:table>
			</xsl:when>
            <xsl:when test="count(/all_results/results[@name = 'po']/row) &lt; 1">
               <fo:block xsl:use-attribute-sets="category-label">No purchase orders for these selected dates.</fo:block>
            </xsl:when>				
		 </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
