<?xml version="1.0" encoding="utf-8"?>
	<!-- $Id: saledetail_by_loca.xsl,v 1.10 2017-07-07 16:29:04 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:fo="http://www.w3.org/1999/XSL/Format" 
	xmlns:saxon="http://saxon.sf.net/" 
	xmlns:java="http://xml.apache.org/xslt/java"
	extension-element-prefixes="saxon" 
	exclude-result-prefixes="java" 
	version="2.0">
	
	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />

	<xsl:variable name="totretailsold" select="0" saxon:assignable="yes" />
	<xsl:variable name="totcostsold" select="0" saxon:assignable="yes" />
	<xsl:variable name="totretailrtn" select="0" saxon:assignable="yes" />
	<xsl:variable name="totcostrtn" select="0" saxon:assignable="yes" />
	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />

	<xsl:variable name="title">
		<xsl:choose>
			<xsl:when test="$sort_type = 1">
				<xsl:value-of select="concat('Sales Detail By Location ', $sold_date[1], ' to ', $sold_date[2])" />
			</xsl:when>
			<xsl:when test="$sort_type = 2">
				<xsl:value-of select="concat('Sales Detail By GL / Location ', $sold_date[1], ' to ', $sold_date[2])" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'Other'" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="marketcount" select="/all_results/results[@name='market']/row/marketcount" />

	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>

	<xsl:template name="body_process">
		<xsl:choose>
			<xsl:when test="$sort_type = 1 and (exists(/all_results/results[@name='detail']/row) and exists(/all_results/results[@name='itemlocasum']/row))">
				<xsl:call-template name="locationrpt" />
			</xsl:when>
			
			<xsl:when test="$sort_type = 1 and exists(/all_results/results[@name='itemlocasum']/row)">
				<xsl:for-each-group select="/all_results/results[@name='itemlocasum']/row" group-by="normalize-space(subloc1)">
					<xsl:sort select="./*[name() = 'subloc1']" />
					<xsl:sort select="./*[name() = 'market']" data-type="number" />
					<xsl:sort select="./*[name() = 'itemdesc']" />
					<xsl:sort select="./*[name() = 'gl']" data-type="number" />
					<xsl:sort select="./*[name() = 'glsub']" data-type="number" />
					
					<xsl:variable name="soldloca" select="current-group()[position() = 1]/subloc1" />

					<xsl:call-template name="locasummary">
						<xsl:with-param name="marketcount" select="$marketcount" />
						<xsl:with-param name="soldloca" select="$soldloca" />
					</xsl:call-template>
				</xsl:for-each-group>
			</xsl:when>
			
			<xsl:when test="$sort_type = 2 and (exists(/all_results/results[@name='detail']/row) and exists(/all_results/results[@name='itemglsum']/row))">
				<xsl:call-template name="glrpt" />
			</xsl:when>

			<xsl:when test="$sort_type = 2 and exists(/all_results/results[@name='itemglsum']/row)">
				<xsl:for-each-group select="/all_results/results[@name='itemglsum']/row" group-by="normalize-space(glsort)">
					<xsl:sort select="./*[name() = 'market']" data-type="number" />
					<xsl:sort select="./*[name() = 'gl']" data-type="number" />
					<xsl:sort select="./*[name() = 'glsub']" data-type="number" />
					<xsl:sort select="./*[name() = 'subloc1']" />
					<xsl:sort select="./*[name() = 'itemdesc']" />

					<xsl:variable name="glsort" select="current-group()/glsort" />
					<xsl:variable name="market" select="current-group()[position() = 1]/market" />
	
					<xsl:call-template name="glsummary">
						<xsl:with-param name="glsort" select="$glsort" />
						<xsl:with-param name="market" select="$market" />
						<xsl:with-param name="marketcount" select="$marketcount" />
						<xsl:with-param name="gl" select="./gl" />
						<xsl:with-param name="glsub" select="./glsub" />
					</xsl:call-template>
				</xsl:for-each-group>
			</xsl:when>
			
			<xsl:otherwise>
				<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Information Found</fo:block>
			</xsl:otherwise>
			
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="locationrpt">
		<xsl:for-each-group select="/all_results/results[@name='detail']/row" group-by="normalize-space(subloc1)">
			<xsl:sort select="./*[name() = 'subloc1']" />
			<xsl:sort select="./*[name() = 'market']" data-type="number" />
			<xsl:sort select="./*[name() = 'itemdesc']" />
			<xsl:sort select="./*[name() = 'gl']" data-type="number" />
			<xsl:sort select="./*[name() = 'glsub']" data-type="number" />
			
			<saxon:assign name="totretailsold" select="0" />
			<saxon:assign name="totcostsold" select="0" />
			<saxon:assign name="totretailrtn" select="0" />
			<saxon:assign name="totcostrtn" select="0" />

			<xsl:variable name="soldloca" select="current-group()[position() = 1]/subloc1" />

			<xsl:if test="$report_type = 2">
			
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<fo:table-column column-width="0.60in" />
					<xsl:if test="$marketcount > 1">
						<fo:table-column column-width="0.5in" />
					</xsl:if>
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.7in" />
					<fo:table-column column-width="1.2in" />
					<fo:table-column column-width="0.5in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.2in" />
					<fo:table-column column-width="0.7in" />
					<fo:table-column column-width="0.7in" />
					<fo:table-column column-width="0.7in" />
					<fo:table-header>
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="{if ($marketcount > 1) then 12 else 11}">
								<fo:block>
									Location:
									<xsl:value-of select="$soldloca" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<xsl:call-template name="detailhead" />
					</fo:table-header>
					<fo:table-body>
						<xsl:for-each select="/all_results/results[@name='detail']/row[subloc1 = $soldloca]">
							<xsl:sort select="./*[name() = 'subloc1']" />
							<xsl:sort select="./*[name() = 'itemdesc']" />
							<xsl:sort select="./*[name() = 'gl']" data-type="number" />
							<xsl:sort select="./*[name() = 'glsub']" data-type="number" />
							
							<xsl:variable name="unitid" select="./unitid" />
							<xsl:variable name="cost" select="/all_results/results[@name = 'costprices']/row[unitid = $unitid]/unitamt" />
							<xsl:variable name="retail" select="/all_results/results[@name = 'retailprices']/row[unitid = $unitid]/unitamt" />
							<xsl:if test="./status = 2 or (./status = 8 and ./soldperiod = 1)">
								<xsl:if test="exists($retail)">
									<saxon:assign name="totretailsold" select="$totretailsold + $retail" />
								</xsl:if>
								<xsl:if test="exists($cost)">
									<saxon:assign name="totcostsold" select="$totcostsold + $cost" />
								</xsl:if>
							</xsl:if>
							<xsl:if test="./status = 8">
								<xsl:if test="exists($retail)">
									<saxon:assign name="totretailrtn" select="$totretailrtn + $retail" />
								</xsl:if>
								<xsl:if test="exists($cost)">
									<saxon:assign name="totcostrtn" select="$totcostrtn + $cost" />
								</xsl:if>
							</xsl:if>
							
							<xsl:call-template name="detailrow">
								<xsl:with-param name="row" select="." />
							</xsl:call-template>
							
						</xsl:for-each>
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" number-columns-spanned="{if ($marketcount > 1) then 9 else 8}" text-align="left">
								<fo:block>Total Sold</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($totcostsold, '##,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($totretailsold, '##,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(sum(/all_results/results[@name='detail']/row[subloc1 = $soldloca and (./status = 2 or (./status = 8 and ./soldperiod = 1))]/saleprice), '##,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell xsl:use-attribute-sets="table-cells" number-columns-spanned="{if ($marketcount > 1) then 9 else 8}" text-align="left">
								<fo:block>Total Returned</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($totcostrtn, '##,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number($totretailrtn, '##,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
								<fo:block>
									<xsl:value-of select="format-number(sum(/all_results/results[@name='detail']/row[subloc1 = $soldloca and status = 8]/saleprice), '##,###,##0.00')" />
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</xsl:if>
			
			<xsl:call-template name="locasummary">
				<xsl:with-param name="marketcount" select="$marketcount" />
				<xsl:with-param name="soldloca" select="$soldloca" />
			</xsl:call-template>
		</xsl:for-each-group>
	</xsl:template>
	
	<xsl:template name="locasummary" >
		<xsl:param name="marketcount" />
		<xsl:param name="soldloca" />
	
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<fo:table-column column-width="1.00in" />
			<xsl:if test="$marketcount > 1">
				<fo:table-column column-width="0.50in" />
			</xsl:if>
			<fo:table-column column-width="0.50in" />
			<fo:table-column column-width="2.00in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-header>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="{if ($marketcount > 1) then 12 else 11}">
						<fo:block>
							Location:
							<xsl:value-of select="$soldloca" />
							Sold Counts
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>GL Code</fo:block>
					</fo:table-cell>
					<xsl:if test="$marketcount > 1">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Mkt</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Sold Count</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Cost</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Retail Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Sold Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Rtn Count</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Rtn Cost</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Retail Rtn Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Return Price</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'itemlocasum']/row[subloc1 = $soldloca]">
					<xsl:variable name="unitid" select="./unitid" />
					<xsl:variable name="cost" select="/all_results/results[@name = 'costprices']/row[unitid = $unitid]/unitamt" />
					<xsl:variable name="retail" select="/all_results/results[@name = 'retailprices']/row[unitid = $unitid]/unitamt" />
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:if test="./gl > ''">
									<xsl:value-of select="format-number(./gl, '######0')" />
								</xsl:if>
								<xsl:if test="./glsub > ''">
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number(./glsub, '####0')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<xsl:if test="$marketcount > 1">
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./market" />
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<xsl:choose>
								<xsl:when test="./externalcd != ''">
									<fo:block>
										<xsl:value-of select="./externalcd" />
									</fo:block>
								</xsl:when>
								<xsl:otherwise>
									<fo:block>
										<xsl:value-of select="./unitcode" />
									</fo:block>
								</xsl:otherwise>
							</xsl:choose>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
								<xsl:value-of select="./itemdesc" />
								<xsl:if test="./deleted = 1">
									<fo:inline color="red" font-weight="bold">
										<xsl:value-of select="' - &lt;DELETED ITEM&gt;'" />
									</fo:inline>
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./soldcount, '##,###,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($cost)">
									<xsl:value-of select="format-number(./soldcount * $cost, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($retail)">
									<xsl:value-of select="format-number(./soldcount * $retail, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./saleprice, '##,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./rtncount, '##,###,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($cost)">
									<xsl:value-of select="format-number(./rtncount * $cost, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($retail)">
									<xsl:value-of select="format-number(./rtncount * $retail, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./rtnprice, '##,###,##0.00')" />
							</fo:block>
						</fo:table-cell>						
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="{if ($marketcount > 1) then 4 else 3}">
						<fo:block>Total Sold</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemlocasum']/row[subloc1 = $soldloca]/soldcount), '##,###,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totcostsold, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totretailsold, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemlocasum']/row[subloc1 = $soldloca]/saleprice), '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemlocasum']/row[subloc1 = $soldloca]/rtncount), '##,###,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totcostrtn, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totretailrtn, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemlocasum']/row[subloc1 = $soldloca]/rtnprice), '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>				
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="glrpt">
		<xsl:for-each-group select="/all_results/results[@name='detail']/row" group-by="market">

			<saxon:assign name="totretailsold" select="0" />
			<saxon:assign name="totcostsold" select="0" />
			<saxon:assign name="totretailrtn" select="0" />
			<saxon:assign name="totcostrtn" select="0" />
			<xsl:variable name="market" select="current-group()[position() = 1]/market" />

			<xsl:if test="$marketcount > 1">
				<fo:block xsl:use-attribute-sets="component-1">
					<xsl:value-of select="'Market: '" />
					<xsl:value-of select="$market" />
				</fo:block>
			</xsl:if>
			<xsl:for-each-group select="/all_results/results[@name='detail']/row[market = $market]" group-by="normalize-space(glsort)">
				<xsl:sort select="./*[name() = 'market']" data-type="number" />
				<xsl:sort select="./*[name() = 'gl']" data-type="number" />
				<xsl:sort select="./*[name() = 'glsub']" data-type="number" />
				<xsl:sort select="./*[name() = 'subloc1']" />
				<xsl:sort select="./*[name() = 'itemdesc']" />
				<xsl:variable name="glsort" select="current-group()/glsort" />
				<saxon:assign name="totretailsold" select="0" />
				<saxon:assign name="totcostsold" select="0" />
				<saxon:assign name="totretailrtn" select="0" />
				<saxon:assign name="totcostrtn" select="0" />

				<xsl:if test="$report_type = 2 and exists(/all_results/results[@name='detail']/row[market = $market])">
					<fo:table table-layout="fixed" width="100%" space-before="16px">
						<fo:table-column column-width="1.00in" />
						<xsl:if test="$marketcount > 1">
							<fo:table-column column-width="0.5in" />
						</xsl:if>
						<fo:table-column column-width="0.5in" />
						<fo:table-column column-width="1.2in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="0.5in" />
						<fo:table-column column-width="1.0in" />
						<fo:table-column column-width="1.2in" />
						<fo:table-column column-width="0.7in" />
						<fo:table-column column-width="0.7in" />
						<fo:table-column column-width="0.7in" />

						<fo:table-header>
							<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="{if ($marketcount > 1) then 12 else 11}">
									<fo:block>
										General Ledger Account:
										<xsl:if test="./gl > ''">
											<xsl:value-of select="format-number(./gl, '######0')" />
										</xsl:if>
										<xsl:if test="./glsub > ''">
											<xsl:value-of select="'-'" />
											<xsl:value-of select="format-number(./glsub, '####0')" />
										</xsl:if>
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<xsl:call-template name="detailhead" />
						</fo:table-header>
						<fo:table-body>
							<xsl:for-each select="/all_results/results[@name='detail']/row[glsort = $glsort and market = $market]">
								<xsl:sort select="./*[name() = 'gl']" data-type="number" />
								<xsl:sort select="./*[name() = 'glsub']" data-type="number" />
								<xsl:sort select="./*[name() = 'subloc1']" />
								<xsl:sort select="./*[name() = 'itemdesc']" />
								<xsl:variable name="unitid" select="./unitid" />
								<xsl:variable name="cost" select="/all_results/results[@name = 'costprices']/row[unitid = $unitid]/unitamt" />
								<xsl:variable name="retail" select="/all_results/results[@name = 'retailprices']/row[unitid = $unitid]/unitamt" />
								<xsl:if test="./status = 2 or (./status = 8 and ./soldperiod = 1)">
									<xsl:if test="exists($retail)">
										<saxon:assign name="totretailsold" select="$totretailsold + $retail" />
									</xsl:if>
									<xsl:if test="exists($cost)">
										<saxon:assign name="totcostsold" select="$totcostsold + $cost" />
									</xsl:if>
								</xsl:if>
								<xsl:if test="./status = 8">
									<xsl:if test="exists($retail)">
										<saxon:assign name="totretailrtn" select="$totretailrtn + $retail" />
									</xsl:if>
									<xsl:if test="exists($cost)">
										<saxon:assign name="totcostrtn" select="$totcostrtn + $cost" />
									</xsl:if>
								</xsl:if>
								
								<xsl:call-template name="detailrow">
									<xsl:with-param name="row" select="." />
								</xsl:call-template>

							</xsl:for-each>
							<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-cells" number-columns-spanned="{if ($marketcount > 1) then 9 else 8}" text-align="left">
									<fo:block>Total Sold</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number($totcostsold, '##,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number($totretailsold, '##,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(sum(/all_results/results[@name='detail']/row[glsort = $glsort and market = $market and (./status = 2 or (./status = 8 and ./soldperiod = 1))]/saleprice), '##,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row>
								<fo:table-cell xsl:use-attribute-sets="table-cells" number-columns-spanned="{if ($marketcount > 1) then 9 else 8}" text-align="left">
									<fo:block>Total Returned</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number($totcostrtn, '##,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number($totretailrtn, '##,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
									<fo:block>
										<xsl:value-of select="format-number(sum(/all_results/results[@name='detail']/row[glsort = $glsort and market = $market and ./status = 8]/saleprice), '##,###,##0.00')" />
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</fo:table-body>
					</fo:table>
				</xsl:if>

				<xsl:call-template name="glsummary">
					<xsl:with-param name="glsort" select="$glsort" />
					<xsl:with-param name="market" select="$market" />
					<xsl:with-param name="marketcount" select="$marketcount" />
					<xsl:with-param name="gl" select="./gl" />
					<xsl:with-param name="glsub" select="./glsub" />
				</xsl:call-template>
			</xsl:for-each-group>
		</xsl:for-each-group>
	</xsl:template>
	
	<xsl:template name="glsummary">
		<xsl:param name="glsort" />
		<xsl:param name="market" />
		<xsl:param name="marketcount" />
		<xsl:param name="gl" />
		<xsl:param name="glsub" />
		
		<fo:table table-layout="fixed" width="100%" space-before="8px">
			<xsl:if test="$marketcount > 1">
				<fo:table-column column-width="0.5in" />
			</xsl:if>
			<fo:table-column column-width="1.00in" />
			<fo:table-column column-width="0.5in" />
			<fo:table-column column-width="2.0in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-column column-width="0.7in" />
			<fo:table-header>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-headings" text-align="left" number-columns-spanned="{if ($marketcount > 1) then 12 else 11}">
						<xsl:if test="$marketcount > 1">
							<fo:block>
								<xsl:value-of select="'Market: '" />
								<xsl:value-of select="$market" />
							</fo:block>
						</xsl:if>
						<fo:block>
							General Ledger Account:
							<xsl:value-of select="format-number($gl, '######0')" />
							<xsl:value-of select="'-'" />
							<xsl:value-of select="format-number($glsub, '####0')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<xsl:if test="$marketcount > 1">
						<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Mkt</fo:block>
						</fo:table-cell>
					</xsl:if>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>GL Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item Code</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Item</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Sold Count</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total at Item Cost</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total at Retail Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total at Sold Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Return Count</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Rtn at Item Cost</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Rtn at Retail Price</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
						<fo:block>Total Rtn at Sold Price</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'itemglsum']/row[market = $market and glsort = $glsort]">
					<xsl:variable name="unitid" select="./unitid" />
					<xsl:variable name="cost" select="/all_results/results[@name = 'costprices']/row[unitid = $unitid]/unitamt" />
					<xsl:variable name="retail" select="/all_results/results[@name = 'retailprices']/row[unitid = $unitid]/unitamt" />
					<!-- 
					<xsl:if test="./status = 2 or (./status = 8 and ./soldperiod = 1)">
						<xsl:if test="exists($retail)">
							<saxon:assign name="totretailsold" select="$totretailsold + $retail" />
						</xsl:if>
						<xsl:if test="exists($cost)">
							<saxon:assign name="totcostsold" select="$totcostsold + $cost" />
						</xsl:if>
					</xsl:if>
					<xsl:if test="./status = 8">
						<xsl:if test="exists($retail)">
							<saxon:assign name="totretailrtn" select="$totretailrtn + $retail" />
						</xsl:if>
						<xsl:if test="exists($cost)">
							<saxon:assign name="totcostrtn" select="$totcostrtn + $cost" />
						</xsl:if>
					</xsl:if>
					-->
					<fo:table-row>
						<xsl:if test="$marketcount > 1">
							<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
								<fo:block>
									<xsl:value-of select="./market" />
								</fo:block>
							</fo:table-cell>
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:if test="./gl > ''">
									<xsl:value-of select="format-number(./gl, '######0')" />
								</xsl:if>
								<xsl:if test="./glsub > ''">
									<xsl:value-of select="'-'" />
									<xsl:value-of select="format-number(./glsub, '####0')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<xsl:choose>
								<xsl:when test="./externalcd != ''">
									<fo:block>
										<xsl:value-of select="./externalcd" />
									</fo:block>
								</xsl:when>
								<xsl:otherwise>
									<fo:block>
										<xsl:value-of select="./unitcode" />
									</fo:block>
								</xsl:otherwise>
							</xsl:choose>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
								<xsl:value-of select="./itemdesc" />
								<xsl:if test="./deleted = 1">
									<fo:inline color="red" font-weight="bold">
										<xsl:value-of select="' - &lt;DELETED ITEM&gt;'" />
									</fo:inline>
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./soldcount, '##,###,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($cost)">
									<xsl:value-of select="format-number(./soldcount * $cost, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($retail)">
									<xsl:value-of select="format-number(./soldcount * $retail, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./saleprice, '##,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./rtncount, '##,###,##0')" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($cost)">
									<xsl:value-of select="format-number(./rtncount * $cost, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="' '" />
								<xsl:if test="exists($retail)">
									<xsl:value-of select="format-number(./rtncount * $retail, '##,###,##0.00')" />
								</xsl:if>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:value-of select="format-number(./rtnprice, '##,###,##0.00')" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="{if ($marketcount > 1) then 4 else 3}">
						<fo:block>Total Sold</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemglsum']/row[glsort = $glsort and market = $market]/soldcount), '##,###,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totcostsold, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totretailsold, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemglsum']/row[glsort = $glsort and market = $market]/saleprice), '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemglsum']/row[glsort = $glsort and market = $market]/rtncount), '##,###,##0')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totcostrtn, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number($totretailrtn, '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(sum(/all_results/results[@name='itemglsum']/row[glsort = $glsort and market = $market]/rtnprice), '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
	<xsl:template name="detailhead">
		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>GL Code</fo:block>
			</fo:table-cell>
			<xsl:if test="$marketcount > 1">
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Mkt</fo:block>
				</fo:table-cell>
			</xsl:if>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Item Code</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Item</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Item Serial#</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Sold By</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Status</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Sold/Rtn Date</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Invoice Number</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Item Cost</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Retail Price</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-headings">
				<fo:block>Sold Price</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>

	<xsl:template name="detailrow">
		<xsl:param name="row" />
		<xsl:variable name="unitid" select="$row/unitid" />
		<xsl:variable name="cost" select="/all_results/results[@name = 'costprices']/row[unitid = $unitid]/unitamt" />
		<xsl:variable name="retail" select="/all_results/results[@name = 'retailprices']/row[unitid = $unitid]/unitamt" />
		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<fo:block>
					<xsl:if test="$row/gl > ''">
						<xsl:value-of select="format-number($row/gl, '######0')" />
					</xsl:if>
					<xsl:if test="$row/glsub > ''">
						<xsl:value-of select="'-'" />
						<xsl:value-of select="format-number($row/glsub, '####0')" />
					</xsl:if>
				</fo:block>
			</fo:table-cell>
			<xsl:if test="$marketcount > 1">
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:value-of select="$row/market" />
					</fo:block>
				</fo:table-cell>
			</xsl:if>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<xsl:choose>
					<xsl:when test="$row/externalcd != ''">
						<fo:block>
							<xsl:value-of select="$row/externalcd" />
						</fo:block>
					</xsl:when>
					<xsl:otherwise>
						<fo:block>
							<xsl:value-of select="$row/unitcode" />
						</fo:block>
					</xsl:otherwise>
				</xsl:choose>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/itemdesc" />
					<xsl:if test="$row/deleted = 1">
						<fo:inline color="red" font-weight="bold">
							<xsl:value-of select="' - &lt;DELETED ITEM&gt;'" />
						</fo:inline>
					</xsl:if>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<fo:inline space-end="0.2in" space-start.precedence="force">
						<xsl:value-of select="$row/serialno2" />
						<xsl:if test="normalize-space($row/serialno)">
							<xsl:value-of select="' (S#: '" />
							<xsl:value-of select="$row/serialno" />
							<xsl:value-of select="')'" />
						</xsl:if>
						<xsl:value-of select="' '" />
					</fo:inline>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/soldby" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<xsl:choose>
					<xsl:when test="$row/status = '8'">
						<fo:block>
							<xsl:value-of select="'Return'" />
						</fo:block>
					</xsl:when>
					<xsl:otherwise>
						<fo:block>
							<xsl:value-of select="'Sold'" />
						</fo:block>
					</xsl:otherwise>
				</xsl:choose>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<xsl:choose>
					<xsl:when test="$row/status = '8'">
						<fo:block>
							<xsl:value-of select="'S: '" />
							<xsl:value-of select="$row/saledate" />
						</fo:block>
						<fo:block>
							<xsl:value-of select="'R: '" />
							<xsl:value-of select="$row/rtndate" />
						</fo:block>
					</xsl:when>
					<xsl:otherwise>
						<fo:block>
							<xsl:value-of select="'S: '" />
							<xsl:value-of select="$row/saledate" />
						</fo:block>
					</xsl:otherwise>
				</xsl:choose>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<fo:block>
					<xsl:value-of select="$row/salerefno" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
				<fo:block>
					<xsl:value-of select="$cost" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
				<fo:block>
					<xsl:value-of select="$retail" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="right">
				<fo:block>
					<xsl:value-of select="format-number($row/saleprice, '##,###,##0.00')" />
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
</xsl:stylesheet>