<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: testpo.xsl,v 1.6 2018-09-04 18:03:02 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
				exclude-result-prefixes="java" 
				version="2.0">
    <xsl:import href="Literal.xsl" />
    <xsl:import href="Format.xsl" />
    <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
    <xsl:variable name="title" select="test" />
    
    <xsl:template match="/">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <xsl:call-template name="make-layout-master-set" />
            <xsl:call-template name="make-body" />
        </fo:root>
    </xsl:template>
    <xsl:template name="body_process">
        <xsl:for-each select="/report_data/purchase_order">
            <xsl:variable name="attachid" select="./inv_company/@attachment_id" />
            <xsl:variable name="companyicon" select="java:com.psasoft.reports.util.ReportUtilities.getStorageSavedToFile($attachid)" />
            <fo:table table-layout="fixed" width="100%">
                <fo:table-column column-width="75px" />
                <fo:table-column column-width="250px" />
                <fo:table-column column-width="75px" />
                <fo:table-column column-width="100px" />
                <fo:table-body>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block>
                                <fo:external-graphic src="url({$companyicon})" height="45px" width="45px" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="report-title" space-after="10px" font-size="16pt" text-align="left">Purchase Order</fo:block>
                            <fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
                                <xsl:value-of select="./inv_company/desc" />
                            </fo:block>
                            <xsl:if test="normalize-space(./inv_company/address[@type='company_bill_to_address']/address/line1) != ' '">
                                <fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
                                    <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/line1" />
                                </fo:block>
                            </xsl:if>
                            <xsl:if test="normalize-space(./inv_company/address[@type='company_bill_to_address']/address/line2) != ' '">
                                <fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
                                    <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/line2" />
                                </fo:block>
                            </xsl:if>
                            <xsl:if test="normalize-space(./inv_company/address[@type='company_bill_to_address']/address/line3) != ' '">
                                <fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
                                    <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/line3" />
                                </fo:block>
                            </xsl:if>
                            <fo:block xsl:use-attribute-sets="component-2" font-weight="bold">
                            <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/city" />
                            , 
                            <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/state" />
                            <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/zip" />
                            <xsl:if test="normalize-space(./inv_company/address[@type='company_bill_to_address']/address/country) != ' '">
                                <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/country" />
                            </xsl:if>
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-1">PO Number</fo:block>
                            <fo:block xsl:use-attribute-sets="component-1">PO Date</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-1">
                                <xsl:value-of select="./po_number" />
                            </fo:block>
                            <fo:block xsl:use-attribute-sets="component-1">
                                <xsl:value-of select="./po_date" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </fo:table-body>
            </fo:table>
            <fo:block text-align="center" start-indent="10pt" space-after="8pt" color="navy">
                <fo:leader leader-pattern="rule" leader-length="500pt" />
            </fo:block>
            <xsl:variable name="vendid" select="./vendor/@id" />
            <fo:table table-layout="fixed" width="100%">
                <fo:table-column column-width="1.75in" />
                <fo:table-column column-width="1.75in" />
                <fo:table-column column-width="1.75in" />
                <fo:table-column column-width="1.75in" />
                <fo:table-body>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Vendor</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./vendor/name" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Vendor Account</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./vendor/vendor_account" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Address 1</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./vendor/address/line1" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Vendor Terms</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./vendor/vendor_terms" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Address 2</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./vendor/address/line2" />
                            </fo:block>
                            <xsl:if test="normalize-space(./vendor/address/line3) != ' '">
                                <fo:block xsl:use-attribute-sets="component-2">
                                    <xsl:value-of select="./vendor/address/line3" />
                                </fo:block>
                            </xsl:if>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Buyer</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">lancetx</fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">City/State/Zip</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                            <xsl:value-of select="./vendor/address/city" />
                            , 
                            <xsl:value-of select="./vendor/address/state" />
                            <xsl:value-of select="./vendor/address/zip" />
                            <xsl:value-of select="./vendor/address/country" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2" space-before="16pt">Bill To:</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2" space-before="16pt">Ship To:</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Address 1</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/line1" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Address 1</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./inv_company/address[@type='company_ship_to_address']/address/line1" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Address 2</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/line2" />
                            </fo:block>
                            <xsl:if test="normalize-space(./inv_company/address[@type='company_bill_to_address']/address/line3) != ' '">
                                <fo:block xsl:use-attribute-sets="component-2">
                                    <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/line3" />
                                </fo:block>
                            </xsl:if>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">Address 2</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                                <xsl:value-of select="./inv_company/address[@type='company_ship_to_address']/address/line2" />
                            </fo:block>
                            <xsl:if test="normalize-space(./inv_company/address[@type='company_ship_to_address']/address/line3) != ' '">
                                <fo:block xsl:use-attribute-sets="component-2">
                                    <xsl:value-of select="./inv_company/address[@type='company_ship_to_address']/address/line3" />
                                </fo:block>
                            </xsl:if>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">City/State/Zip</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                            <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/city" />
                            , 
                            <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/state" />
                            <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/zip" />
                            <xsl:value-of select="./inv_company/address[@type='company_bill_to_address']/address/country" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">City/State/Zip</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2">
                            <xsl:value-of select="./inv_company/address[@type='company_ship_to_address']/address/city" />
                            , 
                            <xsl:value-of select="./inv_company/address[@type='company_ship_to_address']/address/state" />
                            <xsl:value-of select="./inv_company/address[@type='company_ship_to_address']/address/zip" />
                            <xsl:value-of select="./inv_company/address[@type='company_ship_to_address']/address/country" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2" space-before="12px">Preferred Shipper</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2" space-before="12px">
                                <xsl:value-of select="./pref_shipper_id/shipper/desc" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2" space-before="12px">Alternate Shipping</fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block xsl:use-attribute-sets="component-2" space-before="12px">
                                <xsl:value-of select="./alt_shipper_id/shipper/desc" />
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </fo:table-body>
            </fo:table>
            <fo:table table-layout="fixed" width="100%" space-before="16px">
                <fo:table-column column-width="0.6in" />
                <fo:table-column column-width="1.0in" />
                <fo:table-column column-width="1.0in" />
                <fo:table-column column-width="1.5in" />
                <fo:table-column column-width="0.6in" />
                <fo:table-column column-width="0.8in" />
                <fo:table-column column-width="1.5in" />
                <fo:table-body>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Ordered Quantity</fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Item Code</fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Vendor Item Code</fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Item Description</fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Price</fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Total</fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-headings">
                            <fo:block>Comments</fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                    <xsl:for-each select="./po_detail_row">
                        <fo:table-row keep-with-next="always">
                            <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                                <fo:block>
                                    <xsl:value-of select="./unit_qty" />
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                                <fo:block>
                                    <xsl:value-of select="./catalog_item/unit_code" />
                                </fo:block>
                            </fo:table-cell>
														<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
																<fo:block>
																		<xsl:value-of select="./catalog_item/vendor_item_info[vendor/@id=$vendid]/vendor_code" />
																</fo:block>
                            </fo:table-cell>
                            <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
                                <fo:block>
                                    <xsl:value-of select="./catalog_item/desc" />
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                                <fo:block>
                                    <xsl:value-of select="./unit_cost" />
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                                <fo:block>
                                    <xsl:value-of select="format-number((./unit_qty * ./unit_cost), '##,##0.00')" />
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
                                <fo:block>
                                    <xsl:value-of select="./comment" />
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:for-each>
                    <fo:table-row keep-with-next="always">
                        <fo:table-cell>
                            <fo:block>
                                
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block>
                                
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block>
                                
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block>
                               
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block>
                               
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
                            <fo:block>
                                <xsl:value-of select="format-number((./po_total_cost), '#,###,##0.00')" />
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block>
                               
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </fo:table-body>
            </fo:table>
						<fo:block text-align="center" start-indent="10pt" color="white" break-after="page">
								<fo:leader leader-pattern="rule" leader-length="500pt" />
            </fo:block>
        </xsl:for-each>
    </xsl:template>
</xsl:stylesheet>
