<?xml version="1.0" encoding="utf-8"?>
	<!-- $Id: tickets.xsl,v 1.5 2012-08-15 11:50:33 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format" 
				xmlns:java="http://xml.apache.org/xslt/java" 
                xmlns:str="java:org.apache.commons.lang.StringUtils"		
                xmlns:util="java:com.psasoft.util.TextUtilities"
				exclude-result-prefixes="java"
				version="2.0">

	<xsl:import href="Literal.xsl" />
	<xsl:import href="Format.xsl" />
	<xsl:import href="subtemplates.xsl" />

	<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
	<xsl:variable name="title" select="'Tickets Report'" />

	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:call-template name="make-layout-master-set-landscape" />
			<xsl:call-template name="make-body-landscape" />
		</fo:root>
	</xsl:template>

	<xsl:template name="body_process">
		<xsl:choose>

		<xsl:when test="exists(/all_results/results[@name = 'detail']/row)">
			<xsl:choose>
			<xsl:when test="$sort_type = 1">
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<xsl:call-template name="header">
					</xsl:call-template>
					<fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'detail']/row">
							<xsl:sort select="recordid" data-type="number"/>
							<xsl:call-template name="detail">
								<xsl:with-param name="row" select="." />
							</xsl:call-template>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</xsl:when>
			<xsl:otherwise>
				<fo:table table-layout="fixed" width="100%" space-before="16px">
					<xsl:call-template name="header">
					</xsl:call-template>
					<fo:table-body>
						<xsl:for-each select="/all_results/results[@name = 'detail']/row">
							<xsl:sort select="cycle" data-type="number"/>
							<xsl:sort select="account"  data-type="number"/>
							<xsl:sort select="cnpa"  data-type="number"/>
							<xsl:sort select="cnxx"  data-type="number"/>
							<xsl:sort select="cline"  data-type="number"/>
							<xsl:sort select="dccc"  data-type="number"/>
							<xsl:sort select="dcyy"  data-type="number"/>
							<xsl:sort select="dcmm"  data-type="number"/>
							<xsl:sort select="dcdd"  data-type="number"/>
							<xsl:sort select="recordid"  data-type="number"/>
							<xsl:call-template name="detail">
								<xsl:with-param name="row" select="." />
							</xsl:call-template>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<fo:block xsl:use-attribute-sets="category-label" space-before="12px">
				No Information Found
		</fo:block>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="header">

		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.75in" />
		<fo:table-column column-width="0.74in" />
		<fo:table-column column-width="1.38in" />
		<fo:table-column column-width="1.38in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="1.00in" />
		<fo:table-column column-width="0.74in" />
		<fo:table-column column-width="0.74in" />		
		<fo:table-header>
			<fo:table-row keep-with-next="always">
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>No</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Account</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>MDN</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Disc Date</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Ticket Code</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Created</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Assigned</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Cleared</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Notify</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-headings">
					<fo:block>Due</fo:block>
				</fo:table-cell>												
			</fo:table-row>
		</fo:table-header>
	</xsl:template>

	<xsl:template name="detail">
		<xsl:param name="row" />
		<fo:table-row>
			<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
				<fo:block>
					<xsl:value-of select="format-number($row/recordid, '#########0')" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<fo:block>
					<xsl:value-of select="format-number($row/cycle, '000')" />
					<xsl:value-of select="'-'" />
					<xsl:value-of select="format-number($row/account, '0000000')" />
				</fo:block>
			</fo:table-cell>
			<xsl:choose>
			<xsl:when test="$row/tictype = 'S'">
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:call-template name="phone">
							<xsl:with-param name="npa" select="$row/cnpa" />
							<xsl:with-param name="nxx" select="$row/cnxx" />
							<xsl:with-param name="line" select="$row/cline" />
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
					<fo:block>
						<xsl:choose>
						<xsl:when test="$row/dccc = 99">
							<xsl:value-of select="'Suspend NP'" />
						</xsl:when>
						<xsl:when test="$row/dccc &gt; 0">
							<xsl:call-template name="date4parm">
								<xsl:with-param name="cc" select="$row/dccc" />
								<xsl:with-param name="yy" select="$row/dcyy" />
								<xsl:with-param name="mm" select="$row/dcmm" />
								<xsl:with-param name="dd" select="$row/dcdd" />
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="' '" />
						</xsl:otherwise>
						</xsl:choose>
					</fo:block>
				</fo:table-cell>
			</xsl:when>
			<xsl:otherwise>
				<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center" number-columns-spanned="2">
					<fo:block>
						<xsl:value-of select="'Account Level'" />
					</fo:block>
				</fo:table-cell>
			</xsl:otherwise>
			</xsl:choose>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/trbcdds" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/createname" />
				</fo:block>
				<fo:block keep-with-previous="always">
					<xsl:value-of select="util:parseAndFormatTimestamp($row/createtime)" />
				</fo:block>				
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<fo:block>
					<xsl:value-of select="$row/assignedname" />
				</fo:block>
			</fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left">
				<xsl:choose>
				<xsl:when test="$row/closeby &gt; 0">
					<fo:block>
						<xsl:value-of select="$row/closedname" />
					</fo:block>				
					<fo:block keep-with-previous="always">
						<xsl:value-of select="util:parseAndFormatTimestamp($row/closetime)" />
					</fo:block>				
					<fo:block keep-with-previous="always">
						<xsl:value-of select="$row/clrcdds" />
					</fo:block>				
				</xsl:when>
				<xsl:otherwise>
					<fo:block>
						<xsl:value-of select="' '" />
					</fo:block>
				</xsl:otherwise>
				</xsl:choose>
			</fo:table-cell>
		
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<fo:block>
					<xsl:call-template name="date1parm-db">
						<xsl:with-param name="date" select="./starttime" />
					</xsl:call-template>	
                </fo:block>
            </fo:table-cell>
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="center">
				<xsl:if test="./dueyear != 2039">
				<fo:block>
					<xsl:call-template name="date1parm-db">
						<xsl:with-param name="date" select="./duetime" />
					</xsl:call-template>	
                </fo:block>
			    </xsl:if>
            </fo:table-cell>			
		</fo:table-row>
		<fo:table-row keep-with-previous="always">
			<fo:table-cell xsl:use-attribute-sets="table-cells-smaller" text-align="left" number-columns-spanned="10">
				<xsl:variable name="textrows" select="str:split($row/descr, '~')" />
				<fo:table margin-left="10px">
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="1.0in" />
					<fo:table-column column-width="7.0in" />
					<fo:table-body>
						<xsl:for-each select="$textrows">
							<xsl:variable name="trow" select="." />
							<fo:table-row>
								<xsl:variable name="textcols" select="str:split($trow, '|')" />
								<xsl:for-each select="$textcols">
									<fo:table-cell text-align="left">
										<fo:block font-size="6pt">
											<xsl:value-of select="." />
										</fo:block>
									</fo:table-cell>
								</xsl:for-each>
							</fo:table-row>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</fo:table-cell>
		</fo:table-row>		
	</xsl:template>
</xsl:stylesheet>






