<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: transfers_by_date.xsl,v 1.13 2017-02-23 17:55:12 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:invutil="java:com.psasoft.inventory.util.InventoryUtilities"
				xmlns:catitm="java:com.psasoft.inventory.data.PCatalogItem"
                exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="concat('Transfers By Date ', $transfer_date_range[1], ' to ', $transfer_date_range[2])" />

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">

	<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'xfer']/row">
				<xsl:for-each-group select="/all_results/results[@name = 'xfer']/row" group-by="normalize-space(oldcomp)">
					<xsl:variable name="oldcomp" select="current-group()[position() = 1]/oldcomp"/>
					
					<xsl:for-each-group select="/all_results/results[@name = 'xfer']/row[oldcomp = $oldcomp]" group-by="normalize-space(oldloca)">
						<xsl:variable name="oldloca" select="current-group()[position() = 1]/oldloca"/>

						<xsl:for-each-group select="/all_results/results[@name = 'xfer']/row[oldcomp = $oldcomp and oldloca = $oldloca]" group-by="normalize-space(newcomp)">
							<xsl:variable name="newcomp" select="current-group()[position() = 1]/newcomp"/>

							<xsl:for-each-group select="/all_results/results[@name = 'xfer']/row[oldcomp = $oldcomp and oldloca = $oldloca and newcomp = $newcomp]" group-by="normalize-space(newloca)">
								<xsl:variable name="newloca" select="current-group()[position() = 1]/newloca"/>

								<fo:table space-before="16px">
									<fo:table-column column-width="5.0in"/>	
									<fo:table-column column-width="5.0in"/>		
										<fo:table-body>
												<fo:table-row keep-with-next="always">
														<fo:table-cell keep-with-next="always">
																<fo:block xsl:use-attribute-sets="category-label" keep-with-next="always">
																		Transfer From Company: <xsl:value-of select="$oldcomp" />
																</fo:block>
																<fo:block xsl:use-attribute-sets="category-label" keep-with-previous="always">
																		Transfer From Location: <xsl:value-of select="$oldloca" />
																</fo:block>
														</fo:table-cell>					
														<fo:table-cell keep-with-previous="always">
																<xsl:if test="$newloca != ''">
																	<fo:block xsl:use-attribute-sets="category-label" keep-with-next="always">
																			Transferred To Company: <xsl:value-of select="$newcomp" />
																	</fo:block>
																	<fo:block xsl:use-attribute-sets="category-label" keep-with-previous="always">
																			Transferred To Location: <xsl:value-of select="$newloca" />
																	</fo:block>
																</xsl:if>
																<fo:block><xsl:value-of select="' '" /></fo:block>
														</fo:table-cell>						
												</fo:table-row>	
												<fo:table-row keep-with-previous="always">
														<fo:table-cell number-columns-spanned="2">
																<xsl:call-template name="transferrow">
																		<xsl:with-param name="oldcomp" select="$oldcomp"/>
																		<xsl:with-param name="oldloca" select="$oldloca"/>
																		<xsl:with-param name="newcomp" select="$newcomp"/>
																		<xsl:with-param name="newloca" select="$newloca"/>
																</xsl:call-template>																
														</fo:table-cell>						
												</fo:table-row>	
										</fo:table-body>
								</fo:table>

							</xsl:for-each-group>
						</xsl:for-each-group>
					</xsl:for-each-group>
				</xsl:for-each-group>
		</xsl:when>
		<xsl:otherwise>
				<fo:block>No Transfers Found for selected date range</fo:block>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="transferrow">
		<xsl:param name="oldcomp" />
		<xsl:param name="oldloca" />
		<xsl:param name="newcomp" />
		<xsl:param name="newloca" />
		<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="2.0in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="1.0in" />
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>PO No</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Date</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Reason</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Comment</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Transfered By</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Item Code</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>GL Code</fo:block>
								</fo:table-cell>								
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Item Description</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Trnsfr Qty</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>Total Cost</fo:block>
								</fo:table-cell>
						</fo:table-row>
				</fo:table-header>
				<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'xfer']/row[oldcomp = $oldcomp and oldloca = $oldloca and newcomp = $newcomp and newloca = $newloca]">
						<xsl:variable name="pono" select="./pono"/>
						<xsl:variable name="ttype" select="./ttype"/>
						<xsl:variable name="transferdate">
								<xsl:call-template name="date1parm">
									<xsl:with-param name="date" select="replace(./tdate, '-', '')"/>
								</xsl:call-template>							
						</xsl:variable>
						<xsl:variable name="reason" select="./reason"/>
						<xsl:variable name="comment" select="./comment"/>
						<xsl:variable name="transferby" select="./transferby"/>
						<xsl:for-each select="/all_results/results[@name = 'mastsum']/row[pono = $pono and oldcomp = $oldcomp and oldloca = $oldloca and newcomp = $newcomp and newloca = $newloca]">
									<xsl:variable name="unitid" select="./unitid"/>
									<xsl:variable name="rcvprice" select="./rcvprice"/>						
		                            <xsl:variable name="status" select="./status" />
		                            <xsl:variable name="serial2typ" select="./serial2typ" />
									<fo:table-row keep-with-next="always">
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
													<fo:block>
															<xsl:choose>
															<xsl:when test="$ttype = '8'" >
																<fo:block>
																	<xsl:value-of select="'Auto'" />
																</fo:block>
															</xsl:when>
															<xsl:otherwise>
																<fo:block>
																	<xsl:value-of select="$pono" />
																</fo:block>
															</xsl:otherwise>
															</xsl:choose>
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
													<fo:block>
															<xsl:value-of select="$transferdate" />
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
												<xsl:call-template name="transfertype">
													<xsl:with-param name="ttype" select="$ttype" />
												</xsl:call-template>
												<fo:block>
													<xsl:value-of select="$reason" />
												</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
													<fo:block>
															<xsl:value-of select="$comment" />
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
													<fo:block>
															<xsl:value-of select="$transferby" />
													</fo:block>
											</fo:table-cell>

											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
													<xsl:choose>
													<xsl:when test="./externalcd != ''" >
														<fo:block>
															<xsl:value-of select="./externalcd" />
														</fo:block>
													</xsl:when>
													<xsl:otherwise>
														<fo:block>
															<xsl:value-of select="./unitcode" />
														</fo:block>
													</xsl:otherwise>
													</xsl:choose>
											</fo:table-cell>	
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
													<fo:block>
															<xsl:value-of select="./gl" />
													</fo:block>
											</fo:table-cell>											
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
													<fo:block>
															<xsl:value-of select="./unitdesc" />
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
													<fo:block>
															<xsl:value-of select="./qty" />
													</fo:block>
											</fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
												<fo:block>
													<xsl:value-of select="format-number(./rcvprice, '##,###,##0.00')" />
												</fo:block>
											</fo:table-cell>
									</fo:table-row>
									<xsl:if test="./serialized = '1'" >
										<xsl:variable name="seriallbl">
		                                    <xsl:call-template name="getserialname">
		                                        <xsl:with-param name="serial2typ" select="./serial2typ" />
		                                        <xsl:with-param name="s2typlabel" select="./s2typlabel" />
		                                    </xsl:call-template>
										</xsl:variable>
				                        <xsl:variable name="serialno">
		                                    <xsl:text> &#x2007;&#x2007;</xsl:text>
				                            <xsl:for-each select="/all_results/results[@name = 'mastdtl']/row[pono = $pono and unitid = $unitid and (rcvprice = $rcvprice or ($status = 6 or $status = 7))]">
												<xsl:call-template name="formatserial">
													<xsl:with-param name="serial" select="./serialno2" />
													<xsl:with-param name="serial0" select="./serialno" />
													<xsl:with-param name="serial2typ" select="$serial2typ" />
													<xsl:with-param name="unitid" select="$unitid" />
													<xsl:with-param name="actpin" select="./actpin" />
													<xsl:with-param name="npa" select="./npa" />
													<xsl:with-param name="nxx" select="./nxx" />
													<xsl:with-param name="line" select="./line" />
												</xsl:call-template>
				                            </xsl:for-each>
				                        </xsl:variable>                        										
										<fo:table-row>
											<fo:table-cell xsl:use-attribute-sets="table-cells"><fo:block> </fo:block></fo:table-cell>
											<fo:table-cell xsl:use-attribute-sets="table-cells" keep-with-previous="always" text-align="left" number-columns-spanned="9">
												<fo:block>
													<fo:inline><xsl:value-of select="$seriallbl" /></fo:inline>
													<fo:block space-start="auto" space-start.precedence="force" wrap-option="wrap"><xsl:value-of select="$serialno" /></fo:block>
												</fo:block>
											</fo:table-cell>
										</fo:table-row>
								</xsl:if>									
						</xsl:for-each>
				</xsl:for-each>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells" number-columns-spanned="9"><fo:block> </fo:block></fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" keep-with-previous="always" text-align="right">
						<fo:block>
								<xsl:value-of select="format-number(sum(/all_results/results[@name = 'mastsum']/row[oldcomp = $oldcomp and oldloca = $oldloca and newcomp = $newcomp and newloca = $newloca]/rcvprice), '##,###,##0.00')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>				
				</fo:table-body>
		</fo:table>
</xsl:template>
		
</xsl:stylesheet>






