<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
								xmlns:fo="http://www.w3.org/1999/XSL/Format" 
								xmlns:java="http://xml.apache.org/xslt/java" 
								exclude-result-prefixes="java" 
								version="2.0">

<xsl:import href="Literal.xsl" />
<xsl:import href="Format.xsl" />
<xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes" />
<xsl:variable name="title" select="'Under Threshold - Matrix by Vendor'" />

<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
				<xsl:call-template name="make-layout-master-set-landscape-extra-wide" />
				<xsl:call-template name="make-body-landscape" />
		</fo:root>
</xsl:template>

<xsl:template name="body_process">
		<xsl:choose>
		<xsl:when test="/all_results/results[@name = 'items']/row">
				<xsl:call-template name="main">
						<xsl:with-param name="posfrom" select="0" />    
						<xsl:with-param name="posto" select="26" /> 										
				</xsl:call-template>
				<xsl:if test="/all_results/results[@name = 'vend']/row[position() &gt; 25]">
						<fo:block break-before="page" />
						<xsl:call-template name="main">
								<xsl:with-param name="posfrom" select="26" />    
								<xsl:with-param name="posto" select="52" /> 										
						</xsl:call-template>		
				</xsl:if>
				<xsl:if test="/all_results/results[@name = 'vend']/row[position() &gt; 25]">
						<fo:block break-before="page" />
						<xsl:call-template name="main">
								<xsl:with-param name="posfrom" select="52" />    
								<xsl:with-param name="posto" select="78" /> 										
						</xsl:call-template>		
				</xsl:if>	
		</xsl:when>
		<xsl:otherwise>
				<fo:block>No items found under thresholds</fo:block>
		</xsl:otherwise>
	</xsl:choose>		
</xsl:template>

<xsl:template name="main">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 
		
		<fo:table table-layout="fixed" width="100%" space-before="16px">
				<fo:table-column column-width="1.5in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="0.5in" />
				<fo:table-column column-width="1.0in" />
				<xsl:for-each select="/all_results/results[@name = 'vend']/row[position() &gt; $posfrom and position() &lt; $posto]">
						<fo:table-column column-width="1.0in" />
				</xsl:for-each>
				<fo:table-header>
						<fo:table-row keep-with-next="always">
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Item Description
										</fo:block>
								</fo:table-cell>		
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Thrshd Level
										</fo:block>
								</fo:table-cell>
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Thshd
										</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Reord Qty
										</fo:block>
								</fo:table-cell>		
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Tot On Hand Qty
										</fo:block>
								</fo:table-cell>									
								<fo:table-cell xsl:use-attribute-sets="table-headings">
										<fo:block>
										Item Code
										</fo:block>
								</fo:table-cell>																	
								<xsl:for-each select="/all_results/results[@name = 'vend']/row[position() &gt; $posfrom and position() &lt; $posto]">
										<fo:table-cell xsl:use-attribute-sets="table-headings">
												<fo:block>
													<xsl:value-of select="normalize-space(./name)" />
												</fo:block>
										</fo:table-cell>		
								</xsl:for-each>
						</fo:table-row>
				</fo:table-header>
				<fo:table-body>
						<xsl:call-template name="detail">
								<xsl:with-param name="posfrom" select="$posfrom" />    
								<xsl:with-param name="posto" select="$posto" />	
						</xsl:call-template>		
				</fo:table-body>
		</fo:table>
</xsl:template>

<xsl:template name="detail">
		<xsl:param name="posfrom" />    
		<xsl:param name="posto" /> 

		<xsl:for-each select="/all_results/results[@name = 'items']/row">
				<xsl:variable name="unitdesc" select="./unitdesc" />
				<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<fo:block>
									<xsl:value-of select="$unitdesc" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:choose>
											<xsl:when test="./thlvlappl = 'G'">
													<xsl:value-of select="'Glb'"/>
											</xsl:when>
											<xsl:when test="./thlvlappl = 'L'">
													<xsl:value-of select="'Loc'"/>
											</xsl:when>											
											<xsl:otherwise>
													<xsl:value-of select="./thlvlappl"/>
											</xsl:otherwise>
									</xsl:choose>
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:value-of select="format-number(./threslvl, '##,##0')"/>
							</fo:block>
						</fo:table-cell>	
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:value-of select="format-number(./reorderqty, '##,##0')"/>
							</fo:block>
						</fo:table-cell>					
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
									<xsl:choose>
									<xsl:when test="/all_results/results[@name = 'mastsum']/row[./unitdesc = $unitdesc]/qty[1]">
											<xsl:value-of select="format-number(/all_results/results[@name = 'mastsum']/row[./unitdesc = $unitdesc]/qty[1], '##,##0')"/>
									</xsl:when>
									<xsl:otherwise>
											<xsl:value-of select="'-'"/>
									</xsl:otherwise>
									</xsl:choose>
							</fo:block>
						</fo:table-cell>							
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left">
							<xsl:choose>
							<xsl:when test="./unitcode != ''" >
								<fo:block>
									<xsl:value-of select="./unitcode" />
								</fo:block>
							</xsl:when>
							<xsl:otherwise>
								<fo:block>
									<xsl:value-of select="./externalcd" />
								</fo:block>
							</xsl:otherwise>
							</xsl:choose>
						</fo:table-cell>						
						<xsl:for-each select="/all_results/results[@name = 'vend']/row[position() &gt; $posfrom and position() &lt; $posto]">
								<xsl:variable name="vend" select="./name" />
								<xsl:choose>
								<xsl:when test="/all_results/results[@name = 'mastsum']/row[./name = $vend and ./unitdesc = $unitdesc]/qty > 0">
										<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
												<fo:block>
														<xsl:value-of select="'_____ @ '"/>
														<xsl:value-of select="format-number(/all_results/results[@name = 'mastsum']/row[./name = $vend and ./unitdesc = $unitdesc]/unitcost, '##,##0.00')"/>
												</fo:block>												
										</fo:table-cell>		
								</xsl:when>
								<xsl:otherwise>
										<fo:table-cell xsl:use-attribute-sets="table-cells" background-color="lightgrey">
												<fo:block>
														<xsl:value-of select="' '"/>												
												</fo:block>
										</fo:table-cell>		
								</xsl:otherwise>
								</xsl:choose>										
						</xsl:for-each>																	
			</fo:table-row>
		</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
