<?xml version="1.0" encoding="utf-8"?>
<!-- $Id: verizonhistory.xsl,v 1.4 2016-06-09 20:29:39 lancetx Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fo="http://www.w3.org/1999/XSL/Format"
                xmlns:java="http://xml.apache.org/xslt/java"
								exclude-result-prefixes="java" version="2.0">

  
  <xsl:import href="Literal.xsl"/>
  <xsl:import href="Format.xsl"/>
  <xsl:import href="subtemplates.xsl"/>
  
  <xsl:output method="xml" version="1.0" encoding="utf-8" indent="yes"/>
  <xsl:variable name="title" select="'Advance Pay Data Detail History'"/>  

<xsl:template match="/">
	<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

		<xsl:call-template name="make-layout-master-set-landscape"/>
		<xsl:call-template name="make-body-landscape"/>
	</fo:root>
</xsl:template>

<xsl:template name="body_process">
	<xsl:call-template name="account_service">
		<xsl:with-param name="row" select="/all_results/results[@name = 'acctservice']/row"/>
	</xsl:call-template>
	<xsl:choose>
	<xsl:when test="exists(/all_results/results[@name = 'hist']/row)">
		<fo:table table-layout="fixed" width="100%" space-before="16px">
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.0in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-column column-width="1.5in" />
			<fo:table-header>
				<fo:table-row keep-with-next="always">
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Start Time</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>End Time</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Category</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Footprint</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Cellsite</fo:block>
					</fo:table-cell>					
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>Cause of Close</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-headings">
							<fo:block>GB Used</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>					
			<fo:table-body>
				<xsl:for-each select="/all_results/results[@name = 'hist']/row">
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="substring(./starttime, 0, 20)" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="substring(./endtime, 0, 20)" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./category" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./footprint" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./origbsid" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="center">
							<fo:block>
								<xsl:value-of select="./causeclos" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
							<fo:block>
								<xsl:choose>
								<xsl:when test="starts-with(./totalgb, '.000000')">
									<xsl:value-of select="'0'" />
									<xsl:value-of select="substring(./totalgb, 0, 11)" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number(./totalgb, '###,##0.000000000')" />
								</xsl:otherwise>
								</xsl:choose>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="left" number-columns-spanned="6">
						<fo:block>
							<xsl:value-of select="'Total Used - From '" />
							<xsl:value-of select="substring(/all_results/results[@name = 'histsum']/row/starttime, 0, 20)" />
							<xsl:value-of select="' To '" />
							<xsl:value-of select="substring(/all_results/results[@name = 'histsum']/row/endtime, 0, 20)" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell xsl:use-attribute-sets="table-cells" text-align="right">
						<fo:block>
							<xsl:value-of select="format-number(/all_results/results[@name = 'histsum']/row/totalgb, '###,##0.000000000')" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>				
			</fo:table-body>
		</fo:table>    
	</xsl:when>
	<xsl:otherwise>
		<fo:block xsl:use-attribute-sets="category-label" space-before="12px"> No Information Found
		</fo:block>
	</xsl:otherwise>
	</xsl:choose>		
</xsl:template>

</xsl:stylesheet>






